package com.mrousavy.camera;

import android.content.Context;
import android.content.res.Configuration;
import android.graphics.Matrix;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraManager;
import android.hardware.camera2.CaptureRequest;
import android.util.Log;
import android.util.Range;
import android.util.Size;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.widget.FrameLayout;
import androidx.camera.camera2.interop.Camera2Interop;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageAnalysis;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.ImageProxy;
import androidx.camera.core.Preview;
import androidx.camera.core.UseCase;
import androidx.camera.core.ZoomState;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.lifecycle.ProcessCameraProvider;
import androidx.camera.video.FallbackStrategy;
import androidx.camera.video.Quality;
import androidx.camera.video.QualitySelector;
import androidx.camera.video.Recorder;
import androidx.camera.video.Recording;
import androidx.camera.video.VideoCapture;
import androidx.camera.view.PreviewView;
import androidx.core.content.ContextCompat;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import com.facebook.jni.HybridData;
import com.facebook.react.bridge.LifecycleEventListener;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.google.common.util.concurrent.ListenableFuture;
import com.mrousavy.camera.frameprocessor.FrameProcessorPerformanceDataCollector;
import com.mrousavy.camera.frameprocessor.FrameProcessorRuntimeManager;
import com.mrousavy.camera.frameprocessor.PerformanceSampleCollection;
import com.mrousavy.camera.utils.AspectRatioKt;
import com.mrousavy.camera.utils.CameraSelector_byIDKt;
import com.mrousavy.camera.utils.Context_displayRotationKt;
import com.mrousavy.camera.utils.DeviceFormat;
import com.mrousavy.camera.utils.ViewGroup_installHierarchyFitterKt;
import expo.modules.devlauncher.launcher.manifest.DevLauncherOrientation;
import io.sentry.protocol.Device;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import kotlin.Metadata;
import kotlin.ResultKt;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.IntrinsicsKt;
import kotlin.coroutines.jvm.internal.Boxing;
import kotlin.jvm.functions.Function2;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Ref;
import kotlin.jvm.internal.SpreadBuilder;
import kotlin.text.StringsKt;
import kotlinx.coroutines.BuildersKt;
import kotlinx.coroutines.CoroutineScope;
import kotlinx.coroutines.CoroutineScopeKt;
import kotlinx.coroutines.DebugKt;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.guava.ListenableFutureKt;
/* compiled from: CameraView.kt */
@Metadata(d1 = {"\u0000þ\u0001\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0010\u0006\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0006\n\u0002\u0018\u0002\n\u0002\b\u0007\n\u0002\u0010\u000e\n\u0002\b\b\n\u0002\u0018\u0002\n\u0002\b\u0017\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0010\b\n\u0002\b\u000b\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\f\n\u0002\u0010\t\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0007\n\u0002\b\n\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\n\n\u0002\u0010\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0004\b\u0007\u0018\u0000 Á\u00012\u00020\u00012\u00020\u0002:\u0002Á\u0001B\u0015\u0012\u0006\u0010\u0003\u001a\u00020\u0004\u0012\u0006\u0010\u0005\u001a\u00020\u0006¢\u0006\u0002\u0010\u0007J\u0014\u0010¬\u0001\u001a\u00030\u00ad\u0001H\u0083@ø\u0001\u0000¢\u0006\u0003\u0010®\u0001J\n\u0010¯\u0001\u001a\u00030\u00ad\u0001H\u0002J\u0015\u0010°\u0001\u001a\u00030\u00ad\u00012\b\u0010±\u0001\u001a\u00030²\u0001H\u0082 J\n\u0010³\u0001\u001a\u00030´\u0001H\u0016J\n\u0010µ\u0001\u001a\u00020xH\u0082 J\n\u0010¶\u0001\u001a\u00030\u00ad\u0001H\u0014J\u0016\u0010·\u0001\u001a\u00030\u00ad\u00012\n\u0010¸\u0001\u001a\u0005\u0018\u00010¹\u0001H\u0014J\n\u0010º\u0001\u001a\u00030\u00ad\u0001H\u0014J\"\u0010»\u0001\u001a\u00020\u00112\u0019\u0010¼\u0001\u001a\u0014\u0012\u0004\u0012\u00020 0½\u0001j\t\u0012\u0004\u0012\u00020 `¾\u0001J\n\u0010¿\u0001\u001a\u00030\u00ad\u0001H\u0002J\n\u0010À\u0001\u001a\u00030\u00ad\u0001H\u0003R\u001c\u0010\b\u001a\u0004\u0018\u00010\tX\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\n\u0010\u000b\"\u0004\b\f\u0010\rR\u000e\u0010\u000e\u001a\u00020\u000fX\u0082\u000e¢\u0006\u0002\n\u0000R\u001e\u0010\u0010\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0010\n\u0002\u0010\u0016\u001a\u0004\b\u0012\u0010\u0013\"\u0004\b\u0014\u0010\u0015R\u001c\u0010\u0017\u001a\u0004\u0018\u00010\u0018X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\u0019\u0010\u001a\"\u0004\b\u001b\u0010\u001cR\u0016\u0010\u001d\u001a\n \u001e*\u0004\u0018\u00010\u00060\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u001c\u0010\u001f\u001a\u0004\u0018\u00010 X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b!\u0010\"\"\u0004\b#\u0010$R\u001c\u0010%\u001a\u0004\u0018\u00010 X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b&\u0010\"\"\u0004\b'\u0010$R\u001a\u0010(\u001a\u00020)X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b*\u0010+\"\u0004\b,\u0010-R\u001a\u0010.\u001a\u00020\u0011X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b/\u00100\"\u0004\b1\u00102R\u001a\u00103\u001a\u00020\u0011X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b4\u00100\"\u0004\b5\u00102R\u001e\u00106\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0010\n\u0002\u0010\u0016\u001a\u0004\b7\u0010\u0013\"\u0004\b8\u0010\u0015R\u001a\u00109\u001a\u00020\u0011X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b:\u00100\"\u0004\b;\u00102R$\u0010=\u001a\u00020\u00112\u0006\u0010<\u001a\u00020\u0011@FX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b>\u00100\"\u0004\b?\u00102R\u0010\u0010@\u001a\u0004\u0018\u00010AX\u0082\u000e¢\u0006\u0002\n\u0000R\u001a\u0010B\u001a\u00020\u00118AX\u0080\u0004¢\u0006\f\u0012\u0004\bC\u0010D\u001a\u0004\bE\u00100R\u001c\u0010F\u001a\u0004\u0018\u00010GX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bH\u0010I\"\u0004\bJ\u0010KR\u001e\u0010L\u001a\u0004\u0018\u00010MX\u0086\u000e¢\u0006\u0010\n\u0002\u0010R\u001a\u0004\bN\u0010O\"\u0004\bP\u0010QR$\u0010S\u001a\u00020\u000f2\u0006\u0010<\u001a\u00020\u000f@FX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bT\u0010U\"\u0004\bV\u0010WR\u000e\u0010X\u001a\u00020YX\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u001e\u0010Z\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0010\n\u0002\u0010\u0016\u001a\u0004\b[\u0010\u0013\"\u0004\b\\\u0010\u0015R\u000e\u0010]\u001a\u00020^X\u0082\u000e¢\u0006\u0002\n\u0000R\u0010\u0010_\u001a\u0004\u0018\u00010`X\u0082\u000e¢\u0006\u0002\n\u0000R\u001c\u0010a\u001a\u0004\u0018\u00010bX\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bc\u0010d\"\u0004\be\u0010fR\u0014\u0010g\u001a\u00020M8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\bh\u0010iR\u001a\u0010j\u001a\u00020\u0011X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bj\u00100\"\u0004\bk\u00102R\u000e\u0010l\u001a\u00020\u0011X\u0082\u000e¢\u0006\u0002\n\u0000R\u0014\u0010m\u001a\u00020\u00118BX\u0082\u0004¢\u0006\u0006\u001a\u0004\bm\u00100R\u000e\u0010n\u001a\u00020oX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010p\u001a\u00020oX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010q\u001a\u00020\u000fX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010r\u001a\u00020sX\u0082\u0004¢\u0006\u0002\n\u0000R\u001e\u0010t\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0010\n\u0002\u0010\u0016\u001a\u0004\bu\u0010\u0013\"\u0004\bv\u0010\u0015R\u0014\u0010w\u001a\u0004\u0018\u00010x8\u0002@\u0002X\u0083\u000e¢\u0006\u0002\n\u0000R\u000e\u0010y\u001a\u00020zX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010{\u001a\u00020zX\u0082\u000e¢\u0006\u0002\n\u0000R\u001c\u0010|\u001a\u0004\u0018\u00010 X\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b}\u0010\"\"\u0004\b~\u0010$R\u0015\u0010\u007f\u001a\u00020M8BX\u0082\u0004¢\u0006\u0007\u001a\u0005\b\u0080\u0001\u0010iR!\u0010\u0081\u0001\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0012\n\u0002\u0010\u0016\u001a\u0005\b\u0082\u0001\u0010\u0013\"\u0005\b\u0083\u0001\u0010\u0015R\u0012\u0010\u0084\u0001\u001a\u0005\u0018\u00010\u0085\u0001X\u0082\u000e¢\u0006\u0002\n\u0000R\u001f\u0010\u0086\u0001\u001a\u00030\u0087\u0001X\u0080\u0004¢\u0006\u0011\n\u0000\u0012\u0005\b\u0088\u0001\u0010D\u001a\u0006\b\u0089\u0001\u0010\u008a\u0001R\u0018\u0010\u008b\u0001\u001a\u00030\u008c\u00018BX\u0082\u0004¢\u0006\b\u001a\u0006\b\u008d\u0001\u0010\u008e\u0001R\u001f\u0010\u008f\u0001\u001a\n \u001e*\u0004\u0018\u00010\u00060\u0006X\u0080\u0004¢\u0006\n\n\u0000\u001a\u0006\b\u0090\u0001\u0010\u0091\u0001R\u0010\u0010\u0092\u0001\u001a\u00030\u0093\u0001X\u0082\u0004¢\u0006\u0002\n\u0000R\u0010\u0010\u0094\u0001\u001a\u00030\u0095\u0001X\u0082\u0004¢\u0006\u0002\n\u0000R\u001f\u0010\u0096\u0001\u001a\n \u001e*\u0004\u0018\u00010\u00060\u0006X\u0080\u0004¢\u0006\n\n\u0000\u001a\u0006\b\u0097\u0001\u0010\u0091\u0001R\u001d\u0010\u0098\u0001\u001a\u00020 X\u0086\u000e¢\u0006\u0010\n\u0000\u001a\u0005\b\u0099\u0001\u0010\"\"\u0005\b\u009a\u0001\u0010$R\u0010\u0010\u009b\u0001\u001a\u00030\u009c\u0001X\u0082\u0004¢\u0006\u0002\n\u0000R!\u0010\u009d\u0001\u001a\u0004\u0018\u00010\u0011X\u0086\u000e¢\u0006\u0012\n\u0002\u0010\u0016\u001a\u0005\b\u009e\u0001\u0010\u0013\"\u0005\b\u009f\u0001\u0010\u0015R)\u0010 \u0001\u001a\f\u0012\u0005\u0012\u00030¢\u0001\u0018\u00010¡\u0001X\u0080\u000e¢\u0006\u0012\n\u0000\u001a\u0006\b£\u0001\u0010¤\u0001\"\u0006\b¥\u0001\u0010¦\u0001R\u001f\u0010§\u0001\u001a\u00020zX\u0086\u000e¢\u0006\u0012\n\u0000\u001a\u0006\b¨\u0001\u0010©\u0001\"\u0006\bª\u0001\u0010«\u0001\u0082\u0002\u0004\n\u0002\b\u0019¨\u0006Â\u0001"}, d2 = {"Lcom/mrousavy/camera/CameraView;", "Landroid/widget/FrameLayout;", "Landroidx/lifecycle/LifecycleOwner;", "context", "Landroid/content/Context;", "frameProcessorThread", "Ljava/util/concurrent/ExecutorService;", "(Landroid/content/Context;Ljava/util/concurrent/ExecutorService;)V", "activeVideoRecording", "Landroidx/camera/video/Recording;", "getActiveVideoRecording$react_native_vision_camera_release", "()Landroidx/camera/video/Recording;", "setActiveVideoRecording$react_native_vision_camera_release", "(Landroidx/camera/video/Recording;)V", "actualFrameProcessorFps", "", "audio", "", "getAudio", "()Ljava/lang/Boolean;", "setAudio", "(Ljava/lang/Boolean;)V", "Ljava/lang/Boolean;", "camera", "Landroidx/camera/core/Camera;", "getCamera$react_native_vision_camera_release", "()Landroidx/camera/core/Camera;", "setCamera$react_native_vision_camera_release", "(Landroidx/camera/core/Camera;)V", "cameraExecutor", "kotlin.jvm.PlatformType", "cameraId", "", "getCameraId", "()Ljava/lang/String;", "setCameraId", "(Ljava/lang/String;)V", "colorSpace", "getColorSpace", "setColorSpace", "coroutineScope", "Lkotlinx/coroutines/CoroutineScope;", "getCoroutineScope$react_native_vision_camera_release", "()Lkotlinx/coroutines/CoroutineScope;", "setCoroutineScope$react_native_vision_camera_release", "(Lkotlinx/coroutines/CoroutineScope;)V", "enableDepthData", "getEnableDepthData", "()Z", "setEnableDepthData", "(Z)V", "enableFrameProcessor", "getEnableFrameProcessor", "setEnableFrameProcessor", "enableHighQualityPhotos", "getEnableHighQualityPhotos", "setEnableHighQualityPhotos", "enablePortraitEffectsMatteDelivery", "getEnablePortraitEffectsMatteDelivery", "setEnablePortraitEffectsMatteDelivery", "value", "enableZoomGesture", "getEnableZoomGesture", "setEnableZoomGesture", "extensionsManager", "Landroidx/camera/extensions/ExtensionsManager;", "fallbackToSnapshot", "getFallbackToSnapshot$react_native_vision_camera_release$annotations", "()V", "getFallbackToSnapshot$react_native_vision_camera_release", "format", "Lcom/facebook/react/bridge/ReadableMap;", "getFormat", "()Lcom/facebook/react/bridge/ReadableMap;", "setFormat", "(Lcom/facebook/react/bridge/ReadableMap;)V", "fps", "", "getFps", "()Ljava/lang/Integer;", "setFps", "(Ljava/lang/Integer;)V", "Ljava/lang/Integer;", "frameProcessorFps", "getFrameProcessorFps", "()D", "setFrameProcessorFps", "(D)V", "frameProcessorPerformanceDataCollector", "Lcom/mrousavy/camera/frameprocessor/FrameProcessorPerformanceDataCollector;", "hdr", "getHdr", "setHdr", "hostLifecycleState", "Landroidx/lifecycle/Lifecycle$State;", "imageAnalysis", "Landroidx/camera/core/ImageAnalysis;", "imageCapture", "Landroidx/camera/core/ImageCapture;", "getImageCapture$react_native_vision_camera_release", "()Landroidx/camera/core/ImageCapture;", "setImageCapture$react_native_vision_camera_release", "(Landroidx/camera/core/ImageCapture;)V", "inputRotation", "getInputRotation", "()I", "isActive", "setActive", "isMounted", "isReadyForNewEvaluation", "lastFrameProcessorCall", "", "lastFrameProcessorPerformanceEvaluation", "lastSuggestedFrameProcessorFps", "lifecycleRegistry", "Landroidx/lifecycle/LifecycleRegistry;", "lowLightBoost", "getLowLightBoost", "setLowLightBoost", "mHybridData", "Lcom/facebook/jni/HybridData;", "maxZoom", "", "minZoom", Device.JsonKeys.ORIENTATION, "getOrientation", "setOrientation", "outputRotation", "getOutputRotation", "photo", "getPhoto", "setPhoto", "preview", "Landroidx/camera/core/Preview;", "previewView", "Landroidx/camera/view/PreviewView;", "getPreviewView$react_native_vision_camera_release$annotations", "getPreviewView$react_native_vision_camera_release", "()Landroidx/camera/view/PreviewView;", "reactContext", "Lcom/facebook/react/bridge/ReactContext;", "getReactContext", "()Lcom/facebook/react/bridge/ReactContext;", "recordVideoExecutor", "getRecordVideoExecutor$react_native_vision_camera_release", "()Ljava/util/concurrent/ExecutorService;", "scaleGestureDetector", "Landroid/view/ScaleGestureDetector;", "scaleGestureListener", "Landroid/view/ScaleGestureDetector$SimpleOnScaleGestureListener;", "takePhotoExecutor", "getTakePhotoExecutor$react_native_vision_camera_release", "torch", "getTorch", "setTorch", "touchEventListener", "Landroid/view/View$OnTouchListener;", "video", "getVideo", "setVideo", "videoCapture", "Landroidx/camera/video/VideoCapture;", "Landroidx/camera/video/Recorder;", "getVideoCapture$react_native_vision_camera_release", "()Landroidx/camera/video/VideoCapture;", "setVideoCapture$react_native_vision_camera_release", "(Landroidx/camera/video/VideoCapture;)V", "zoom", "getZoom", "()F", "setZoom", "(F)V", "configureSession", "", "(Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "evaluateNewPerformanceSamples", "frameProcessorCallback", "frame", "Landroidx/camera/core/ImageProxy;", "getLifecycle", "Landroidx/lifecycle/Lifecycle;", "initHybrid", "onAttachedToWindow", "onConfigurationChanged", "newConfig", "Landroid/content/res/Configuration;", "onDetachedFromWindow", "update", "changedProps", "Ljava/util/ArrayList;", "Lkotlin/collections/ArrayList;", "updateLifecycleState", "updateOrientation", "Companion", "react-native-vision-camera_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes2.dex */
public final class CameraView extends FrameLayout implements LifecycleOwner {
    public static final String TAG = "CameraView";
    public static final String TAG_PERF = "CameraView.performance";
    private Recording activeVideoRecording;
    private double actualFrameProcessorFps;
    private Boolean audio;
    private Camera camera;
    private final ExecutorService cameraExecutor;
    private String cameraId;
    private String colorSpace;
    private CoroutineScope coroutineScope;
    private boolean enableDepthData;
    private boolean enableFrameProcessor;
    private Boolean enableHighQualityPhotos;
    private boolean enablePortraitEffectsMatteDelivery;
    private boolean enableZoomGesture;
    private ExtensionsManager extensionsManager;
    private ReadableMap format;
    private Integer fps;
    private double frameProcessorFps;
    private final FrameProcessorPerformanceDataCollector frameProcessorPerformanceDataCollector;
    private final ExecutorService frameProcessorThread;
    private Boolean hdr;
    private Lifecycle.State hostLifecycleState;
    private ImageAnalysis imageAnalysis;
    private ImageCapture imageCapture;
    private boolean isActive;
    private boolean isMounted;
    private long lastFrameProcessorCall;
    private long lastFrameProcessorPerformanceEvaluation;
    private double lastSuggestedFrameProcessorFps;
    private final LifecycleRegistry lifecycleRegistry;
    private Boolean lowLightBoost;
    private HybridData mHybridData;
    private float maxZoom;
    private float minZoom;
    private String orientation;
    private Boolean photo;
    private Preview preview;
    private final PreviewView previewView;
    private final ExecutorService recordVideoExecutor;
    private final ScaleGestureDetector scaleGestureDetector;
    private final ScaleGestureDetector.SimpleOnScaleGestureListener scaleGestureListener;
    private final ExecutorService takePhotoExecutor;
    private String torch;
    private final View.OnTouchListener touchEventListener;
    private Boolean video;
    private VideoCapture<Recorder> videoCapture;
    private float zoom;
    public static final Companion Companion = new Companion(null);
    private static final ArrayList<String> propsThatRequireSessionReconfiguration = CollectionsKt.arrayListOf("cameraId", "format", "fps", "hdr", "lowLightBoost", "photo", "video", "enableFrameProcessor");
    private static final ArrayList<String> arrayListOfZoom = CollectionsKt.arrayListOf("zoom");

    private final native void frameProcessorCallback(ImageProxy imageProxy);

    public static /* synthetic */ void getFallbackToSnapshot$react_native_vision_camera_release$annotations() {
    }

    public static /* synthetic */ void getPreviewView$react_native_vision_camera_release$annotations() {
    }

    private final native HybridData initHybrid();

    /* compiled from: CameraView.kt */
    @Metadata(d1 = {"\u0000 \n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u000e\u0010\u0003\u001a\u00020\u0004X\u0086T¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0004X\u0086T¢\u0006\u0002\n\u0000R\u001e\u0010\u0006\u001a\u0012\u0012\u0004\u0012\u00020\u00040\u0007j\b\u0012\u0004\u0012\u00020\u0004`\bX\u0082\u0004¢\u0006\u0002\n\u0000R\u001e\u0010\t\u001a\u0012\u0012\u0004\u0012\u00020\u00040\u0007j\b\u0012\u0004\u0012\u00020\u0004`\bX\u0082\u0004¢\u0006\u0002\n\u0000¨\u0006\n"}, d2 = {"Lcom/mrousavy/camera/CameraView$Companion;", "", "()V", "TAG", "", "TAG_PERF", "arrayListOfZoom", "Ljava/util/ArrayList;", "Lkotlin/collections/ArrayList;", "propsThatRequireSessionReconfiguration", "react-native-vision-camera_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }

    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
    public CameraView(Context context, ExecutorService frameProcessorThread) {
        super(context);
        Intrinsics.checkNotNullParameter(context, "context");
        Intrinsics.checkNotNullParameter(frameProcessorThread, "frameProcessorThread");
        this.frameProcessorThread = frameProcessorThread;
        this.torch = DebugKt.DEBUG_PROPERTY_VALUE_OFF;
        this.zoom = 1.0f;
        this.frameProcessorFps = 1.0d;
        this.cameraExecutor = Executors.newSingleThreadExecutor();
        this.takePhotoExecutor = Executors.newSingleThreadExecutor();
        this.recordVideoExecutor = Executors.newSingleThreadExecutor();
        this.coroutineScope = CoroutineScopeKt.CoroutineScope(Dispatchers.getMain());
        this.lastFrameProcessorCall = System.currentTimeMillis();
        this.minZoom = 1.0f;
        this.maxZoom = 1.0f;
        this.actualFrameProcessorFps = 30.0d;
        this.frameProcessorPerformanceDataCollector = new FrameProcessorPerformanceDataCollector();
        this.lastFrameProcessorPerformanceEvaluation = System.currentTimeMillis();
        if (FrameProcessorRuntimeManager.Companion.getEnableFrameProcessors()) {
            this.mHybridData = initHybrid();
        }
        PreviewView previewView = new PreviewView(context);
        this.previewView = previewView;
        previewView.setLayoutParams(new FrameLayout.LayoutParams(-1, -1));
        ViewGroup_installHierarchyFitterKt.installHierarchyFitter(previewView);
        addView(previewView);
        ScaleGestureDetector.SimpleOnScaleGestureListener simpleOnScaleGestureListener = new ScaleGestureDetector.SimpleOnScaleGestureListener() { // from class: com.mrousavy.camera.CameraView.1
            @Override // android.view.ScaleGestureDetector.SimpleOnScaleGestureListener, android.view.ScaleGestureDetector.OnScaleGestureListener
            public boolean onScale(ScaleGestureDetector detector) {
                Intrinsics.checkNotNullParameter(detector, "detector");
                CameraView cameraView = CameraView.this;
                cameraView.setZoom(Math.max(Math.min(cameraView.getZoom() * detector.getScaleFactor(), CameraView.this.maxZoom), CameraView.this.minZoom));
                CameraView.this.update(CameraView.arrayListOfZoom);
                return true;
            }
        };
        this.scaleGestureListener = simpleOnScaleGestureListener;
        this.scaleGestureDetector = new ScaleGestureDetector(context, simpleOnScaleGestureListener);
        this.touchEventListener = new View.OnTouchListener() { // from class: com.mrousavy.camera.CameraView$$ExternalSyntheticLambda0
            @Override // android.view.View.OnTouchListener
            public final boolean onTouch(View view, MotionEvent motionEvent) {
                boolean m410_init_$lambda2;
                m410_init_$lambda2 = CameraView.m410_init_$lambda2(CameraView.this, view, motionEvent);
                return m410_init_$lambda2;
            }
        };
        this.hostLifecycleState = Lifecycle.State.INITIALIZED;
        this.lifecycleRegistry = new LifecycleRegistry(this);
        getReactContext().addLifecycleEventListener(new LifecycleEventListener() { // from class: com.mrousavy.camera.CameraView.3
            @Override // com.facebook.react.bridge.LifecycleEventListener
            public void onHostResume() {
                CameraView.this.hostLifecycleState = Lifecycle.State.RESUMED;
                CameraView.this.updateLifecycleState();
                CameraView.this.update(CameraView.propsThatRequireSessionReconfiguration);
            }

            @Override // com.facebook.react.bridge.LifecycleEventListener
            public void onHostPause() {
                CameraView.this.hostLifecycleState = Lifecycle.State.CREATED;
                CameraView.this.updateLifecycleState();
            }

            @Override // com.facebook.react.bridge.LifecycleEventListener
            public void onHostDestroy() {
                CameraView.this.hostLifecycleState = Lifecycle.State.DESTROYED;
                CameraView.this.updateLifecycleState();
                CameraView.this.cameraExecutor.shutdown();
                CameraView.this.getTakePhotoExecutor$react_native_vision_camera_release().shutdown();
                CameraView.this.getRecordVideoExecutor$react_native_vision_camera_release().shutdown();
                CameraView.this.getReactContext().removeLifecycleEventListener(this);
            }
        });
    }

    public final String getCameraId() {
        return this.cameraId;
    }

    public final void setCameraId(String str) {
        this.cameraId = str;
    }

    public final boolean getEnableDepthData() {
        return this.enableDepthData;
    }

    public final void setEnableDepthData(boolean z) {
        this.enableDepthData = z;
    }

    public final Boolean getEnableHighQualityPhotos() {
        return this.enableHighQualityPhotos;
    }

    public final void setEnableHighQualityPhotos(Boolean bool) {
        this.enableHighQualityPhotos = bool;
    }

    public final boolean getEnablePortraitEffectsMatteDelivery() {
        return this.enablePortraitEffectsMatteDelivery;
    }

    public final void setEnablePortraitEffectsMatteDelivery(boolean z) {
        this.enablePortraitEffectsMatteDelivery = z;
    }

    public final Boolean getPhoto() {
        return this.photo;
    }

    public final void setPhoto(Boolean bool) {
        this.photo = bool;
    }

    public final Boolean getVideo() {
        return this.video;
    }

    public final void setVideo(Boolean bool) {
        this.video = bool;
    }

    public final Boolean getAudio() {
        return this.audio;
    }

    public final void setAudio(Boolean bool) {
        this.audio = bool;
    }

    public final boolean getEnableFrameProcessor() {
        return this.enableFrameProcessor;
    }

    public final void setEnableFrameProcessor(boolean z) {
        this.enableFrameProcessor = z;
    }

    public final ReadableMap getFormat() {
        return this.format;
    }

    public final void setFormat(ReadableMap readableMap) {
        this.format = readableMap;
    }

    public final Integer getFps() {
        return this.fps;
    }

    public final void setFps(Integer num) {
        this.fps = num;
    }

    public final Boolean getHdr() {
        return this.hdr;
    }

    public final void setHdr(Boolean bool) {
        this.hdr = bool;
    }

    public final String getColorSpace() {
        return this.colorSpace;
    }

    public final void setColorSpace(String str) {
        this.colorSpace = str;
    }

    public final Boolean getLowLightBoost() {
        return this.lowLightBoost;
    }

    public final void setLowLightBoost(Boolean bool) {
        this.lowLightBoost = bool;
    }

    public final boolean isActive() {
        return this.isActive;
    }

    public final void setActive(boolean z) {
        this.isActive = z;
    }

    public final String getTorch() {
        return this.torch;
    }

    public final void setTorch(String str) {
        Intrinsics.checkNotNullParameter(str, "<set-?>");
        this.torch = str;
    }

    public final float getZoom() {
        return this.zoom;
    }

    public final void setZoom(float f) {
        this.zoom = f;
    }

    public final String getOrientation() {
        return this.orientation;
    }

    public final void setOrientation(String str) {
        this.orientation = str;
    }

    public final boolean getEnableZoomGesture() {
        return this.enableZoomGesture;
    }

    public final void setEnableZoomGesture(boolean z) {
        this.enableZoomGesture = z;
        setOnTouchListener(z ? this.touchEventListener : null);
    }

    public final double getFrameProcessorFps() {
        return this.frameProcessorFps;
    }

    public final void setFrameProcessorFps(double d) {
        this.frameProcessorFps = d;
        if (d == -1.0d) {
            d = 30.0d;
        }
        this.actualFrameProcessorFps = d;
        this.lastFrameProcessorPerformanceEvaluation = System.currentTimeMillis();
        this.frameProcessorPerformanceDataCollector.clear();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final ReactContext getReactContext() {
        Context context = getContext();
        Intrinsics.checkNotNull(context, "null cannot be cast to non-null type com.facebook.react.bridge.ReactContext");
        return (ReactContext) context;
    }

    public final PreviewView getPreviewView$react_native_vision_camera_release() {
        return this.previewView;
    }

    public final ExecutorService getTakePhotoExecutor$react_native_vision_camera_release() {
        return this.takePhotoExecutor;
    }

    public final ExecutorService getRecordVideoExecutor$react_native_vision_camera_release() {
        return this.recordVideoExecutor;
    }

    public final CoroutineScope getCoroutineScope$react_native_vision_camera_release() {
        return this.coroutineScope;
    }

    public final void setCoroutineScope$react_native_vision_camera_release(CoroutineScope coroutineScope) {
        Intrinsics.checkNotNullParameter(coroutineScope, "<set-?>");
        this.coroutineScope = coroutineScope;
    }

    public final Camera getCamera$react_native_vision_camera_release() {
        return this.camera;
    }

    public final void setCamera$react_native_vision_camera_release(Camera camera) {
        this.camera = camera;
    }

    public final ImageCapture getImageCapture$react_native_vision_camera_release() {
        return this.imageCapture;
    }

    public final void setImageCapture$react_native_vision_camera_release(ImageCapture imageCapture) {
        this.imageCapture = imageCapture;
    }

    public final VideoCapture<Recorder> getVideoCapture$react_native_vision_camera_release() {
        return this.videoCapture;
    }

    public final void setVideoCapture$react_native_vision_camera_release(VideoCapture<Recorder> videoCapture) {
        this.videoCapture = videoCapture;
    }

    public final Recording getActiveVideoRecording$react_native_vision_camera_release() {
        return this.activeVideoRecording;
    }

    public final void setActiveVideoRecording$react_native_vision_camera_release(Recording recording) {
        this.activeVideoRecording = recording;
    }

    private final int getInputRotation() {
        Context context = getContext();
        Intrinsics.checkNotNullExpressionValue(context, "context");
        return Context_displayRotationKt.getDisplayRotation(context);
    }

    private final int getOutputRotation() {
        String str = this.orientation;
        if (str != null) {
            Intrinsics.checkNotNull(str);
            switch (str.hashCode()) {
                case -2022952606:
                    if (str.equals("landscapeLeft")) {
                        return 3;
                    }
                    break;
                case -1090566097:
                    if (str.equals("portraitUpsideDown")) {
                        return 2;
                    }
                    break;
                case 729267099:
                    if (str.equals(DevLauncherOrientation.PORTRAIT)) {
                        return 0;
                    }
                    break;
                case 1718639649:
                    if (str.equals("landscapeRight")) {
                        return 1;
                    }
                    break;
            }
            String str2 = this.orientation;
            Intrinsics.checkNotNull(str2);
            throw new InvalidTypeScriptUnionError(Device.JsonKeys.ORIENTATION, str2);
        }
        return getInputRotation();
    }

    private final boolean isReadyForNewEvaluation() {
        return System.currentTimeMillis() - this.lastFrameProcessorPerformanceEvaluation > 1000;
    }

    public final boolean getFallbackToSnapshot$react_native_vision_camera_release() {
        String str;
        if ((Intrinsics.areEqual((Object) this.video, (Object) true) || this.enableFrameProcessor) && (str = this.cameraId) != null) {
            Object systemService = getReactContext().getSystemService("camera");
            CameraManager cameraManager = systemService instanceof CameraManager ? (CameraManager) systemService : null;
            if (cameraManager != null) {
                CameraCharacteristics cameraCharacteristics = cameraManager.getCameraCharacteristics(str);
                Intrinsics.checkNotNullExpressionValue(cameraCharacteristics, "cameraManger.getCameraCharacteristics(cameraId)");
                Integer num = (Integer) cameraCharacteristics.get(CameraCharacteristics.INFO_SUPPORTED_HARDWARE_LEVEL);
                if (num != null && num.intValue() == 2) {
                    return true;
                }
                return Intrinsics.areEqual((Object) this.video, (Object) true) && this.enableFrameProcessor;
            }
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: _init_$lambda-2  reason: not valid java name */
    public static final boolean m410_init_$lambda2(CameraView this$0, View view, MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        return this$0.scaleGestureDetector.onTouchEvent(motionEvent);
    }

    @Override // android.view.View
    protected void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        updateOrientation();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void updateOrientation() {
        Preview preview = this.preview;
        if (preview != null) {
            preview.setTargetRotation(getInputRotation());
        }
        ImageCapture imageCapture = this.imageCapture;
        if (imageCapture != null) {
            imageCapture.setTargetRotation(getOutputRotation());
        }
        VideoCapture<Recorder> videoCapture = this.videoCapture;
        if (videoCapture != null) {
            videoCapture.setTargetRotation(getOutputRotation());
        }
        ImageAnalysis imageAnalysis = this.imageAnalysis;
        if (imageAnalysis == null) {
            return;
        }
        imageAnalysis.setTargetRotation(getOutputRotation());
    }

    @Override // androidx.lifecycle.LifecycleOwner
    public Lifecycle getLifecycle() {
        return this.lifecycleRegistry;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void updateLifecycleState() {
        Lifecycle.State currentState = this.lifecycleRegistry.getCurrentState();
        Intrinsics.checkNotNullExpressionValue(currentState, "lifecycleRegistry.currentState");
        if (this.hostLifecycleState == Lifecycle.State.RESUMED) {
            if (this.isActive && isAttachedToWindow()) {
                this.lifecycleRegistry.setCurrentState(Lifecycle.State.RESUMED);
            } else {
                this.lifecycleRegistry.setCurrentState(Lifecycle.State.CREATED);
            }
        } else {
            this.lifecycleRegistry.setCurrentState(this.hostLifecycleState);
        }
        Log.d("CameraView", "Lifecycle went from " + currentState.name() + " -> " + this.lifecycleRegistry.getCurrentState().name() + " (isActive: " + this.isActive + " | isAttachedToWindow: " + isAttachedToWindow() + ')');
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onAttachedToWindow() {
        super.onAttachedToWindow();
        updateLifecycleState();
        if (this.isMounted) {
            return;
        }
        this.isMounted = true;
        CameraView_EventsKt.invokeOnViewReady(this);
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        updateLifecycleState();
    }

    public final boolean update(final ArrayList<String> changedProps) {
        Intrinsics.checkNotNullParameter(changedProps, "changedProps");
        return this.previewView.post(new Runnable() { // from class: com.mrousavy.camera.CameraView$$ExternalSyntheticLambda1
            @Override // java.lang.Runnable
            public final void run() {
                CameraView.m412update$lambda3(CameraView.this, changedProps);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: update$lambda-3  reason: not valid java name */
    public static final void m412update$lambda3(CameraView this$0, ArrayList changedProps) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(changedProps, "$changedProps");
        BuildersKt.launch$default(this$0.coroutineScope, null, null, new CameraView$update$1$1(changedProps, this$0, null), 3, null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Not initialized variable reg: 18, insn: 0x0549: MOVE  (r3 I:??[OBJECT, ARRAY]) = (r18 I:??[OBJECT, ARRAY]), block:B:147:0x0549 */
    /* JADX WARN: Removed duplicated region for block: B:10:0x002e  */
    /* JADX WARN: Removed duplicated region for block: B:115:0x03ae A[Catch: all -> 0x0548, TryCatch #0 {all -> 0x0548, blocks: (B:121:0x03e4, B:113:0x03a1, B:115:0x03ae, B:101:0x0330, B:105:0x0358, B:107:0x0365, B:102:0x034b, B:103:0x0352), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:120:0x03dc  */
    /* JADX WARN: Removed duplicated region for block: B:123:0x03ff  */
    /* JADX WARN: Removed duplicated region for block: B:126:0x042a  */
    /* JADX WARN: Removed duplicated region for block: B:129:0x0439 A[Catch: all -> 0x055a, TryCatch #1 {all -> 0x055a, blocks: (B:125:0x0403, B:127:0x042c, B:129:0x0439, B:131:0x043f, B:132:0x0445, B:133:0x0456, B:135:0x045a, B:136:0x0479, B:138:0x04f6, B:140:0x04fd, B:142:0x0514, B:143:0x0518, B:149:0x054d, B:150:0x0552, B:151:0x0553, B:152:0x0559), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:135:0x045a A[Catch: all -> 0x055a, TryCatch #1 {all -> 0x055a, blocks: (B:125:0x0403, B:127:0x042c, B:129:0x0439, B:131:0x043f, B:132:0x0445, B:133:0x0456, B:135:0x045a, B:136:0x0479, B:138:0x04f6, B:140:0x04fd, B:142:0x0514, B:143:0x0518, B:149:0x054d, B:150:0x0552, B:151:0x0553, B:152:0x0559), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:138:0x04f6 A[Catch: all -> 0x055a, TryCatch #1 {all -> 0x055a, blocks: (B:125:0x0403, B:127:0x042c, B:129:0x0439, B:131:0x043f, B:132:0x0445, B:133:0x0456, B:135:0x045a, B:136:0x0479, B:138:0x04f6, B:140:0x04fd, B:142:0x0514, B:143:0x0518, B:149:0x054d, B:150:0x0552, B:151:0x0553, B:152:0x0559), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:139:0x04fb  */
    /* JADX WARN: Removed duplicated region for block: B:142:0x0514 A[Catch: all -> 0x055a, TryCatch #1 {all -> 0x055a, blocks: (B:125:0x0403, B:127:0x042c, B:129:0x0439, B:131:0x043f, B:132:0x0445, B:133:0x0456, B:135:0x045a, B:136:0x0479, B:138:0x04f6, B:140:0x04fd, B:142:0x0514, B:143:0x0518, B:149:0x054d, B:150:0x0552, B:151:0x0553, B:152:0x0559), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:159:0x0577  */
    /* JADX WARN: Removed duplicated region for block: B:169:0x0597  */
    /* JADX WARN: Removed duplicated region for block: B:170:0x059f  */
    /* JADX WARN: Removed duplicated region for block: B:177:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:24:0x0097  */
    /* JADX WARN: Removed duplicated region for block: B:40:0x018b A[Catch: all -> 0x055c, TryCatch #2 {all -> 0x055c, blocks: (B:14:0x0052, B:19:0x0083, B:22:0x0091, B:38:0x0104, B:40:0x018b, B:41:0x01ae, B:43:0x01f3, B:45:0x0202, B:52:0x022f, B:85:0x02ad, B:87:0x02b1, B:89:0x02c1, B:99:0x02eb, B:92:0x02cc, B:93:0x02d0, B:95:0x02d6, B:60:0x0247, B:68:0x0264, B:76:0x0281, B:84:0x029e, B:44:0x01fb, B:25:0x009a, B:27:0x00af, B:29:0x00b3, B:32:0x00b9, B:34:0x00e6, B:33:0x00d0), top: B:174:0x002c }] */
    /* JADX WARN: Removed duplicated region for block: B:41:0x01ae A[Catch: all -> 0x055c, TryCatch #2 {all -> 0x055c, blocks: (B:14:0x0052, B:19:0x0083, B:22:0x0091, B:38:0x0104, B:40:0x018b, B:41:0x01ae, B:43:0x01f3, B:45:0x0202, B:52:0x022f, B:85:0x02ad, B:87:0x02b1, B:89:0x02c1, B:99:0x02eb, B:92:0x02cc, B:93:0x02d0, B:95:0x02d6, B:60:0x0247, B:68:0x0264, B:76:0x0281, B:84:0x029e, B:44:0x01fb, B:25:0x009a, B:27:0x00af, B:29:0x00b3, B:32:0x00b9, B:34:0x00e6, B:33:0x00d0), top: B:174:0x002c }] */
    /* JADX WARN: Type inference failed for: r0v28, types: [androidx.camera.core.CameraSelector, T, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r1v33 */
    /* JADX WARN: Type inference failed for: r1v36 */
    /* JADX WARN: Type inference failed for: r1v41, types: [androidx.camera.core.ImageAnalysis, androidx.camera.core.ImageCapture, androidx.camera.video.VideoCapture<androidx.camera.video.Recorder>] */
    /* JADX WARN: Type inference failed for: r1v54 */
    /* JADX WARN: Type inference failed for: r3v2, types: [kotlin.coroutines.Continuation, com.mrousavy.camera.CameraView$configureSession$1, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r3v21 */
    /* JADX WARN: Type inference failed for: r3v22 */
    /* JADX WARN: Type inference failed for: r3v3 */
    /* JADX WARN: Type inference failed for: r3v6 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final Object configureSession(Continuation<? super Unit> continuation) {
        String str;
        int i;
        boolean z;
        InvalidCameraDeviceError invalidCameraDeviceError;
        Object obj;
        final CameraView cameraView;
        long j;
        ProcessCameraProvider processCameraProvider;
        Ref.ObjectRef objectRef;
        CameraView$configureSession$tryEnableExtension$1 cameraView$configureSession$tryEnableExtension$1;
        Preview.Builder targetRotation;
        ImageCapture.Builder captureMode;
        Recorder.Builder executor;
        ImageAnalysis.Builder backgroundExecutor;
        ReadableMap readableMap;
        ImageAnalysis.Builder builder;
        String str2;
        long j2;
        Object obj2;
        Recorder.Builder builder2;
        ImageCapture.Builder builder3;
        Preview.Builder builder4;
        Ref.ObjectRef objectRef2;
        ProcessCameraProvider processCameraProvider2;
        ImageAnalysis.Builder builder5;
        long j3;
        long j4;
        boolean z2;
        ?? r1;
        Recorder.Builder builder6;
        CameraView cameraView2;
        String str3;
        try {
            try {
                try {
                    if (continuation instanceof CameraView$configureSession$1) {
                        CameraView$configureSession$1 cameraView$configureSession$1 = (CameraView$configureSession$1) continuation;
                        if ((cameraView$configureSession$1.label & Integer.MIN_VALUE) != 0) {
                            cameraView$configureSession$1.label -= Integer.MIN_VALUE;
                            str = cameraView$configureSession$1;
                            Object obj3 = str.result;
                            Object coroutine_suspended = IntrinsicsKt.getCOROUTINE_SUSPENDED();
                            i = str.label;
                            if (i != 0) {
                                ResultKt.throwOnFailure(obj3);
                                long currentTimeMillis = System.currentTimeMillis();
                                Log.i("CameraView", "Configuring session...");
                                if (ContextCompat.checkSelfPermission(getContext(), "android.permission.CAMERA") != 0) {
                                    throw new CameraPermissionError();
                                }
                                if (this.cameraId == null) {
                                    throw new NoCameraDeviceError();
                                }
                                if (this.format != null) {
                                    Log.i("CameraView", "Configuring session with Camera ID " + this.cameraId + " and custom format...");
                                } else {
                                    Log.i("CameraView", "Configuring session with Camera ID " + this.cameraId + " and default format options...");
                                }
                                ListenableFuture<ProcessCameraProvider> processCameraProvider3 = ProcessCameraProvider.getInstance(getReactContext());
                                Intrinsics.checkNotNullExpressionValue(processCameraProvider3, "getInstance(reactContext)");
                                str.L$0 = this;
                                str.J$0 = currentTimeMillis;
                                str.label = 1;
                                obj3 = ListenableFutureKt.await(processCameraProvider3, str);
                                if (obj3 == coroutine_suspended) {
                                    return coroutine_suspended;
                                }
                                cameraView = this;
                                j = currentTimeMillis;
                            } else if (i != 1) {
                                if (i != 2) {
                                    if (i == 3) {
                                        j3 = str.J$0;
                                        builder5 = (ImageAnalysis.Builder) str.L$6;
                                        builder6 = (Recorder.Builder) str.L$5;
                                        builder3 = (ImageCapture.Builder) str.L$4;
                                        builder4 = (Preview.Builder) str.L$3;
                                        objectRef2 = (Ref.ObjectRef) str.L$2;
                                        processCameraProvider2 = (ProcessCameraProvider) str.L$1;
                                        cameraView2 = (CameraView) str.L$0;
                                        ResultKt.throwOnFailure(obj3);
                                        str2 = "CameraView";
                                        backgroundExecutor = builder5;
                                        cameraView = cameraView2;
                                        objectRef = objectRef2;
                                        processCameraProvider = processCameraProvider2;
                                        r1 = 0;
                                        captureMode = builder3;
                                        targetRotation = builder4;
                                        j = j3;
                                        executor = builder6;
                                        cameraView.videoCapture = r1;
                                        cameraView.imageCapture = r1;
                                        cameraView.imageAnalysis = r1;
                                        processCameraProvider.unbindAll();
                                        ArrayList arrayList = new ArrayList();
                                        if (Intrinsics.areEqual(cameraView.video, Boxing.boxBoolean(true))) {
                                            str3 = str2;
                                        } else {
                                            str3 = str2;
                                            Log.i(str3, "Adding VideoCapture use-case...");
                                            Recorder build = executor.build();
                                            Intrinsics.checkNotNullExpressionValue(build, "videoRecorderBuilder.build()");
                                            VideoCapture<Recorder> withOutput = VideoCapture.withOutput(build);
                                            cameraView.videoCapture = withOutput;
                                            Intrinsics.checkNotNull(withOutput);
                                            withOutput.setTargetRotation(cameraView.getOutputRotation());
                                            VideoCapture<Recorder> videoCapture = cameraView.videoCapture;
                                            Intrinsics.checkNotNull(videoCapture);
                                            arrayList.add(videoCapture);
                                        }
                                        if (Intrinsics.areEqual(cameraView.photo, Boxing.boxBoolean(true))) {
                                            if (cameraView.getFallbackToSnapshot$react_native_vision_camera_release()) {
                                                Log.i(str3, "Tried to add photo use-case (`photo={true}`) but the Camera device only supports a single use-case at a time. Falling back to Snapshot capture.");
                                            } else {
                                                Log.i(str3, "Adding ImageCapture use-case...");
                                                ImageCapture build2 = captureMode.build();
                                                cameraView.imageCapture = build2;
                                                Intrinsics.checkNotNull(build2);
                                                arrayList.add(build2);
                                            }
                                        }
                                        if (cameraView.enableFrameProcessor) {
                                            Log.i(str3, "Adding ImageAnalysis use-case...");
                                            ImageAnalysis build3 = backgroundExecutor.build();
                                            build3.setAnalyzer(cameraView.cameraExecutor, new ImageAnalysis.Analyzer() { // from class: com.mrousavy.camera.CameraView$$ExternalSyntheticLambda2
                                                @Override // androidx.camera.core.ImageAnalysis.Analyzer
                                                public final void analyze(ImageProxy imageProxy) {
                                                    CameraView.m411configureSession$lambda7$lambda6(CameraView.this, imageProxy);
                                                }

                                                @Override // androidx.camera.core.ImageAnalysis.Analyzer
                                                public /* synthetic */ int getTargetCoordinateSystem() {
                                                    return ImageAnalysis.Analyzer.CC.$default$getTargetCoordinateSystem(this);
                                                }

                                                @Override // androidx.camera.core.ImageAnalysis.Analyzer
                                                public /* synthetic */ Size getTargetResolutionOverride() {
                                                    return ImageAnalysis.Analyzer.CC.$default$getTargetResolutionOverride(this);
                                                }

                                                @Override // androidx.camera.core.ImageAnalysis.Analyzer
                                                public /* synthetic */ void updateTransform(Matrix matrix) {
                                                    ImageAnalysis.Analyzer.CC.$default$updateTransform(this, matrix);
                                                }
                                            });
                                            Unit unit = Unit.INSTANCE;
                                            cameraView.imageAnalysis = build3;
                                            Intrinsics.checkNotNull(build3);
                                            arrayList.add(build3);
                                        }
                                        cameraView.preview = targetRotation.build();
                                        Log.i(str3, "Attaching " + arrayList.size() + " use-cases...");
                                        SpreadBuilder spreadBuilder = new SpreadBuilder(2);
                                        spreadBuilder.add(cameraView.preview);
                                        Object[] array = arrayList.toArray(new UseCase[0]);
                                        Intrinsics.checkNotNull(array, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
                                        spreadBuilder.addSpread(array);
                                        cameraView.camera = processCameraProvider.bindToLifecycle(cameraView, (CameraSelector) objectRef.element, (UseCase[]) spreadBuilder.toArray(new UseCase[spreadBuilder.size()]));
                                        Preview preview = cameraView.preview;
                                        Intrinsics.checkNotNull(preview);
                                        preview.setSurfaceProvider(cameraView.previewView.getSurfaceProvider());
                                        Camera camera = cameraView.camera;
                                        Intrinsics.checkNotNull(camera);
                                        ZoomState value = camera.getCameraInfo().getZoomState().getValue();
                                        cameraView.minZoom = value == null ? value.getMinZoomRatio() : 1.0f;
                                        Camera camera2 = cameraView.camera;
                                        Intrinsics.checkNotNull(camera2);
                                        ZoomState value2 = camera2.getCameraInfo().getZoomState().getValue();
                                        cameraView.maxZoom = value2 != null ? value2.getMaxZoomRatio() : 1.0f;
                                        StringBuilder sb = new StringBuilder();
                                        sb.append("Session configured in ");
                                        sb.append(System.currentTimeMillis() - j);
                                        sb.append(" ms! Camera: ");
                                        Camera camera3 = cameraView.camera;
                                        Intrinsics.checkNotNull(camera3);
                                        sb.append(camera3);
                                        Log.i(TAG_PERF, sb.toString());
                                        CameraView_EventsKt.invokeOnInitialized(cameraView);
                                        return Unit.INSTANCE;
                                    }
                                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                                }
                                j4 = str.J$0;
                                builder5 = (ImageAnalysis.Builder) str.L$7;
                                executor = (Recorder.Builder) str.L$6;
                                captureMode = (ImageCapture.Builder) str.L$5;
                                targetRotation = (Preview.Builder) str.L$4;
                                cameraView$configureSession$tryEnableExtension$1 = (Function2) str.L$3;
                                objectRef = (Ref.ObjectRef) str.L$2;
                                processCameraProvider = (ProcessCameraProvider) str.L$1;
                                cameraView = (CameraView) str.L$0;
                                ResultKt.throwOnFailure(obj3);
                                str2 = "CameraView";
                                obj2 = coroutine_suspended;
                                builder2 = executor;
                                j3 = j4;
                                builder3 = captureMode;
                                builder4 = targetRotation;
                                objectRef2 = objectRef;
                                processCameraProvider2 = processCameraProvider;
                                if (Intrinsics.areEqual(cameraView.lowLightBoost, Boxing.boxBoolean(true))) {
                                    Integer boxInt = Boxing.boxInt(3);
                                    str.L$0 = cameraView;
                                    str.L$1 = processCameraProvider2;
                                    str.L$2 = objectRef2;
                                    str.L$3 = builder4;
                                    str.L$4 = builder3;
                                    str.L$5 = builder2;
                                    str.L$6 = builder5;
                                    str.L$7 = null;
                                    str.J$0 = j3;
                                    str.label = 3;
                                    if (cameraView$configureSession$tryEnableExtension$1.invoke(boxInt, str) == obj2) {
                                        return obj2;
                                    }
                                    builder6 = builder2;
                                    cameraView2 = cameraView;
                                    backgroundExecutor = builder5;
                                    cameraView = cameraView2;
                                    objectRef = objectRef2;
                                    processCameraProvider = processCameraProvider2;
                                    r1 = 0;
                                    captureMode = builder3;
                                    targetRotation = builder4;
                                    j = j3;
                                    executor = builder6;
                                    cameraView.videoCapture = r1;
                                    cameraView.imageCapture = r1;
                                    cameraView.imageAnalysis = r1;
                                    processCameraProvider.unbindAll();
                                    ArrayList arrayList2 = new ArrayList();
                                    if (Intrinsics.areEqual(cameraView.video, Boxing.boxBoolean(true))) {
                                    }
                                    if (Intrinsics.areEqual(cameraView.photo, Boxing.boxBoolean(true))) {
                                    }
                                    if (cameraView.enableFrameProcessor) {
                                    }
                                    cameraView.preview = targetRotation.build();
                                    Log.i(str3, "Attaching " + arrayList2.size() + " use-cases...");
                                    SpreadBuilder spreadBuilder2 = new SpreadBuilder(2);
                                    spreadBuilder2.add(cameraView.preview);
                                    Object[] array2 = arrayList2.toArray(new UseCase[0]);
                                    Intrinsics.checkNotNull(array2, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
                                    spreadBuilder2.addSpread(array2);
                                    cameraView.camera = processCameraProvider.bindToLifecycle(cameraView, (CameraSelector) objectRef.element, (UseCase[]) spreadBuilder2.toArray(new UseCase[spreadBuilder2.size()]));
                                    Preview preview2 = cameraView.preview;
                                    Intrinsics.checkNotNull(preview2);
                                    preview2.setSurfaceProvider(cameraView.previewView.getSurfaceProvider());
                                    Camera camera4 = cameraView.camera;
                                    Intrinsics.checkNotNull(camera4);
                                    ZoomState value3 = camera4.getCameraInfo().getZoomState().getValue();
                                    cameraView.minZoom = value3 == null ? value3.getMinZoomRatio() : 1.0f;
                                    Camera camera22 = cameraView.camera;
                                    Intrinsics.checkNotNull(camera22);
                                    ZoomState value22 = camera22.getCameraInfo().getZoomState().getValue();
                                    cameraView.maxZoom = value22 != null ? value22.getMaxZoomRatio() : 1.0f;
                                    StringBuilder sb2 = new StringBuilder();
                                    sb2.append("Session configured in ");
                                    sb2.append(System.currentTimeMillis() - j);
                                    sb2.append(" ms! Camera: ");
                                    Camera camera32 = cameraView.camera;
                                    Intrinsics.checkNotNull(camera32);
                                    sb2.append(camera32);
                                    Log.i(TAG_PERF, sb2.toString());
                                    CameraView_EventsKt.invokeOnInitialized(cameraView);
                                    return Unit.INSTANCE;
                                }
                                objectRef = objectRef2;
                                processCameraProvider = processCameraProvider2;
                                r1 = 0;
                                captureMode = builder3;
                                targetRotation = builder4;
                                j = j3;
                                executor = builder2;
                                backgroundExecutor = builder5;
                                cameraView.videoCapture = r1;
                                cameraView.imageCapture = r1;
                                cameraView.imageAnalysis = r1;
                                processCameraProvider.unbindAll();
                                ArrayList arrayList22 = new ArrayList();
                                if (Intrinsics.areEqual(cameraView.video, Boxing.boxBoolean(true))) {
                                }
                                if (Intrinsics.areEqual(cameraView.photo, Boxing.boxBoolean(true))) {
                                }
                                if (cameraView.enableFrameProcessor) {
                                }
                                cameraView.preview = targetRotation.build();
                                Log.i(str3, "Attaching " + arrayList22.size() + " use-cases...");
                                SpreadBuilder spreadBuilder22 = new SpreadBuilder(2);
                                spreadBuilder22.add(cameraView.preview);
                                Object[] array22 = arrayList22.toArray(new UseCase[0]);
                                Intrinsics.checkNotNull(array22, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
                                spreadBuilder22.addSpread(array22);
                                cameraView.camera = processCameraProvider.bindToLifecycle(cameraView, (CameraSelector) objectRef.element, (UseCase[]) spreadBuilder22.toArray(new UseCase[spreadBuilder22.size()]));
                                Preview preview22 = cameraView.preview;
                                Intrinsics.checkNotNull(preview22);
                                preview22.setSurfaceProvider(cameraView.previewView.getSurfaceProvider());
                                Camera camera42 = cameraView.camera;
                                Intrinsics.checkNotNull(camera42);
                                ZoomState value32 = camera42.getCameraInfo().getZoomState().getValue();
                                cameraView.minZoom = value32 == null ? value32.getMinZoomRatio() : 1.0f;
                                Camera camera222 = cameraView.camera;
                                Intrinsics.checkNotNull(camera222);
                                ZoomState value222 = camera222.getCameraInfo().getZoomState().getValue();
                                cameraView.maxZoom = value222 != null ? value222.getMaxZoomRatio() : 1.0f;
                                StringBuilder sb22 = new StringBuilder();
                                sb22.append("Session configured in ");
                                sb22.append(System.currentTimeMillis() - j);
                                sb22.append(" ms! Camera: ");
                                Camera camera322 = cameraView.camera;
                                Intrinsics.checkNotNull(camera322);
                                sb22.append(camera322);
                                Log.i(TAG_PERF, sb22.toString());
                                CameraView_EventsKt.invokeOnInitialized(cameraView);
                                return Unit.INSTANCE;
                            } else {
                                long j5 = str.J$0;
                                CameraView cameraView3 = (CameraView) str.L$0;
                                ResultKt.throwOnFailure(obj3);
                                j = j5;
                                cameraView = cameraView3;
                            }
                            processCameraProvider = (ProcessCameraProvider) obj3;
                            objectRef = new Ref.ObjectRef();
                            CameraSelector.Builder builder7 = new CameraSelector.Builder();
                            String str4 = cameraView.cameraId;
                            Intrinsics.checkNotNull(str4);
                            ?? build4 = CameraSelector_byIDKt.byID(builder7, str4).build();
                            Intrinsics.checkNotNullExpressionValue(build4, "Builder().byID(cameraId!!).build()");
                            objectRef.element = build4;
                            cameraView$configureSession$tryEnableExtension$1 = new CameraView$configureSession$tryEnableExtension$1(cameraView, processCameraProvider, objectRef, null);
                            targetRotation = new Preview.Builder().setTargetRotation(cameraView.getInputRotation());
                            Intrinsics.checkNotNullExpressionValue(targetRotation, "Builder()\n        .setTa…etRotation(inputRotation)");
                            captureMode = new ImageCapture.Builder().setTargetRotation(cameraView.getOutputRotation()).setCaptureMode(1);
                            Intrinsics.checkNotNullExpressionValue(captureMode, "Builder()\n        .setTa…RE_MODE_MINIMIZE_LATENCY)");
                            executor = new Recorder.Builder().setExecutor(cameraView.cameraExecutor);
                            Intrinsics.checkNotNullExpressionValue(executor, "Builder()\n        .setExecutor(cameraExecutor)");
                            backgroundExecutor = new ImageAnalysis.Builder().setTargetRotation(cameraView.getOutputRotation()).setBackpressureStrategy(0).setBackgroundExecutor((Executor) cameraView.frameProcessorThread);
                            Intrinsics.checkNotNullExpressionValue(backgroundExecutor, "Builder()\n        .setTa…tor(frameProcessorThread)");
                            readableMap = cameraView.format;
                            if (readableMap != null) {
                                Log.i("CameraView", "No custom format has been set, CameraX will automatically determine best configuration...");
                                int aspectRatio = AspectRatioKt.aspectRatio(cameraView.previewView.getHeight(), cameraView.previewView.getWidth());
                                targetRotation.setTargetAspectRatio(aspectRatio);
                                captureMode.setTargetAspectRatio(aspectRatio);
                                backgroundExecutor.setTargetAspectRatio(aspectRatio);
                                str2 = "CameraView";
                                r1 = 0;
                                cameraView.videoCapture = r1;
                                cameraView.imageCapture = r1;
                                cameraView.imageAnalysis = r1;
                                processCameraProvider.unbindAll();
                                ArrayList arrayList222 = new ArrayList();
                                if (Intrinsics.areEqual(cameraView.video, Boxing.boxBoolean(true))) {
                                }
                                if (Intrinsics.areEqual(cameraView.photo, Boxing.boxBoolean(true))) {
                                }
                                if (cameraView.enableFrameProcessor) {
                                }
                                cameraView.preview = targetRotation.build();
                                Log.i(str3, "Attaching " + arrayList222.size() + " use-cases...");
                                SpreadBuilder spreadBuilder222 = new SpreadBuilder(2);
                                spreadBuilder222.add(cameraView.preview);
                                Object[] array222 = arrayList222.toArray(new UseCase[0]);
                                Intrinsics.checkNotNull(array222, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
                                spreadBuilder222.addSpread(array222);
                                cameraView.camera = processCameraProvider.bindToLifecycle(cameraView, (CameraSelector) objectRef.element, (UseCase[]) spreadBuilder222.toArray(new UseCase[spreadBuilder222.size()]));
                                Preview preview222 = cameraView.preview;
                                Intrinsics.checkNotNull(preview222);
                                preview222.setSurfaceProvider(cameraView.previewView.getSurfaceProvider());
                                Camera camera422 = cameraView.camera;
                                Intrinsics.checkNotNull(camera422);
                                ZoomState value322 = camera422.getCameraInfo().getZoomState().getValue();
                                cameraView.minZoom = value322 == null ? value322.getMinZoomRatio() : 1.0f;
                                Camera camera2222 = cameraView.camera;
                                Intrinsics.checkNotNull(camera2222);
                                ZoomState value2222 = camera2222.getCameraInfo().getZoomState().getValue();
                                cameraView.maxZoom = value2222 != null ? value2222.getMaxZoomRatio() : 1.0f;
                                StringBuilder sb222 = new StringBuilder();
                                sb222.append("Session configured in ");
                                sb222.append(System.currentTimeMillis() - j);
                                sb222.append(" ms! Camera: ");
                                Camera camera3222 = cameraView.camera;
                                Intrinsics.checkNotNull(camera3222);
                                sb222.append(camera3222);
                                Log.i(TAG_PERF, sb222.toString());
                                CameraView_EventsKt.invokeOnInitialized(cameraView);
                                return Unit.INSTANCE;
                            }
                            Intrinsics.checkNotNull(readableMap);
                            DeviceFormat deviceFormat = new DeviceFormat(readableMap);
                            Log.i("CameraView", "Using custom format - photo: " + deviceFormat.getPhotoSize() + ", video: " + deviceFormat.getVideoSize() + " @ " + cameraView.fps + " FPS");
                            if (Intrinsics.areEqual(cameraView.video, Boxing.boxBoolean(true))) {
                                targetRotation.setTargetResolution(deviceFormat.getVideoSize());
                            } else {
                                targetRotation.setTargetResolution(deviceFormat.getPhotoSize());
                            }
                            captureMode.setTargetResolution(deviceFormat.getPhotoSize());
                            backgroundExecutor.setTargetResolution(deviceFormat.getPhotoSize());
                            int min = Math.min(deviceFormat.getVideoSize().getHeight(), deviceFormat.getVideoSize().getWidth());
                            if (min >= 0 && min < 481) {
                                executor.setQualitySelector(QualitySelector.from(Quality.SD));
                            } else {
                                if (480 <= min && min < 721) {
                                    executor.setQualitySelector(QualitySelector.from(Quality.HD, FallbackStrategy.lowerQualityThan(Quality.HD)));
                                } else {
                                    if (720 <= min && min < 1081) {
                                        executor.setQualitySelector(QualitySelector.from(Quality.FHD, FallbackStrategy.lowerQualityThan(Quality.FHD)));
                                    } else {
                                        if (1080 <= min && min < 2161) {
                                            executor.setQualitySelector(QualitySelector.from(Quality.UHD, FallbackStrategy.lowerQualityThan(Quality.UHD)));
                                        } else {
                                            if (2160 <= min && min < 4321) {
                                                executor.setQualitySelector(QualitySelector.from(Quality.HIGHEST, FallbackStrategy.lowerQualityThan(Quality.HIGHEST)));
                                            }
                                        }
                                    }
                                }
                            }
                            Integer num = cameraView.fps;
                            if (num != null) {
                                int intValue = num.intValue();
                                List<Range<Integer>> frameRateRanges = deviceFormat.getFrameRateRanges();
                                if (!(frameRateRanges instanceof Collection) || !frameRateRanges.isEmpty()) {
                                    Iterator<T> it = frameRateRanges.iterator();
                                    while (it.hasNext()) {
                                        if (((Range) it.next()).contains((Range) Boxing.boxInt(intValue))) {
                                            z2 = true;
                                            break;
                                        }
                                    }
                                }
                                z2 = false;
                                if (z2) {
                                    j2 = j;
                                    builder = backgroundExecutor;
                                    long j6 = ((long) (1.0d / intValue)) * 1000000000;
                                    Log.i("CameraView", "Setting AE_TARGET_FPS_RANGE to " + intValue + '-' + intValue + ", and SENSOR_FRAME_DURATION to " + j6);
                                    str2 = "CameraView";
                                    new Camera2Interop.Extender(targetRotation).setCaptureRequestOption(CaptureRequest.CONTROL_AE_TARGET_FPS_RANGE, new Range(Boxing.boxInt(intValue), Boxing.boxInt(intValue))).setCaptureRequestOption(CaptureRequest.SENSOR_FRAME_DURATION, Boxing.boxLong(j6));
                                } else {
                                    throw new FpsNotContainedInFormatError(intValue);
                                }
                            } else {
                                builder = backgroundExecutor;
                                str2 = "CameraView";
                                j2 = j;
                            }
                            if (Intrinsics.areEqual(cameraView.hdr, Boxing.boxBoolean(true))) {
                                Integer boxInt2 = Boxing.boxInt(2);
                                str.L$0 = cameraView;
                                str.L$1 = processCameraProvider;
                                str.L$2 = objectRef;
                                str.L$3 = cameraView$configureSession$tryEnableExtension$1;
                                str.L$4 = targetRotation;
                                str.L$5 = captureMode;
                                str.L$6 = executor;
                                str.L$7 = builder;
                                long j7 = j2;
                                str.J$0 = j7;
                                str.label = 2;
                                obj2 = coroutine_suspended;
                                if (cameraView$configureSession$tryEnableExtension$1.invoke((CameraView$configureSession$tryEnableExtension$1) boxInt2, (Integer) str) == obj2) {
                                    return obj2;
                                }
                                j4 = j7;
                                builder5 = builder;
                                builder2 = executor;
                                j3 = j4;
                                builder3 = captureMode;
                                builder4 = targetRotation;
                                objectRef2 = objectRef;
                                processCameraProvider2 = processCameraProvider;
                                if (Intrinsics.areEqual(cameraView.lowLightBoost, Boxing.boxBoolean(true))) {
                                }
                            } else {
                                obj2 = coroutine_suspended;
                                builder2 = executor;
                                builder3 = captureMode;
                                builder4 = targetRotation;
                                objectRef2 = objectRef;
                                processCameraProvider2 = processCameraProvider;
                                builder5 = builder;
                                j3 = j2;
                                if (Intrinsics.areEqual(cameraView.lowLightBoost, Boxing.boxBoolean(true))) {
                                }
                            }
                        }
                    }
                    if (i != 0) {
                    }
                    processCameraProvider = (ProcessCameraProvider) obj3;
                    objectRef = new Ref.ObjectRef();
                    CameraSelector.Builder builder72 = new CameraSelector.Builder();
                    String str42 = cameraView.cameraId;
                    Intrinsics.checkNotNull(str42);
                    ?? build42 = CameraSelector_byIDKt.byID(builder72, str42).build();
                    Intrinsics.checkNotNullExpressionValue(build42, "Builder().byID(cameraId!!).build()");
                    objectRef.element = build42;
                    cameraView$configureSession$tryEnableExtension$1 = new CameraView$configureSession$tryEnableExtension$1(cameraView, processCameraProvider, objectRef, null);
                    targetRotation = new Preview.Builder().setTargetRotation(cameraView.getInputRotation());
                    Intrinsics.checkNotNullExpressionValue(targetRotation, "Builder()\n        .setTa…etRotation(inputRotation)");
                    captureMode = new ImageCapture.Builder().setTargetRotation(cameraView.getOutputRotation()).setCaptureMode(1);
                    Intrinsics.checkNotNullExpressionValue(captureMode, "Builder()\n        .setTa…RE_MODE_MINIMIZE_LATENCY)");
                    executor = new Recorder.Builder().setExecutor(cameraView.cameraExecutor);
                    Intrinsics.checkNotNullExpressionValue(executor, "Builder()\n        .setExecutor(cameraExecutor)");
                    backgroundExecutor = new ImageAnalysis.Builder().setTargetRotation(cameraView.getOutputRotation()).setBackpressureStrategy(0).setBackgroundExecutor((Executor) cameraView.frameProcessorThread);
                    Intrinsics.checkNotNullExpressionValue(backgroundExecutor, "Builder()\n        .setTa…tor(frameProcessorThread)");
                    readableMap = cameraView.format;
                    if (readableMap != null) {
                    }
                } catch (Throwable th) {
                    th = th;
                    str = obj;
                    Log.e(str, "Failed to configure session: " + th.getMessage());
                    if (th instanceof CameraError) {
                        throw th;
                    }
                    if (th instanceof IllegalArgumentException) {
                        String message = th.getMessage();
                        if (message != null && StringsKt.contains$default((CharSequence) message, (CharSequence) "too many use cases", false, 2, (Object) null)) {
                            z = true;
                            if (!z) {
                                invalidCameraDeviceError = new ParallelVideoProcessingNotSupportedError(th);
                            } else {
                                invalidCameraDeviceError = new InvalidCameraDeviceError(th);
                            }
                            throw invalidCameraDeviceError;
                        }
                        z = false;
                        if (!z) {
                        }
                        throw invalidCameraDeviceError;
                    }
                    throw new UnknownCameraError(th);
                }
            } catch (Throwable th2) {
                th = th2;
                Log.e(str, "Failed to configure session: " + th.getMessage());
                if (th instanceof CameraError) {
                }
            }
        } catch (Throwable th3) {
            th = th3;
            str = "CameraView";
            Log.e(str, "Failed to configure session: " + th.getMessage());
            if (th instanceof CameraError) {
            }
        }
        str = new CameraView$configureSession$1(this, continuation);
        Object obj32 = str.result;
        Object coroutine_suspended2 = IntrinsicsKt.getCOROUTINE_SUSPENDED();
        i = str.label;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: configureSession$lambda-7$lambda-6  reason: not valid java name */
    public static final void m411configureSession$lambda7$lambda6(CameraView this$0, ImageProxy image) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(image, "image");
        long currentTimeMillis = System.currentTimeMillis();
        if (currentTimeMillis - this$0.lastFrameProcessorCall > (1.0d / this$0.actualFrameProcessorFps) * 1000.0d) {
            this$0.lastFrameProcessorCall = currentTimeMillis;
            PerformanceSampleCollection beginPerformanceSampleCollection = this$0.frameProcessorPerformanceDataCollector.beginPerformanceSampleCollection();
            this$0.frameProcessorCallback(image);
            beginPerformanceSampleCollection.getEndPerformanceSampleCollection().invoke();
        }
        image.close();
        if (this$0.isReadyForNewEvaluation()) {
            this$0.evaluateNewPerformanceSamples();
        }
    }

    private final void evaluateNewPerformanceSamples() {
        this.lastFrameProcessorPerformanceEvaluation = System.currentTimeMillis();
        double floor = Math.floor(Math.min(1.0d / this.frameProcessorPerformanceDataCollector.getAverageExecutionTimeSeconds(), 30));
        double d = this.frameProcessorFps;
        if (d == -1.0d) {
            this.actualFrameProcessorFps = floor;
            return;
        }
        if (floor == this.lastSuggestedFrameProcessorFps) {
            return;
        }
        if (floor == d) {
            return;
        }
        CameraView_EventsKt.invokeOnFrameProcessorPerformanceSuggestionAvailable(this, d, floor);
        this.lastSuggestedFrameProcessorFps = floor;
    }
}
