package expo.modules.image;

import android.app.Activity;
import android.content.Context;
import android.graphics.Rect;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Handler;
import android.view.View;
import android.view.ViewPropertyAnimator;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.core.view.AccessibilityDelegateCompat;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import com.bumptech.glide.Glide;
import com.bumptech.glide.RequestBuilder;
import com.bumptech.glide.RequestManager;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.load.resource.bitmap.DownsampleStrategy;
import com.bumptech.glide.request.BaseRequestOptions;
import com.bumptech.glide.request.RequestOptions;
import com.facebook.react.uimanager.ViewProps;
import com.facebook.react.uimanager.events.TouchesHelper;
import com.google.firebase.analytics.FirebaseAnalytics;
import expo.modules.image.enums.ContentFit;
import expo.modules.image.enums.Priority;
import expo.modules.image.events.GlideRequestListener;
import expo.modules.image.events.OkHttpProgressListener;
import expo.modules.image.okhttp.GlideUrlWrapper;
import expo.modules.image.records.CachePolicy;
import expo.modules.image.records.ContentPosition;
import expo.modules.image.records.ImageErrorEvent;
import expo.modules.image.records.ImageLoadEvent;
import expo.modules.image.records.ImageProgressEvent;
import expo.modules.image.records.ImageTransition;
import expo.modules.image.records.SourceMap;
import expo.modules.image.svg.SVGSoftwareLayerSetter;
import expo.modules.kotlin.AppContext;
import expo.modules.kotlin.viewevent.ViewEventCallback;
import expo.modules.kotlin.viewevent.ViewEventDelegate;
import expo.modules.kotlin.views.ExpoView;
import io.sentry.protocol.SentryThread;
import io.sentry.protocol.ViewHierarchyNode;
import java.lang.ref.WeakReference;
import java.util.List;
import jp.wasabeef.glide.transformations.BlurTransformation;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PropertyReference1Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KProperty;
/* compiled from: ExpoImageViewWrapper.kt */
@Metadata(d1 = {"\u0000ð\u0001\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0002\b\u0005\n\u0002\u0010\u000b\n\u0002\b\u0006\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\b\n\u0002\b\u0007\n\u0002\u0018\u0002\n\u0002\b\b\n\u0002\u0010\u0011\n\u0002\u0018\u0002\n\u0002\u0010\u0007\n\u0002\b\u0002\n\u0002\u0010\u0014\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0010 \n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\f\n\u0002\u0018\u0002\n\u0002\b\b\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0013\n\u0002\u0018\u0002\n\u0002\b\u0002\b\u0007\u0018\u0000 «\u00012\u00020\u0001:\u0002«\u0001B\u0015\u0012\u0006\u0010\u0002\u001a\u00020\u0003\u0012\u0006\u0010\u0004\u001a\u00020\u0005¢\u0006\u0002\u0010\u0006J.\u0010\u008e\u0001\u001a\u00020`2\u0007\u0010\u008f\u0001\u001a\u00020\u00152\u0007\u0010\u0090\u0001\u001a\u00020K2\b\u0010\u0091\u0001\u001a\u00030\u0092\u00012\u0007\u0010\u0093\u0001\u001a\u00020\u000eH\u0002J\u0012\u0010\u0094\u0001\u001a\u00020`2\u0007\u0010\u008f\u0001\u001a\u00020\u0015H\u0002J\n\u0010\u0095\u0001\u001a\u00030\u0096\u0001H\u0002J\u0019\u0010(\u001a\u0004\u0018\u00010$2\r\u0010\u0081\u0001\u001a\b\u0012\u0004\u0012\u00020$0kH\u0002J6\u0010\u0097\u0001\u001a\u00020`2\u0007\u0010\u0098\u0001\u001a\u00020\u000e2\u0007\u0010\u0099\u0001\u001a\u00020\u001c2\u0007\u0010\u009a\u0001\u001a\u00020\u001c2\u0007\u0010\u009b\u0001\u001a\u00020\u001c2\u0007\u0010\u009c\u0001\u001a\u00020\u001cH\u0014J%\u0010\u009d\u0001\u001a\u00020\u000e2\u0007\u0010\u0090\u0001\u001a\u00020K2\b\u0010\u0091\u0001\u001a\u00030\u0092\u00012\t\b\u0002\u0010\u0093\u0001\u001a\u00020\u000eJ\u0007\u0010\u009e\u0001\u001a\u00020`J\u000f\u0010\u009f\u0001\u001a\u00020`H\u0000¢\u0006\u0003\b \u0001J\"\u0010¡\u0001\u001a\u00020`2\u0007\u0010¢\u0001\u001a\u00020\u001c2\u0007\u0010£\u0001\u001a\u00020/2\u0007\u0010¤\u0001\u001a\u00020/J\u0019\u0010¥\u0001\u001a\u00020`2\u0007\u0010¢\u0001\u001a\u00020\u001c2\u0007\u0010¦\u0001\u001a\u00020/J\u0019\u0010§\u0001\u001a\u00020`2\u0007\u0010¢\u0001\u001a\u00020\u001c2\u0007\u0010¨\u0001\u001a\u00020/J\u001b\u0010©\u0001\u001a\u00020`2\b\u0010\u008f\u0001\u001a\u00030ª\u00012\u0006\u0010\u0007\u001a\u00020\u000eH\u0002R(\u0010\t\u001a\u0004\u0018\u00010\b2\b\u0010\u0007\u001a\u0004\u0018\u00010\b@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\n\u0010\u000b\"\u0004\b\f\u0010\rR$\u0010\u000f\u001a\u00020\u000e2\u0006\u0010\u0007\u001a\u00020\u000e@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\u0010\u0010\u0011\"\u0004\b\u0012\u0010\u0013R\u0014\u0010\u0014\u001a\u00020\u00158BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u0016\u0010\u0017R\u0014\u0010\u0018\u001a\u00020\u00198BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u001a\u0010\u001bR*\u0010\u001d\u001a\u0004\u0018\u00010\u001c2\b\u0010\u0007\u001a\u0004\u0018\u00010\u001c@@X\u0080\u000e¢\u0006\u0010\n\u0002\u0010\"\u001a\u0004\b\u001e\u0010\u001f\"\u0004\b \u0010!R\u0016\u0010#\u001a\u0004\u0018\u00010$8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b%\u0010&R\u0016\u0010'\u001a\u0004\u0018\u00010$8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b(\u0010&R*\u0010)\u001a\u0004\u0018\u00010\u001c2\b\u0010\u0007\u001a\u0004\u0018\u00010\u001c@@X\u0080\u000e¢\u0006\u0010\n\u0002\u0010\"\u001a\u0004\b*\u0010\u001f\"\u0004\b+\u0010!R\"\u0010,\u001a\u0014\u0012\u0010\u0012\u000e\u0012\u0004\u0012\u00020/\u0012\u0004\u0012\u00020/0.0-X\u0082\u000e¢\u0006\u0004\n\u0002\u00100R\u000e\u00101\u001a\u000202X\u0082\u000e¢\u0006\u0002\n\u0000R(\u00103\u001a\u0004\u0018\u00010\b2\b\u0010\u0007\u001a\u0004\u0018\u00010\b@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b4\u0010\u000b\"\u0004\b5\u0010\rR\u000e\u00106\u001a\u000202X\u0082\u000e¢\u0006\u0002\n\u0000R\u001a\u00107\u001a\u000208X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b9\u0010:\"\u0004\b;\u0010<R\u000e\u0010=\u001a\u00020\u000eX\u0082\u000e¢\u0006\u0002\n\u0000R$\u0010?\u001a\u00020>2\u0006\u0010\u0007\u001a\u00020>@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b@\u0010A\"\u0004\bB\u0010CR$\u0010E\u001a\u00020D2\u0006\u0010\u0007\u001a\u00020D@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bF\u0010G\"\u0004\bH\u0010IR\u000e\u0010J\u001a\u00020KX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010L\u001a\u00020\u0015X\u0082\u0004¢\u0006\u0002\n\u0000R$\u0010M\u001a\u00020\u000e2\u0006\u0010\u0007\u001a\u00020\u000e@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bN\u0010\u0011\"\u0004\bO\u0010\u0013R\u0010\u0010P\u001a\u0004\u0018\u00010QX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010R\u001a\u00020SX\u0082\u0004¢\u0006\u0002\n\u0000R!\u0010T\u001a\b\u0012\u0004\u0012\u00020V0U8@X\u0080\u0084\u0002¢\u0006\f\n\u0004\bY\u0010Z\u001a\u0004\bW\u0010XR!\u0010[\u001a\b\u0012\u0004\u0012\u00020\\0U8@X\u0080\u0084\u0002¢\u0006\f\n\u0004\b^\u0010Z\u001a\u0004\b]\u0010XR!\u0010_\u001a\b\u0012\u0004\u0012\u00020`0U8@X\u0080\u0084\u0002¢\u0006\f\n\u0004\bb\u0010Z\u001a\u0004\ba\u0010XR!\u0010c\u001a\b\u0012\u0004\u0012\u00020d0U8@X\u0080\u0084\u0002¢\u0006\f\n\u0004\bf\u0010Z\u001a\u0004\be\u0010XR$\u0010g\u001a\u00020>2\u0006\u0010\u0007\u001a\u00020>@@X\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bh\u0010A\"\u0004\bi\u0010CR \u0010j\u001a\b\u0012\u0004\u0012\u00020$0kX\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\bl\u0010m\"\u0004\bn\u0010oR\u001a\u0010p\u001a\u00020qX\u0080\u000e¢\u0006\u000e\n\u0000\u001a\u0004\br\u0010s\"\u0004\bt\u0010uR\u000e\u0010v\u001a\u00020wX\u0082\u0004¢\u0006\u0002\n\u0000R(\u0010x\u001a\u0004\u0018\u00010\b2\b\u0010\u0007\u001a\u0004\u0018\u00010\b@FX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\by\u0010\u000b\"\u0004\bz\u0010\rR\u0010\u0010{\u001a\u00020|X\u0082\u0004¢\u0006\u0004\n\u0002\b}R\u000e\u0010~\u001a\u00020KX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u007f\u001a\u00020\u0015X\u0082\u0004¢\u0006\u0002\n\u0000R\u000f\u0010\u0080\u0001\u001a\u00020\u000eX\u0082\u000e¢\u0006\u0002\n\u0000R#\u0010\u0081\u0001\u001a\b\u0012\u0004\u0012\u00020$0kX\u0080\u000e¢\u0006\u0010\n\u0000\u001a\u0005\b\u0082\u0001\u0010m\"\u0005\b\u0083\u0001\u0010oR-\u0010\u0084\u0001\u001a\u0004\u0018\u00010\u001c2\b\u0010\u0007\u001a\u0004\u0018\u00010\u001c@@X\u0080\u000e¢\u0006\u0012\n\u0002\u0010\"\u001a\u0005\b\u0085\u0001\u0010\u001f\"\u0005\b\u0086\u0001\u0010!R\u000f\u0010\u0087\u0001\u001a\u00020\u000eX\u0082\u000e¢\u0006\u0002\n\u0000R\"\u0010\u0088\u0001\u001a\u0005\u0018\u00010\u0089\u0001X\u0080\u000e¢\u0006\u0012\n\u0000\u001a\u0006\b\u008a\u0001\u0010\u008b\u0001\"\u0006\b\u008c\u0001\u0010\u008d\u0001¨\u0006¬\u0001"}, d2 = {"Lexpo/modules/image/ExpoImageViewWrapper;", "Lexpo/modules/kotlin/views/ExpoView;", "context", "Landroid/content/Context;", "appContext", "Lexpo/modules/kotlin/AppContext;", "(Landroid/content/Context;Lexpo/modules/kotlin/AppContext;)V", "value", "", ViewProps.ACCESSIBILITY_LABEL, "getAccessibilityLabel$expo_image_release", "()Ljava/lang/String;", "setAccessibilityLabel$expo_image_release", "(Ljava/lang/String;)V", "", "accessible", "getAccessible$expo_image_release", "()Z", "setAccessible$expo_image_release", "(Z)V", "activeView", "Lexpo/modules/image/ExpoImageView;", "getActiveView", "()Lexpo/modules/image/ExpoImageView;", "activity", "Landroid/app/Activity;", "getActivity", "()Landroid/app/Activity;", "", ViewProps.BACKGROUND_COLOR, "getBackgroundColor$expo_image_release", "()Ljava/lang/Integer;", "setBackgroundColor$expo_image_release", "(Ljava/lang/Integer;)V", "Ljava/lang/Integer;", "bestPlaceholder", "Lexpo/modules/image/records/SourceMap;", "getBestPlaceholder", "()Lexpo/modules/image/records/SourceMap;", "bestSource", "getBestSource", "blurRadius", "getBlurRadius$expo_image_release", "setBlurRadius$expo_image_release", ViewProps.BORDER_COLOR, "", "Lkotlin/Pair;", "", "[Lkotlin/Pair;", ViewProps.BORDER_RADIUS, "", "borderStyle", "getBorderStyle$expo_image_release", "setBorderStyle$expo_image_release", ViewProps.BORDER_WIDTH, "cachePolicy", "Lexpo/modules/image/records/CachePolicy;", "getCachePolicy$expo_image_release", "()Lexpo/modules/image/records/CachePolicy;", "setCachePolicy$expo_image_release", "(Lexpo/modules/image/records/CachePolicy;)V", "clearViewBeforeChangingSource", "Lexpo/modules/image/enums/ContentFit;", "contentFit", "getContentFit$expo_image_release", "()Lexpo/modules/image/enums/ContentFit;", "setContentFit$expo_image_release", "(Lexpo/modules/image/enums/ContentFit;)V", "Lexpo/modules/image/records/ContentPosition;", "contentPosition", "getContentPosition$expo_image_release", "()Lexpo/modules/image/records/ContentPosition;", "setContentPosition$expo_image_release", "(Lexpo/modules/image/records/ContentPosition;)V", "firstTarget", "Lexpo/modules/image/ImageViewWrapperTarget;", "firstView", "isFocusableProp", "isFocusableProp$expo_image_release", "setFocusableProp$expo_image_release", "loadedSource", "Lexpo/modules/image/GlideModel;", "mainHandler", "Landroid/os/Handler;", "onError", "Lexpo/modules/kotlin/viewevent/ViewEventCallback;", "Lexpo/modules/image/records/ImageErrorEvent;", "getOnError$expo_image_release", "()Lexpo/modules/kotlin/viewevent/ViewEventCallback;", "onError$delegate", "Lexpo/modules/kotlin/viewevent/ViewEventDelegate;", "onLoad", "Lexpo/modules/image/records/ImageLoadEvent;", "getOnLoad$expo_image_release", "onLoad$delegate", "onLoadStart", "", "getOnLoadStart$expo_image_release", "onLoadStart$delegate", "onProgress", "Lexpo/modules/image/records/ImageProgressEvent;", "getOnProgress$expo_image_release", "onProgress$delegate", "placeholderContentFit", "getPlaceholderContentFit$expo_image_release", "setPlaceholderContentFit$expo_image_release", "placeholders", "", "getPlaceholders$expo_image_release", "()Ljava/util/List;", "setPlaceholders$expo_image_release", "(Ljava/util/List;)V", SentryThread.JsonKeys.PRIORITY, "Lexpo/modules/image/enums/Priority;", "getPriority$expo_image_release", "()Lexpo/modules/image/enums/Priority;", "setPriority$expo_image_release", "(Lexpo/modules/image/enums/Priority;)V", "progressListener", "Lexpo/modules/image/events/OkHttpProgressListener;", "recyclingKey", "getRecyclingKey", "setRecyclingKey", "requestManager", "Lcom/bumptech/glide/RequestManager;", "requestManager$1", "secondTarget", "secondView", "shouldRerender", "sources", "getSources$expo_image_release", "setSources$expo_image_release", "tintColor", "getTintColor$expo_image_release", "setTintColor$expo_image_release", "transformationMatrixChanged", "transition", "Lexpo/modules/image/records/ImageTransition;", "getTransition$expo_image_release", "()Lexpo/modules/image/records/ImageTransition;", "setTransition$expo_image_release", "(Lexpo/modules/image/records/ImageTransition;)V", "configureView", "view", TouchesHelper.TARGET_KEY, "resource", "Landroid/graphics/drawable/Drawable;", "isPlaceholder", "copyProps", "createPropOptions", "Lcom/bumptech/glide/request/RequestOptions;", ViewProps.ON_LAYOUT, "changed", ViewProps.LEFT, ViewProps.TOP, ViewProps.RIGHT, ViewProps.BOTTOM, "onResourceReady", "onViewDestroys", "rerenderIfNeeded", "rerenderIfNeeded$expo_image_release", "setBorderColor", FirebaseAnalytics.Param.INDEX, "rgb", ViewHierarchyNode.JsonKeys.ALPHA, "setBorderRadius", "radius", "setBorderWidth", "width", "setIsScreenReaderFocusable", "Landroid/view/View;", "Companion", "expo-image_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class ExpoImageViewWrapper extends ExpoView {
    static final /* synthetic */ KProperty<Object>[] $$delegatedProperties = {Reflection.property1(new PropertyReference1Impl(ExpoImageViewWrapper.class, "onLoadStart", "getOnLoadStart$expo_image_release()Lexpo/modules/kotlin/viewevent/ViewEventCallback;", 0)), Reflection.property1(new PropertyReference1Impl(ExpoImageViewWrapper.class, "onProgress", "getOnProgress$expo_image_release()Lexpo/modules/kotlin/viewevent/ViewEventCallback;", 0)), Reflection.property1(new PropertyReference1Impl(ExpoImageViewWrapper.class, "onError", "getOnError$expo_image_release()Lexpo/modules/kotlin/viewevent/ViewEventCallback;", 0)), Reflection.property1(new PropertyReference1Impl(ExpoImageViewWrapper.class, "onLoad", "getOnLoad$expo_image_release()Lexpo/modules/kotlin/viewevent/ViewEventCallback;", 0))};
    public static final Companion Companion = new Companion(null);
    private static WeakReference<AppContext> appContextRef = new WeakReference<>(null);
    private static RequestManager requestManager;
    private String accessibilityLabel;
    private boolean accessible;
    private Integer backgroundColor;
    private Integer blurRadius;
    private Pair<Float, Float>[] borderColor;
    private float[] borderRadius;
    private String borderStyle;
    private float[] borderWidth;
    private CachePolicy cachePolicy;
    private boolean clearViewBeforeChangingSource;
    private ContentFit contentFit;
    private ContentPosition contentPosition;
    private ImageViewWrapperTarget firstTarget;
    private final ExpoImageView firstView;
    private boolean isFocusableProp;
    private GlideModel loadedSource;
    private final Handler mainHandler;
    private final ViewEventDelegate onError$delegate;
    private final ViewEventDelegate onLoad$delegate;
    private final ViewEventDelegate onLoadStart$delegate;
    private final ViewEventDelegate onProgress$delegate;
    private ContentFit placeholderContentFit;
    private List<SourceMap> placeholders;
    private Priority priority;
    private final OkHttpProgressListener progressListener;
    private String recyclingKey;
    private final RequestManager requestManager$1;
    private ImageViewWrapperTarget secondTarget;
    private final ExpoImageView secondView;
    private boolean shouldRerender;
    private List<SourceMap> sources;
    private Integer tintColor;
    private boolean transformationMatrixChanged;
    private ImageTransition transition;

    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
    public ExpoImageViewWrapper(Context context, AppContext appContext) {
        super(context, appContext);
        Intrinsics.checkNotNullParameter(context, "context");
        Intrinsics.checkNotNullParameter(appContext, "appContext");
        this.requestManager$1 = Companion.getOrCreateRequestManager(appContext, getActivity());
        this.progressListener = new OkHttpProgressListener(new WeakReference(this));
        this.firstView = new ExpoImageView(getActivity());
        this.secondView = new ExpoImageView(getActivity());
        this.mainHandler = new Handler(context.getMainLooper());
        this.firstTarget = new ImageViewWrapperTarget(new WeakReference(this));
        this.secondTarget = new ImageViewWrapperTarget(new WeakReference(this));
        ExpoImageViewWrapper expoImageViewWrapper = this;
        this.onLoadStart$delegate = new ViewEventDelegate(Reflection.typeOf(Unit.class), expoImageViewWrapper, null);
        this.onProgress$delegate = new ViewEventDelegate(Reflection.typeOf(ImageProgressEvent.class), expoImageViewWrapper, null);
        this.onError$delegate = new ViewEventDelegate(Reflection.typeOf(ImageErrorEvent.class), expoImageViewWrapper, null);
        this.onLoad$delegate = new ViewEventDelegate(Reflection.typeOf(ImageLoadEvent.class), expoImageViewWrapper, null);
        this.sources = CollectionsKt.emptyList();
        this.placeholders = CollectionsKt.emptyList();
        this.contentFit = ContentFit.Cover;
        this.placeholderContentFit = ContentFit.ScaleDown;
        this.contentPosition = ContentPosition.Companion.getCenter();
        this.priority = Priority.NORMAL;
        this.cachePolicy = CachePolicy.DISK;
        float[] fArr = new float[9];
        for (int i = 0; i < 9; i++) {
            fArr[i] = Float.NaN;
        }
        this.borderRadius = fArr;
        float[] fArr2 = new float[9];
        for (int i2 = 0; i2 < 9; i2++) {
            fArr2[i2] = Float.NaN;
        }
        this.borderWidth = fArr2;
        Pair<Float, Float>[] pairArr = new Pair[9];
        for (int i3 = 0; i3 < 9; i3++) {
            pairArr[i3] = TuplesKt.to(Float.valueOf(Float.NaN), Float.valueOf(Float.NaN));
        }
        this.borderColor = pairArr;
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -1);
        setLayoutParams(layoutParams);
        this.firstView.setVisibility(0);
        this.secondView.setVisibility(0);
        FrameLayout frameLayout = new FrameLayout(context);
        frameLayout.setLayoutParams(layoutParams);
        frameLayout.addView(this.firstView, layoutParams);
        frameLayout.addView(this.secondView, layoutParams);
        addView(frameLayout, layoutParams);
    }

    private final Activity getActivity() {
        Activity currentActivity = getAppContext().getCurrentActivity();
        if (currentActivity != null) {
            return currentActivity;
        }
        throw new MissingActivity();
    }

    private final ExpoImageView getActiveView() {
        if (this.secondView.getDrawable() != null) {
            return this.secondView;
        }
        return this.firstView;
    }

    public final ViewEventCallback<Unit> getOnLoadStart$expo_image_release() {
        return this.onLoadStart$delegate.getValue(this, $$delegatedProperties[0]);
    }

    public final ViewEventCallback<ImageProgressEvent> getOnProgress$expo_image_release() {
        return this.onProgress$delegate.getValue(this, $$delegatedProperties[1]);
    }

    public final ViewEventCallback<ImageErrorEvent> getOnError$expo_image_release() {
        return this.onError$delegate.getValue(this, $$delegatedProperties[2]);
    }

    public final ViewEventCallback<ImageLoadEvent> getOnLoad$expo_image_release() {
        return this.onLoad$delegate.getValue(this, $$delegatedProperties[3]);
    }

    public final List<SourceMap> getSources$expo_image_release() {
        return this.sources;
    }

    public final void setSources$expo_image_release(List<SourceMap> list) {
        Intrinsics.checkNotNullParameter(list, "<set-?>");
        this.sources = list;
    }

    private final SourceMap getBestSource() {
        return getBestSource(this.sources);
    }

    public final List<SourceMap> getPlaceholders$expo_image_release() {
        return this.placeholders;
    }

    public final void setPlaceholders$expo_image_release(List<SourceMap> list) {
        Intrinsics.checkNotNullParameter(list, "<set-?>");
        this.placeholders = list;
    }

    private final SourceMap getBestPlaceholder() {
        return getBestSource(this.placeholders);
    }

    public final Integer getBlurRadius$expo_image_release() {
        return this.blurRadius;
    }

    public final void setBlurRadius$expo_image_release(Integer num) {
        if (!Intrinsics.areEqual(this.blurRadius, num)) {
            this.shouldRerender = true;
        }
        this.blurRadius = num;
    }

    public final ImageTransition getTransition$expo_image_release() {
        return this.transition;
    }

    public final void setTransition$expo_image_release(ImageTransition imageTransition) {
        this.transition = imageTransition;
    }

    public final ContentFit getContentFit$expo_image_release() {
        return this.contentFit;
    }

    public final void setContentFit$expo_image_release(ContentFit value) {
        Intrinsics.checkNotNullParameter(value, "value");
        this.contentFit = value;
        getActiveView().setContentFit$expo_image_release(value);
        this.transformationMatrixChanged = true;
    }

    public final ContentFit getPlaceholderContentFit$expo_image_release() {
        return this.placeholderContentFit;
    }

    public final void setPlaceholderContentFit$expo_image_release(ContentFit value) {
        Intrinsics.checkNotNullParameter(value, "value");
        this.placeholderContentFit = value;
        getActiveView().setPlaceholderContentFit$expo_image_release(value);
        this.transformationMatrixChanged = true;
    }

    public final ContentPosition getContentPosition$expo_image_release() {
        return this.contentPosition;
    }

    public final void setContentPosition$expo_image_release(ContentPosition value) {
        Intrinsics.checkNotNullParameter(value, "value");
        this.contentPosition = value;
        getActiveView().setContentPosition$expo_image_release(value);
        this.transformationMatrixChanged = true;
    }

    public final String getBorderStyle$expo_image_release() {
        return this.borderStyle;
    }

    public final void setBorderStyle$expo_image_release(String str) {
        this.borderStyle = str;
        getActiveView().setBorderStyle$expo_image_release(str);
    }

    public final Integer getBackgroundColor$expo_image_release() {
        return this.backgroundColor;
    }

    public final void setBackgroundColor$expo_image_release(Integer num) {
        this.backgroundColor = num;
        getActiveView().setBackgroundColor$expo_image_release(num);
    }

    public final Integer getTintColor$expo_image_release() {
        return this.tintColor;
    }

    public final void setTintColor$expo_image_release(Integer num) {
        this.tintColor = num;
        getActiveView().setTintColor$expo_image_release(num);
    }

    public final boolean isFocusableProp$expo_image_release() {
        return this.isFocusableProp;
    }

    public final void setFocusableProp$expo_image_release(boolean z) {
        this.isFocusableProp = z;
        getActiveView().setFocusable(z);
    }

    public final boolean getAccessible$expo_image_release() {
        return this.accessible;
    }

    public final void setAccessible$expo_image_release(boolean z) {
        this.accessible = z;
        setIsScreenReaderFocusable(getActiveView(), z);
    }

    public final String getAccessibilityLabel$expo_image_release() {
        return this.accessibilityLabel;
    }

    public final void setAccessibilityLabel$expo_image_release(String str) {
        this.accessibilityLabel = str;
        getActiveView().setContentDescription(this.accessibilityLabel);
    }

    public final String getRecyclingKey() {
        return this.recyclingKey;
    }

    public final void setRecyclingKey(String str) {
        this.clearViewBeforeChangingSource = (str == null || Intrinsics.areEqual(str, this.recyclingKey)) ? false : true;
        this.recyclingKey = str;
    }

    public final Priority getPriority$expo_image_release() {
        return this.priority;
    }

    public final void setPriority$expo_image_release(Priority priority) {
        Intrinsics.checkNotNullParameter(priority, "<set-?>");
        this.priority = priority;
    }

    public final CachePolicy getCachePolicy$expo_image_release() {
        return this.cachePolicy;
    }

    public final void setCachePolicy$expo_image_release(CachePolicy cachePolicy) {
        Intrinsics.checkNotNullParameter(cachePolicy, "<set-?>");
        this.cachePolicy = cachePolicy;
    }

    public final void setBorderRadius(int i, float f) {
        this.borderRadius[i] = f;
        getActiveView().setBorderRadius$expo_image_release(i, f);
    }

    public final void setBorderWidth(int i, float f) {
        this.borderWidth[i] = f;
        getActiveView().setBorderWidth$expo_image_release(i, f);
    }

    public final void setBorderColor(int i, float f, float f2) {
        this.borderColor[i] = TuplesKt.to(Float.valueOf(f), Float.valueOf(f2));
        getActiveView().setBorderColor$expo_image_release(i, f, f2);
    }

    private final void copyProps(ExpoImageView expoImageView) {
        expoImageView.setContentFit$expo_image_release(this.contentFit);
        expoImageView.setContentPosition$expo_image_release(this.contentPosition);
        expoImageView.setBorderStyle$expo_image_release(this.borderStyle);
        expoImageView.setBackgroundColor$expo_image_release(this.backgroundColor);
        expoImageView.setTintColor$expo_image_release(this.tintColor);
        expoImageView.setFocusable(this.isFocusableProp);
        expoImageView.setContentDescription(this.accessibilityLabel);
        Pair<Float, Float>[] pairArr = this.borderColor;
        int length = pairArr.length;
        int i = 0;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            Pair<Float, Float> pair = pairArr[i2];
            expoImageView.setBorderColor$expo_image_release(i3, pair.component1().floatValue(), pair.component2().floatValue());
            i2++;
            i3++;
        }
        float[] fArr = this.borderRadius;
        int length2 = fArr.length;
        int i4 = 0;
        int i5 = 0;
        while (i4 < length2) {
            expoImageView.setBorderRadius$expo_image_release(i5, fArr[i4]);
            i4++;
            i5++;
        }
        float[] fArr2 = this.borderWidth;
        int length3 = fArr2.length;
        int i6 = 0;
        while (i < length3) {
            expoImageView.setBorderWidth$expo_image_release(i6, fArr2[i]);
            i++;
            i6++;
        }
        setIsScreenReaderFocusable(expoImageView, this.accessible);
    }

    private final void setIsScreenReaderFocusable(View view, final boolean z) {
        if (Build.VERSION.SDK_INT >= 28) {
            view.setScreenReaderFocusable(z);
        } else {
            ViewCompat.setAccessibilityDelegate(this, new AccessibilityDelegateCompat() { // from class: expo.modules.image.ExpoImageViewWrapper$setIsScreenReaderFocusable$1
                @Override // androidx.core.view.AccessibilityDelegateCompat
                public void onInitializeAccessibilityNodeInfo(View host, AccessibilityNodeInfoCompat info) {
                    Intrinsics.checkNotNullParameter(host, "host");
                    Intrinsics.checkNotNullParameter(info, "info");
                    info.setScreenReaderFocusable(z);
                    super.onInitializeAccessibilityNodeInfo(host, info);
                }
            });
        }
    }

    public static /* synthetic */ boolean onResourceReady$default(ExpoImageViewWrapper expoImageViewWrapper, ImageViewWrapperTarget imageViewWrapperTarget, Drawable drawable, boolean z, int i, Object obj) {
        if ((i & 4) != 0) {
            z = false;
        }
        return expoImageViewWrapper.onResourceReady(imageViewWrapperTarget, drawable, z);
    }

    public final boolean onResourceReady(final ImageViewWrapperTarget target, final Drawable resource, final boolean z) {
        Intrinsics.checkNotNullParameter(target, "target");
        Intrinsics.checkNotNullParameter(resource, "resource");
        return this.mainHandler.postAtFrontOfQueue(new Runnable() { // from class: expo.modules.image.ExpoImageViewWrapper$$ExternalSyntheticLambda1
            @Override // java.lang.Runnable
            public final void run() {
                ExpoImageViewWrapper.m498onResourceReady$lambda7(ExpoImageViewWrapper.this, z, target, resource);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: onResourceReady$lambda-7  reason: not valid java name */
    public static final void m498onResourceReady$lambda7(ExpoImageViewWrapper this$0, boolean z, ImageViewWrapperTarget target, Drawable resource) {
        Pair pair;
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(target, "$target");
        Intrinsics.checkNotNullParameter(resource, "$resource");
        ImageTransition imageTransition = this$0.transition;
        long duration = imageTransition != null ? imageTransition.getDuration() : 0;
        if (!z || !target.getHasSource()) {
            if (this$0.firstView.getDrawable() == null) {
                pair = TuplesKt.to(this$0.firstView, this$0.secondView);
            } else {
                pair = TuplesKt.to(this$0.secondView, this$0.firstView);
            }
            ExpoImageView expoImageView = (ExpoImageView) pair.component1();
            ExpoImageView expoImageView2 = (ExpoImageView) pair.component2();
            final ExpoImageViewWrapper$onResourceReady$1$clearPreviousView$1 expoImageViewWrapper$onResourceReady$1$clearPreviousView$1 = new ExpoImageViewWrapper$onResourceReady$1$clearPreviousView$1(expoImageView2, target, this$0);
            this$0.configureView(expoImageView, target, resource, z);
            if (duration <= 0) {
                expoImageViewWrapper$onResourceReady$1$clearPreviousView$1.invoke();
                expoImageView.setAlpha(1.0f);
                expoImageView.bringToFront();
                return;
            }
            expoImageView.bringToFront();
            expoImageView2.setAlpha(1.0f);
            expoImageView.setAlpha(0.0f);
            ViewPropertyAnimator animate = expoImageView2.animate();
            animate.setDuration(duration);
            animate.alpha(0.0f);
            animate.withEndAction(new Runnable() { // from class: expo.modules.image.ExpoImageViewWrapper$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    ExpoImageViewWrapper.m499onResourceReady$lambda7$lambda4$lambda3(Function0.this);
                }
            });
            ViewPropertyAnimator animate2 = expoImageView.animate();
            animate2.setDuration(duration);
            animate2.alpha(1.0f);
        } else if ((this$0.firstView.getDrawable() == null || this$0.firstView.isPlaceholder()) && this$0.secondView.getDrawable() == null) {
            ImageViewWrapperTarget recycleView = this$0.firstView.recycleView();
            if (recycleView != null) {
                recycleView.clear(this$0.requestManager$1);
            }
            this$0.configureView(this$0.firstView, target, resource, z);
            if (duration > 0) {
                this$0.firstView.bringToFront();
                this$0.firstView.setAlpha(0.0f);
                this$0.secondView.setVisibility(8);
                ViewPropertyAnimator animate3 = this$0.firstView.animate();
                animate3.setDuration(duration);
                animate3.alpha(1.0f);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: onResourceReady$lambda-7$lambda-4$lambda-3  reason: not valid java name */
    public static final void m499onResourceReady$lambda7$lambda4$lambda3(Function0 clearPreviousView) {
        Intrinsics.checkNotNullParameter(clearPreviousView, "$clearPreviousView");
        clearPreviousView.invoke();
    }

    private final void configureView(ExpoImageView expoImageView, ImageViewWrapperTarget imageViewWrapperTarget, Drawable drawable, boolean z) {
        expoImageView.setImageDrawable(drawable);
        expoImageView.setPlaceholder(z);
        ContentFit placeholderContentFit = imageViewWrapperTarget.getPlaceholderContentFit();
        if (placeholderContentFit == null) {
            placeholderContentFit = ContentFit.ScaleDown;
        }
        expoImageView.setPlaceholderContentFit$expo_image_release(placeholderContentFit);
        copyProps(expoImageView);
        expoImageView.setVisibility(0);
        expoImageView.layout(0, 0, getWidth(), getHeight());
        expoImageView.applyTransformationMatrix();
        expoImageView.setCurrentTarget(imageViewWrapperTarget);
        imageViewWrapperTarget.setUsed(true);
        if (drawable instanceof Animatable) {
            ((Animatable) drawable).start();
        }
    }

    private final SourceMap getBestSource(List<SourceMap> list) {
        SourceMap sourceMap = null;
        if (list.isEmpty()) {
            return null;
        }
        if (list.size() == 1) {
            return (SourceMap) CollectionsKt.first((List<? extends Object>) list);
        }
        Rect rect = new Rect(0, 0, getWidth(), getHeight());
        if (rect.isEmpty()) {
            return null;
        }
        int width = rect.width() * rect.height();
        double d = Double.MAX_VALUE;
        for (SourceMap sourceMap2 : list) {
            double abs = Math.abs(1 - (sourceMap2.getPixelCount$expo_image_release() / width));
            if (abs < d) {
                sourceMap = sourceMap2;
                d = abs;
            }
        }
        return sourceMap;
    }

    @Override // android.widget.LinearLayout, android.view.ViewGroup, android.view.View
    protected void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        rerenderIfNeeded$expo_image_release();
    }

    private final RequestOptions createPropOptions() {
        RequestOptions requestOptions = new RequestOptions();
        requestOptions.priority(this.priority.toGlidePriority$expo_image_release());
        if (this.cachePolicy != CachePolicy.MEMORY_AND_DISK && this.cachePolicy != CachePolicy.MEMORY) {
            requestOptions.skipMemoryCache(true);
        }
        if (this.cachePolicy == CachePolicy.NONE || this.cachePolicy == CachePolicy.MEMORY) {
            requestOptions.diskCacheStrategy(DiskCacheStrategy.NONE);
        }
        Integer num = this.blurRadius;
        if (num != null) {
            requestOptions.transform(new BlurTransformation(Math.min(num.intValue(), 25), 4));
        }
        return requestOptions;
    }

    public final void onViewDestroys() {
        this.firstView.setImageDrawable(null);
        this.secondView.setImageDrawable(null);
        this.requestManager$1.clear(this.firstTarget);
        this.requestManager$1.clear(this.secondTarget);
    }

    public final void rerenderIfNeeded$expo_image_release() {
        GlideModel glideModel;
        GlideModel glideModel2;
        RequestOptions requestOptions;
        ImageViewWrapperTarget imageViewWrapperTarget;
        ContentFit contentFit;
        ExpoImageView expoImageView;
        SourceMap bestSource = getBestSource();
        SourceMap bestPlaceholder = getBestPlaceholder();
        if (bestSource != null) {
            Context context = getContext();
            Intrinsics.checkNotNullExpressionValue(context, "context");
            glideModel = bestSource.createGlideModel$expo_image_release(context);
        } else {
            glideModel = null;
        }
        if (bestPlaceholder != null) {
            Context context2 = getContext();
            Intrinsics.checkNotNullExpressionValue(context2, "context");
            glideModel2 = bestPlaceholder.createGlideModel$expo_image_release(context2);
        } else {
            glideModel2 = null;
        }
        if ((bestSource == null || glideModel == null) && glideModel2 == null) {
            this.firstView.recycleView();
            this.secondView.recycleView();
            this.requestManager$1.clear(this.firstTarget);
            this.requestManager$1.clear(this.secondTarget);
            this.shouldRerender = false;
            this.loadedSource = null;
            this.transformationMatrixChanged = false;
            this.clearViewBeforeChangingSource = false;
            return;
        }
        if (!Intrinsics.areEqual(glideModel, this.loadedSource) || this.shouldRerender || (glideModel == null && glideModel2 != null)) {
            if (this.clearViewBeforeChangingSource) {
                if (this.firstView.getDrawable() != null) {
                    expoImageView = this.firstView;
                } else {
                    expoImageView = this.secondView;
                }
                ImageViewWrapperTarget recycleView = expoImageView.recycleView();
                if (recycleView != null) {
                    recycleView.clear(this.requestManager$1);
                }
            }
            this.shouldRerender = false;
            this.loadedSource = glideModel;
            if (bestSource != null) {
                Context context3 = getContext();
                Intrinsics.checkNotNullExpressionValue(context3, "context");
                requestOptions = bestSource.createOptions$expo_image_release(context3);
            } else {
                requestOptions = null;
            }
            RequestOptions createPropOptions = createPropOptions();
            Object glideData = glideModel != null ? glideModel.getGlideData() : null;
            if (glideData instanceof GlideUrlWrapper) {
                ((GlideUrlWrapper) glideData).setProgressListener(this.progressListener);
            }
            getOnLoadStart$expo_image_release().invoke(Unit.INSTANCE);
            if (this.secondTarget.isUsed()) {
                imageViewWrapperTarget = this.firstTarget;
            } else {
                imageViewWrapperTarget = this.secondTarget;
            }
            imageViewWrapperTarget.setHasSource(glideModel != null);
            RequestBuilder<Drawable> load = this.requestManager$1.asDrawable().load(glideData);
            if (glideModel2 != null) {
                load.thumbnail(this.requestManager$1.load(glideModel2.getGlideData()));
                if (bestPlaceholder.isBlurhash()) {
                    contentFit = this.contentFit;
                } else {
                    contentFit = this.placeholderContentFit;
                }
                imageViewWrapperTarget.setPlaceholderContentFit(contentFit);
            }
            if (requestOptions != null) {
                load.apply((BaseRequestOptions<?>) requestOptions);
            }
            RequestBuilder apply = load.downsample(DownsampleStrategy.NONE).addListener(new GlideRequestListener(new WeakReference(this))).encodeQuality(100).apply((BaseRequestOptions<?>) createPropOptions);
            Intrinsics.checkNotNullExpressionValue(apply, "requestManager\n        .…      .apply(propOptions)");
            apply.into((RequestBuilder) imageViewWrapperTarget);
        } else if (this.transformationMatrixChanged) {
            getActiveView().applyTransformationMatrix();
        }
        this.transformationMatrixChanged = false;
        this.clearViewBeforeChangingSource = false;
    }

    /* compiled from: ExpoImageViewWrapper.kt */
    @Metadata(d1 = {"\u0000&\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0010\u0010\b\u001a\u00020\u00072\u0006\u0010\t\u001a\u00020\nH\u0002J\u0016\u0010\u000b\u001a\u00020\u00072\u0006\u0010\f\u001a\u00020\u00052\u0006\u0010\t\u001a\u00020\nR\u0016\u0010\u0003\u001a\n\u0012\u0006\u0012\u0004\u0018\u00010\u00050\u0004X\u0082\u000e¢\u0006\u0002\n\u0000R\u0010\u0010\u0006\u001a\u0004\u0018\u00010\u0007X\u0082\u000e¢\u0006\u0002\n\u0000¨\u0006\r"}, d2 = {"Lexpo/modules/image/ExpoImageViewWrapper$Companion;", "", "()V", "appContextRef", "Ljava/lang/ref/WeakReference;", "Lexpo/modules/kotlin/AppContext;", "requestManager", "Lcom/bumptech/glide/RequestManager;", "createNewRequestManager", "activity", "Landroid/app/Activity;", "getOrCreateRequestManager", "appContext", "expo-image_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes3.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final RequestManager getOrCreateRequestManager(AppContext appContext, Activity activity) {
            Intrinsics.checkNotNullParameter(appContext, "appContext");
            Intrinsics.checkNotNullParameter(activity, "activity");
            synchronized (ExpoImageViewWrapper.Companion) {
                RequestManager requestManager = ExpoImageViewWrapper.requestManager;
                if (requestManager != null) {
                    if (Intrinsics.areEqual(ExpoImageViewWrapper.appContextRef.get(), appContext)) {
                        return requestManager;
                    }
                    RequestManager createNewRequestManager = ExpoImageViewWrapper.Companion.createNewRequestManager(activity);
                    Companion companion = ExpoImageViewWrapper.Companion;
                    ExpoImageViewWrapper.requestManager = createNewRequestManager;
                    Companion companion2 = ExpoImageViewWrapper.Companion;
                    ExpoImageViewWrapper.appContextRef = new WeakReference(appContext);
                    return createNewRequestManager;
                }
                RequestManager createNewRequestManager2 = ExpoImageViewWrapper.Companion.createNewRequestManager(activity);
                Companion companion3 = ExpoImageViewWrapper.Companion;
                ExpoImageViewWrapper.requestManager = createNewRequestManager2;
                Companion companion4 = ExpoImageViewWrapper.Companion;
                ExpoImageViewWrapper.appContextRef = new WeakReference(appContext);
                return createNewRequestManager2;
            }
        }

        private final RequestManager createNewRequestManager(Activity activity) {
            RequestManager addDefaultRequestListener = Glide.with(activity).addDefaultRequestListener(new SVGSoftwareLayerSetter(0, 1, null));
            Intrinsics.checkNotNullExpressionValue(addDefaultRequestListener, "with(activity).addDefaul…SVGSoftwareLayerSetter())");
            return addDefaultRequestListener;
        }
    }
}
