package com.horcrux.svg;

import android.content.res.AssetManager;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.os.Build;
import android.text.Layout;
import android.text.SpannableString;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.view.View;
import android.view.ViewParent;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.views.text.ReactFontManager;
import com.horcrux.svg.TextProperties;
import io.sentry.protocol.ViewHierarchyNode;
import java.text.Bidi;
import java.util.ArrayList;
import javax.annotation.Nullable;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes2.dex */
public class TSpanView extends TextView {
    private static final String FONTS = "fonts/";
    private static final String OTF = ".otf";
    private static final String TTF = ".ttf";
    static final String additionalLigatures = "'hlig', 'cala', ";
    static final String defaultFeatures = "'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', ";
    static final String disableDiscretionaryLigatures = "'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, ";
    static final String fontWeightTag = "'wght' ";
    private static final double radToDeg = 57.29577951308232d;
    static final String requiredFontFeatures = "'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk',";
    private static final double tau = 6.283185307179586d;
    private final AssetManager assets;
    private final ArrayList<String> emoji;
    private final ArrayList<Matrix> emojiTransforms;
    private Path mCachedPath;
    @Nullable
    String mContent;
    private TextPathView textPath;

    public TSpanView(ReactContext reactContext) {
        super(reactContext);
        this.emoji = new ArrayList<>();
        this.emojiTransforms = new ArrayList<>();
        this.assets = this.mContext.getResources().getAssets();
    }

    public void setContent(@Nullable String str) {
        this.mContent = str;
        invalidate();
    }

    @Override // com.horcrux.svg.TextView, com.horcrux.svg.VirtualView, android.view.View
    public void invalidate() {
        this.mCachedPath = null;
        super.invalidate();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // com.horcrux.svg.TextView, com.horcrux.svg.VirtualView
    public void clearCache() {
        this.mCachedPath = null;
        super.clearCache();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // com.horcrux.svg.TextView, com.horcrux.svg.GroupView, com.horcrux.svg.RenderableView, com.horcrux.svg.VirtualView
    public void draw(Canvas canvas, Paint paint, float f) {
        if (this.mContent != null) {
            if (this.mInlineSize != null && this.mInlineSize.value != 0.0d) {
                if (setupFillPaint(paint, this.fillOpacity * f)) {
                    drawWrappedText(canvas, paint);
                }
                if (setupStrokePaint(paint, f * this.strokeOpacity)) {
                    drawWrappedText(canvas, paint);
                    return;
                }
                return;
            }
            int size = this.emoji.size();
            if (size > 0) {
                applyTextPropertiesToPaint(paint, getTextRootGlyphContext().getFont());
                for (int i = 0; i < size; i++) {
                    canvas.save();
                    canvas.concat(this.emojiTransforms.get(i));
                    canvas.drawText(this.emoji.get(i), 0.0f, 0.0f, paint);
                    canvas.restore();
                }
            }
            drawPath(canvas, paint, f);
            return;
        }
        clip(canvas, paint);
        drawGroup(canvas, paint, f);
    }

    private void drawWrappedText(Canvas canvas, Paint paint) {
        Layout.Alignment alignment;
        GlyphContext textRootGlyphContext = getTextRootGlyphContext();
        pushGlyphContext();
        FontData font = textRootGlyphContext.getFont();
        TextPaint textPaint = new TextPaint(paint);
        applyTextPropertiesToPaint(textPaint, font);
        applySpacingAndFeatures(textPaint, font);
        double fontSize = textRootGlyphContext.getFontSize();
        int i = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[font.textAnchor.ordinal()];
        if (i == 2) {
            alignment = Layout.Alignment.ALIGN_CENTER;
        } else if (i != 3) {
            alignment = Layout.Alignment.ALIGN_NORMAL;
        } else {
            alignment = Layout.Alignment.ALIGN_OPPOSITE;
        }
        StaticLayout staticLayout = getStaticLayout(textPaint, alignment, true, new SpannableString(this.mContent), (int) PropHelper.fromRelative(this.mInlineSize, canvas.getWidth(), 0.0d, this.mScale, fontSize));
        int lineAscent = staticLayout.getLineAscent(0);
        popGlyphContext();
        canvas.save();
        canvas.translate((float) textRootGlyphContext.nextX(0.0d), (float) (textRootGlyphContext.nextY() + lineAscent));
        staticLayout.draw(canvas);
        canvas.restore();
    }

    private StaticLayout getStaticLayout(TextPaint textPaint, Layout.Alignment alignment, boolean z, SpannableString spannableString, int i) {
        if (Build.VERSION.SDK_INT < 23) {
            return new StaticLayout(spannableString, textPaint, i, alignment, 1.0f, 0.0f, z);
        }
        return StaticLayout.Builder.obtain(spannableString, 0, spannableString.length(), textPaint, i).setAlignment(alignment).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(1).setHyphenationFrequency(1).build();
    }

    public static String visualToLogical(String str) {
        if (str == null || str.length() == 0) {
            return str;
        }
        Bidi bidi = new Bidi(str, -2);
        if (bidi.isLeftToRight()) {
            return str;
        }
        int runCount = bidi.getRunCount();
        byte[] bArr = new byte[runCount];
        Integer[] numArr = new Integer[runCount];
        for (int i = 0; i < runCount; i++) {
            bArr[i] = (byte) bidi.getRunLevel(i);
            numArr[i] = Integer.valueOf(i);
        }
        Bidi.reorderVisually(bArr, 0, numArr, 0, runCount);
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < runCount; i2++) {
            int intValue = numArr[i2].intValue();
            int runStart = bidi.getRunStart(intValue);
            int runLimit = bidi.getRunLimit(intValue);
            if ((bArr[intValue] & 1) != 0) {
                while (true) {
                    runLimit--;
                    if (runLimit >= runStart) {
                        sb.append(str.charAt(runLimit));
                    }
                }
            } else {
                sb.append((CharSequence) str, runStart, runLimit);
            }
        }
        return sb.toString();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // com.horcrux.svg.TextView, com.horcrux.svg.GroupView, com.horcrux.svg.RenderableView, com.horcrux.svg.VirtualView
    public Path getPath(Canvas canvas, Paint paint) {
        Path path = this.mCachedPath;
        if (path != null) {
            return path;
        }
        if (this.mContent == null) {
            Path groupPath = getGroupPath(canvas, paint);
            this.mCachedPath = groupPath;
            return groupPath;
        }
        setupTextPath();
        pushGlyphContext();
        this.mCachedPath = getLinePath(visualToLogical(this.mContent), paint, canvas);
        popGlyphContext();
        return this.mCachedPath;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // com.horcrux.svg.TextView
    public double getSubtreeTextChunksTotalAdvance(Paint paint) {
        if (!Double.isNaN(this.cachedAdvance)) {
            return this.cachedAdvance;
        }
        String str = this.mContent;
        double d = 0.0d;
        if (str == null) {
            for (int i = 0; i < getChildCount(); i++) {
                View childAt = getChildAt(i);
                if (childAt instanceof TextView) {
                    d += ((TextView) childAt).getSubtreeTextChunksTotalAdvance(paint);
                }
            }
            this.cachedAdvance = d;
            return d;
        } else if (str.length() == 0) {
            this.cachedAdvance = 0.0d;
            return 0.0d;
        } else {
            FontData font = getTextRootGlyphContext().getFont();
            applyTextPropertiesToPaint(paint, font);
            applySpacingAndFeatures(paint, font);
            this.cachedAdvance = paint.measureText(str);
            return this.cachedAdvance;
        }
    }

    private void applySpacingAndFeatures(Paint paint, FontData fontData) {
        double d = fontData.letterSpacing;
        paint.setLetterSpacing((float) (d / (fontData.fontSize * this.mScale)));
        if (d == 0.0d && fontData.fontVariantLigatures == TextProperties.FontVariantLigatures.normal) {
            paint.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'hlig', 'cala', " + fontData.fontFeatureSettings);
        } else {
            paint.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, " + fontData.fontFeatureSettings);
        }
        if (Build.VERSION.SDK_INT >= 26) {
            paint.setFontVariationSettings(fontWeightTag + fontData.absoluteFontWeight + fontData.fontVariationSettings);
        }
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Removed duplicated region for block: B:100:0x025f  */
    /* JADX WARN: Removed duplicated region for block: B:110:0x0296  */
    /* JADX WARN: Removed duplicated region for block: B:122:0x02e5  */
    /* JADX WARN: Removed duplicated region for block: B:84:0x0220  */
    /* JADX WARN: Removed duplicated region for block: B:85:0x0222  */
    /* JADX WARN: Removed duplicated region for block: B:89:0x022d  */
    /* JADX WARN: Removed duplicated region for block: B:93:0x0238  */
    /* JADX WARN: Removed duplicated region for block: B:99:0x024b  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private Path getLinePath(String str, Paint paint, Canvas canvas) {
        PathMeasure pathMeasure;
        double d;
        boolean z;
        boolean[] zArr;
        float[] fArr;
        GlyphContext glyphContext;
        GlyphPathBag glyphPathBag;
        double d2;
        double d3;
        int i;
        boolean z2;
        double d4;
        int i2;
        boolean z3;
        int i3;
        String str2;
        boolean z4;
        int i4;
        double d5;
        double d6;
        TSpanView tSpanView;
        Paint paint2;
        GlyphContext glyphContext2;
        int i5;
        int i6;
        float[] fArr2;
        float[] fArr3;
        int i7;
        GlyphPathBag glyphPathBag2;
        double d7;
        double d8;
        PathMeasure pathMeasure2;
        Matrix matrix;
        Path path;
        char c;
        double d9;
        GlyphContext glyphContext3;
        float[] fArr4;
        double d10;
        Path path2;
        String str3;
        boolean z5;
        Path orCreateAndCache;
        int i8;
        double d11;
        int i9;
        char c2;
        Rect rect;
        double d12;
        TSpanView tSpanView2 = this;
        Paint paint3 = paint;
        int length = str.length();
        Path path3 = new Path();
        tSpanView2.emoji.clear();
        tSpanView2.emojiTransforms.clear();
        if (length == 0) {
            return path3;
        }
        boolean z6 = tSpanView2.textPath != null;
        if (z6) {
            PathMeasure pathMeasure3 = new PathMeasure(tSpanView2.textPath.getTextPath(canvas, paint3), false);
            double length2 = pathMeasure3.getLength();
            boolean isClosed = pathMeasure3.isClosed();
            if (length2 == 0.0d) {
                return path3;
            }
            pathMeasure = pathMeasure3;
            d = length2;
            z = isClosed;
        } else {
            pathMeasure = null;
            d = 0.0d;
            z = false;
        }
        GlyphContext textRootGlyphContext = getTextRootGlyphContext();
        FontData font = textRootGlyphContext.getFont();
        tSpanView2.applyTextPropertiesToPaint(paint3, font);
        GlyphPathBag glyphPathBag3 = new GlyphPathBag(paint3);
        boolean[] zArr2 = new boolean[length];
        char[] charArray = str.toCharArray();
        Path path4 = path3;
        double d13 = font.kerning;
        double d14 = font.wordSpacing;
        double d15 = font.letterSpacing;
        boolean z7 = !font.manualKerning;
        if (d15 == 0.0d && font.fontVariantLigatures == TextProperties.FontVariantLigatures.normal) {
            paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'hlig', 'cala', " + font.fontFeatureSettings);
        } else {
            paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, " + font.fontFeatureSettings);
        }
        if (Build.VERSION.SDK_INT >= 26) {
            paint3.setFontVariationSettings(fontWeightTag + font.absoluteFontWeight + font.fontVariationSettings);
        }
        ReadableMap readableMap = font.fontData;
        float[] fArr5 = new float[length];
        paint3.getTextWidths(str, fArr5);
        TextProperties.TextAnchor textAnchor = font.textAnchor;
        PathMeasure pathMeasure4 = pathMeasure;
        double d16 = d15;
        double subtreeTextChunksTotalAdvance = getTextAnchorRoot().getSubtreeTextChunksTotalAdvance(paint3);
        double textAnchorOffset = tSpanView2.getTextAnchorOffset(textAnchor, subtreeTextChunksTotalAdvance);
        double fontSize = textRootGlyphContext.getFontSize();
        if (z6) {
            boolean z8 = tSpanView2.textPath.getMidLine() == TextProperties.TextPathMidLine.sharp;
            int i10 = tSpanView2.textPath.getSide() == TextProperties.TextPathSide.right ? -1 : 1;
            boolean z9 = z8;
            zArr = zArr2;
            fArr = fArr5;
            glyphContext = textRootGlyphContext;
            glyphPathBag = glyphPathBag3;
            double absoluteStartOffset = getAbsoluteStartOffset(tSpanView2.textPath.getStartOffset(), d, fontSize);
            textAnchorOffset += absoluteStartOffset;
            if (z) {
                d3 = absoluteStartOffset + (textAnchor == TextProperties.TextAnchor.middle ? -(d / 2.0d) : 0.0d);
                d2 = d3 + d;
            } else {
                d2 = d;
                d3 = 0.0d;
            }
            i = i10;
            z2 = z9;
        } else {
            zArr = zArr2;
            fArr = fArr5;
            glyphContext = textRootGlyphContext;
            glyphPathBag = glyphPathBag3;
            d2 = d;
            d3 = 0.0d;
            i = 1;
            z2 = false;
        }
        double d17 = d;
        double d18 = 1.0d;
        if (tSpanView2.mTextLength != null) {
            d4 = d3;
            double fromRelative = PropHelper.fromRelative(tSpanView2.mTextLength, canvas.getWidth(), 0.0d, tSpanView2.mScale, fontSize);
            if (fromRelative < 0.0d) {
                throw new IllegalArgumentException("Negative textLength value");
            }
            if (AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[tSpanView2.mLengthAdjust.ordinal()] != 2) {
                d16 += (fromRelative - subtreeTextChunksTotalAdvance) / (length - 1);
            } else {
                d18 = fromRelative / subtreeTextChunksTotalAdvance;
            }
        } else {
            d4 = d3;
        }
        double d19 = i;
        Paint.FontMetrics fontMetrics = paint.getFontMetrics();
        double d20 = fontMetrics.descent;
        int i11 = i;
        double d21 = d18 * d19;
        double d22 = fontMetrics.leading + d20;
        boolean z10 = z2;
        double d23 = (-fontMetrics.ascent) + fontMetrics.leading;
        double d24 = d2;
        double d25 = -fontMetrics.top;
        double d26 = d25 + d22;
        String baselineShift = getBaselineShift();
        TextProperties.AlignmentBaseline alignmentBaseline = getAlignmentBaseline();
        if (alignmentBaseline != null) {
            switch (alignmentBaseline) {
                case textBottom:
                case afterEdge:
                case textAfterEdge:
                case ideographic:
                    d22 = -d20;
                    break;
                case middle:
                    paint3.getTextBounds(ViewHierarchyNode.JsonKeys.X, 0, 1, new Rect());
                    d22 = rect.height() / 2.0d;
                    break;
                case central:
                    d22 = (d23 - d20) / 2.0d;
                    break;
                case mathematical:
                    d12 = 0.5d;
                    d22 = d23 * d12;
                    break;
                case hanging:
                    d12 = 0.8d;
                    d22 = d23 * d12;
                    break;
                case textTop:
                case beforeEdge:
                case textBeforeEdge:
                    d22 = d23;
                    break;
                case center:
                    d22 = d26 / 2.0d;
                    break;
                case top:
                    d22 = d25;
                    break;
            }
            if (baselineShift != null && !baselineShift.isEmpty() && (i9 = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[alignmentBaseline.ordinal()]) != 14 && i9 != 16) {
                baselineShift.hashCode();
                switch (baselineShift.hashCode()) {
                    case -1720785339:
                        if (baselineShift.equals("baseline")) {
                            c2 = 0;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 114240:
                        if (baselineShift.equals("sub")) {
                            c2 = 1;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 109801339:
                        if (baselineShift.equals("super")) {
                            c2 = 2;
                            break;
                        }
                        c2 = 65535;
                        break;
                    default:
                        c2 = 65535;
                        break;
                }
                switch (c2) {
                    case 0:
                        break;
                    case 1:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i12 = readableMap.getInt("unitsPerEm");
                            ReadableMap map = readableMap.getMap("tables");
                            if (map.hasKey("os2")) {
                                ReadableMap map2 = map.getMap("os2");
                                if (map2.hasKey("ySubscriptYOffset")) {
                                    d22 += ((tSpanView2.mScale * fontSize) * map2.getDouble("ySubscriptYOffset")) / i12;
                                    break;
                                }
                            }
                        }
                        break;
                    case 2:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i13 = readableMap.getInt("unitsPerEm");
                            ReadableMap map3 = readableMap.getMap("tables");
                            if (map3.hasKey("os2")) {
                                ReadableMap map4 = map3.getMap("os2");
                                if (map4.hasKey("ySuperscriptYOffset")) {
                                    d22 -= ((tSpanView2.mScale * fontSize) * map4.getDouble("ySuperscriptYOffset")) / i13;
                                    break;
                                }
                            }
                        }
                        break;
                    default:
                        d22 -= PropHelper.fromRelative(baselineShift, tSpanView2.mScale * fontSize, tSpanView2.mScale, fontSize);
                        break;
                }
            }
            double d27 = d22;
            Matrix matrix2 = new Matrix();
            Matrix matrix3 = new Matrix();
            Matrix matrix4 = new Matrix();
            float[] fArr6 = new float[9];
            float[] fArr7 = new float[9];
            i2 = 0;
            while (i2 < length) {
                char c3 = charArray[i2];
                String valueOf = String.valueOf(c3);
                boolean z11 = zArr[i2];
                if (z11) {
                    str2 = "";
                    i3 = length;
                    z3 = false;
                } else {
                    String str4 = valueOf;
                    int i14 = i2;
                    z3 = false;
                    while (true) {
                        int i15 = i14 + 1;
                        if (i15 < length && fArr[i15] <= 0.0f) {
                            str4 = str4 + charArray[i15];
                            zArr[i15] = true;
                            i14 = i15;
                            length = length;
                            z3 = true;
                        }
                    }
                    i3 = length;
                    str2 = str4;
                }
                double measureText = paint3.measureText(str2) * d18;
                String str5 = str2;
                if (z7) {
                    z4 = z3;
                    i4 = i2;
                    d13 = (fArr[i2] * d18) - measureText;
                } else {
                    z4 = z3;
                    i4 = i2;
                }
                boolean z12 = c3 == ' ';
                double d28 = (z12 ? d14 : 0.0d) + d16 + measureText;
                if (z11) {
                    d5 = d27;
                    d6 = 0.0d;
                } else {
                    d5 = d27;
                    d6 = d13 + d28;
                }
                double nextX = glyphContext.nextX(d6);
                float[] fArr8 = fArr7;
                float[] fArr9 = fArr6;
                double nextY = glyphContext.nextY();
                double nextDeltaX = glyphContext.nextDeltaX();
                double nextDeltaY = glyphContext.nextDeltaY();
                double nextRotation = glyphContext.nextRotation();
                if (!z11 && !z12) {
                    double d29 = measureText * d19;
                    double d30 = (textAnchorOffset + ((nextX + nextDeltaX) * d19)) - (d28 * d19);
                    if (z6) {
                        double d31 = d30 + d29;
                        double d32 = d29 / 2.0d;
                        c = c3;
                        double d33 = d30 + d32;
                        if (d33 <= d24 && d33 >= d4) {
                            glyphContext3 = glyphContext;
                            if (z10) {
                                pathMeasure4.getMatrix((float) d33, matrix3, 3);
                                d9 = nextRotation;
                                fArr4 = fArr9;
                            } else {
                                d9 = nextRotation;
                                PathMeasure pathMeasure5 = pathMeasure4;
                                if (d30 < 0.0d) {
                                    pathMeasure5.getMatrix(0.0f, matrix2, 3);
                                    matrix2.preTranslate((float) d30, 0.0f);
                                    i8 = 1;
                                } else {
                                    i8 = 1;
                                    pathMeasure5.getMatrix((float) d30, matrix2, 1);
                                }
                                pathMeasure5.getMatrix((float) d33, matrix3, i8);
                                if (d31 > d17) {
                                    d11 = d17;
                                    pathMeasure5.getMatrix((float) d11, matrix4, 3);
                                    matrix4.preTranslate((float) (d31 - d11), 0.0f);
                                } else {
                                    d11 = d17;
                                    pathMeasure5.getMatrix((float) d31, matrix4, i8);
                                }
                                fArr4 = fArr9;
                                matrix2.getValues(fArr4);
                                matrix4.getValues(fArr8);
                                d17 = d11;
                                pathMeasure4 = pathMeasure5;
                                matrix3.preRotate((float) (Math.atan2(fArr8[5] - fArr4[5], fArr8[2] - fArr4[2]) * radToDeg * d19));
                            }
                            matrix3.preTranslate((float) (-d32), (float) (nextDeltaY + d5));
                            d10 = d21;
                            i7 = i11;
                            matrix3.preScale((float) d10, i7);
                            matrix3.postTranslate(0.0f, (float) nextY);
                        }
                    } else {
                        c = c3;
                        d9 = nextRotation;
                        glyphContext3 = glyphContext;
                        fArr4 = fArr9;
                        i7 = i11;
                        d10 = d21;
                        matrix3.setTranslate((float) d30, (float) (nextY + nextDeltaY + d5));
                    }
                    matrix3.preRotate((float) d9);
                    if (z4) {
                        Path path5 = new Path();
                        d7 = d17;
                        i6 = i4;
                        pathMeasure2 = pathMeasure4;
                        d8 = d10;
                        fArr3 = fArr8;
                        fArr2 = fArr4;
                        z5 = true;
                        Path path6 = path4;
                        matrix = matrix4;
                        path2 = path6;
                        i5 = i3;
                        paint.getTextPath(str5, 0, str5.length(), 0.0f, 0.0f, path5);
                        orCreateAndCache = path5;
                        str3 = str5;
                        glyphPathBag2 = glyphPathBag;
                    } else {
                        fArr2 = fArr4;
                        path2 = path4;
                        char c4 = c;
                        i5 = i3;
                        str3 = str5;
                        i6 = i4;
                        fArr3 = fArr8;
                        glyphPathBag2 = glyphPathBag;
                        d7 = d17;
                        z5 = true;
                        d8 = d10;
                        matrix = matrix4;
                        pathMeasure2 = pathMeasure4;
                        orCreateAndCache = glyphPathBag2.getOrCreateAndCache(c4, str3);
                    }
                    RectF rectF = new RectF();
                    orCreateAndCache.computeBounds(rectF, z5);
                    if (rectF.width() == 0.0f) {
                        canvas.save();
                        glyphContext2 = glyphContext3;
                        canvas.concat(matrix3);
                        tSpanView = this;
                        tSpanView.emoji.add(str3);
                        tSpanView.emojiTransforms.add(new Matrix(matrix3));
                        paint2 = paint;
                        canvas.drawText(str3, 0.0f, 0.0f, paint2);
                        canvas.restore();
                        path = path2;
                    } else {
                        tSpanView = this;
                        paint2 = paint;
                        glyphContext2 = glyphContext3;
                        orCreateAndCache.transform(matrix3);
                        path = path2;
                        path.addPath(orCreateAndCache);
                    }
                    glyphPathBag = glyphPathBag2;
                    glyphContext = glyphContext2;
                    length = i5;
                    fArr7 = fArr3;
                    pathMeasure4 = pathMeasure2;
                    d17 = d7;
                    d21 = d8;
                    i11 = i7;
                    tSpanView2 = tSpanView;
                    paint3 = paint2;
                    fArr6 = fArr2;
                    i2 = i6 + 1;
                    d27 = d5;
                    Matrix matrix5 = matrix;
                    path4 = path;
                    matrix4 = matrix5;
                }
                tSpanView = this;
                paint2 = paint;
                glyphContext2 = glyphContext;
                i5 = i3;
                i6 = i4;
                fArr2 = fArr9;
                fArr3 = fArr8;
                i7 = i11;
                glyphPathBag2 = glyphPathBag;
                d7 = d17;
                d8 = d21;
                pathMeasure2 = pathMeasure4;
                Path path7 = path4;
                matrix = matrix4;
                path = path7;
                glyphPathBag = glyphPathBag2;
                glyphContext = glyphContext2;
                length = i5;
                fArr7 = fArr3;
                pathMeasure4 = pathMeasure2;
                d17 = d7;
                d21 = d8;
                i11 = i7;
                tSpanView2 = tSpanView;
                paint3 = paint2;
                fArr6 = fArr2;
                i2 = i6 + 1;
                d27 = d5;
                Matrix matrix52 = matrix;
                path4 = path;
                matrix4 = matrix52;
            }
            return path4;
        }
        d22 = 0.0d;
        if (baselineShift != null) {
            baselineShift.hashCode();
            switch (baselineShift.hashCode()) {
                case -1720785339:
                    break;
                case 114240:
                    break;
                case 109801339:
                    break;
            }
            switch (c2) {
            }
        }
        double d272 = d22;
        Matrix matrix22 = new Matrix();
        Matrix matrix32 = new Matrix();
        Matrix matrix42 = new Matrix();
        float[] fArr62 = new float[9];
        float[] fArr72 = new float[9];
        i2 = 0;
        while (i2 < length) {
        }
        return path4;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.horcrux.svg.TSpanView$1  reason: invalid class name */
    /* loaded from: classes2.dex */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor;
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust;

        static {
            int[] iArr = new int[TextProperties.AlignmentBaseline.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline = iArr;
            try {
                iArr[TextProperties.AlignmentBaseline.baseline.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBottom.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.afterEdge.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textAfterEdge.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.alphabetic.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.ideographic.ordinal()] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.middle.ordinal()] = 7;
            } catch (NoSuchFieldError unused7) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.central.ordinal()] = 8;
            } catch (NoSuchFieldError unused8) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.mathematical.ordinal()] = 9;
            } catch (NoSuchFieldError unused9) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.hanging.ordinal()] = 10;
            } catch (NoSuchFieldError unused10) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textTop.ordinal()] = 11;
            } catch (NoSuchFieldError unused11) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.beforeEdge.ordinal()] = 12;
            } catch (NoSuchFieldError unused12) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBeforeEdge.ordinal()] = 13;
            } catch (NoSuchFieldError unused13) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.bottom.ordinal()] = 14;
            } catch (NoSuchFieldError unused14) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.center.ordinal()] = 15;
            } catch (NoSuchFieldError unused15) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.top.ordinal()] = 16;
            } catch (NoSuchFieldError unused16) {
            }
            int[] iArr2 = new int[TextProperties.TextLengthAdjust.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust = iArr2;
            try {
                iArr2[TextProperties.TextLengthAdjust.spacing.ordinal()] = 1;
            } catch (NoSuchFieldError unused17) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[TextProperties.TextLengthAdjust.spacingAndGlyphs.ordinal()] = 2;
            } catch (NoSuchFieldError unused18) {
            }
            int[] iArr3 = new int[TextProperties.TextAnchor.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor = iArr3;
            try {
                iArr3[TextProperties.TextAnchor.start.ordinal()] = 1;
            } catch (NoSuchFieldError unused19) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.middle.ordinal()] = 2;
            } catch (NoSuchFieldError unused20) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.end.ordinal()] = 3;
            } catch (NoSuchFieldError unused21) {
            }
        }
    }

    private double getAbsoluteStartOffset(SVGLength sVGLength, double d, double d2) {
        return PropHelper.fromRelative(sVGLength, d, 0.0d, this.mScale, d2);
    }

    private double getTextAnchorOffset(TextProperties.TextAnchor textAnchor, double d) {
        int i = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[textAnchor.ordinal()];
        if (i != 2) {
            if (i != 3) {
                return 0.0d;
            }
            return -d;
        }
        return (-d) / 2.0d;
    }

    private void applyTextPropertiesToPaint(Paint paint, FontData fontData) {
        int i = 0;
        boolean z = fontData.fontWeight == TextProperties.FontWeight.Bold || fontData.absoluteFontWeight >= 550;
        boolean z2 = fontData.fontStyle == TextProperties.FontStyle.italic;
        if (z && z2) {
            i = 3;
        } else if (z) {
            i = 1;
        } else if (z2) {
            i = 2;
        }
        int i2 = fontData.absoluteFontWeight;
        String str = fontData.fontFamily;
        Typeface typeface = null;
        if (str != null && str.length() > 0) {
            String str2 = FONTS + str + OTF;
            String str3 = FONTS + str + TTF;
            if (Build.VERSION.SDK_INT >= 26) {
                Typeface.Builder builder = new Typeface.Builder(this.assets, str2);
                builder.setFontVariationSettings(fontWeightTag + i2 + fontData.fontVariationSettings);
                builder.setWeight(i2);
                builder.setItalic(z2);
                typeface = builder.build();
                if (typeface == null) {
                    Typeface.Builder builder2 = new Typeface.Builder(this.assets, str3);
                    builder2.setFontVariationSettings(fontWeightTag + i2 + fontData.fontVariationSettings);
                    builder2.setWeight(i2);
                    builder2.setItalic(z2);
                    typeface = builder2.build();
                }
            } else {
                try {
                    try {
                        typeface = Typeface.create(Typeface.createFromAsset(this.assets, str2), i);
                    } catch (Exception unused) {
                        typeface = Typeface.create(Typeface.createFromAsset(this.assets, str3), i);
                    }
                } catch (Exception unused2) {
                }
            }
        }
        if (typeface == null) {
            try {
                typeface = ReactFontManager.getInstance().getTypeface(str, i, this.assets);
            } catch (Exception unused3) {
            }
        }
        if (Build.VERSION.SDK_INT >= 28) {
            typeface = Typeface.create(typeface, i2, z2);
        }
        paint.setLinearText(true);
        paint.setSubpixelText(true);
        paint.setTypeface(typeface);
        paint.setTextSize((float) (fontData.fontSize * this.mScale));
        paint.setLetterSpacing(0.0f);
    }

    private void setupTextPath() {
        for (ViewParent parent = getParent(); parent != null; parent = parent.getParent()) {
            if (parent.getClass() == TextPathView.class) {
                this.textPath = (TextPathView) parent;
                return;
            } else if (!(parent instanceof TextView)) {
                return;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // com.horcrux.svg.GroupView, com.horcrux.svg.RenderableView, com.horcrux.svg.VirtualView
    public int hitTest(float[] fArr) {
        if (this.mContent == null) {
            return super.hitTest(fArr);
        }
        if (this.mPath != null && this.mInvertible && this.mTransformInvertible) {
            float[] fArr2 = new float[2];
            this.mInvMatrix.mapPoints(fArr2, fArr);
            this.mInvTransform.mapPoints(fArr2);
            int round = Math.round(fArr2[0]);
            int round2 = Math.round(fArr2[1]);
            initBounds();
            if ((this.mRegion != null && this.mRegion.contains(round, round2)) || (this.mStrokeRegion != null && this.mStrokeRegion.contains(round, round2))) {
                if (getClipPath() == null || this.mClipRegion.contains(round, round2)) {
                    return getId();
                }
                return -1;
            }
        }
        return -1;
    }
}
