package com.mrousavy.camera.frameprocessor;

import android.util.Log;
import com.facebook.jni.HybridData;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.UIManager;
import com.facebook.react.turbomodule.core.CallInvokerHolderImpl;
import com.facebook.react.turbomodule.core.interfaces.CallInvokerHolder;
import com.facebook.react.uimanager.UIManagerHelper;
import com.mrousavy.camera.CameraView;
import com.mrousavy.camera.ViewNotFoundError;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.concurrent.ExecutorService;
import kotlin.Metadata;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
/* compiled from: FrameProcessorRuntimeManager.kt */
@Metadata(d1 = {"\u0000V\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\b\n\u0002\b\u0002\n\u0002\u0010\t\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0003\u0018\u0000 \u001e2\u00020\u0001:\u0001\u001eB\u0015\u0012\u0006\u0010\u0002\u001a\u00020\u0003\u0012\u0006\u0010\u0004\u001a\u00020\u0005¢\u0006\u0002\u0010\u0006J\u0010\u0010\r\u001a\u00020\u000e2\u0006\u0010\u000f\u001a\u00020\u0010H\u0007J!\u0010\u0011\u001a\u00020\n2\u0006\u0010\u0012\u001a\u00020\u00132\u0006\u0010\u0014\u001a\u00020\u00152\u0006\u0010\u0016\u001a\u00020\fH\u0082 J\t\u0010\u0017\u001a\u00020\u0018H\u0082 J\t\u0010\u0019\u001a\u00020\u0018H\u0082 J\u0011\u0010\u001a\u001a\u00020\u00182\u0006\u0010\u001b\u001a\u00020\u001cH\u0082 J\b\u0010\u001d\u001a\u00020\u0018H\u0007R\u0016\u0010\u0007\u001a\n\u0012\u0004\u0012\u00020\u0003\u0018\u00010\bX\u0082\u000e¢\u0006\u0002\n\u0000R\u0014\u0010\t\u001a\u0004\u0018\u00010\n8\u0002@\u0002X\u0083\u000e¢\u0006\u0002\n\u0000R\u0010\u0010\u000b\u001a\u0004\u0018\u00010\fX\u0082\u000e¢\u0006\u0002\n\u0000¨\u0006\u001f"}, d2 = {"Lcom/mrousavy/camera/frameprocessor/FrameProcessorRuntimeManager;", "", "context", "Lcom/facebook/react/bridge/ReactApplicationContext;", "frameProcessorThread", "Ljava/util/concurrent/ExecutorService;", "(Lcom/facebook/react/bridge/ReactApplicationContext;Ljava/util/concurrent/ExecutorService;)V", "mContext", "Ljava/lang/ref/WeakReference;", "mHybridData", "Lcom/facebook/jni/HybridData;", "mScheduler", "Lcom/mrousavy/camera/frameprocessor/VisionCameraScheduler;", "findCameraViewById", "Lcom/mrousavy/camera/CameraView;", "viewId", "", "initHybrid", "jsContext", "", "jsCallInvokerHolder", "Lcom/facebook/react/turbomodule/core/CallInvokerHolderImpl;", "scheduler", "initializeRuntime", "", "installJSIBindings", "registerPlugin", "plugin", "Lcom/mrousavy/camera/frameprocessor/FrameProcessorPlugin;", "registerPlugins", "Companion", "react-native-vision-camera_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes2.dex */
public final class FrameProcessorRuntimeManager {
    public static final Companion Companion = new Companion(null);
    private static final ArrayList<FrameProcessorPlugin> Plugins = new ArrayList<>();
    public static final String TAG = "FrameProcessorRuntime";
    private static boolean enableFrameProcessors;
    private WeakReference<ReactApplicationContext> mContext;
    private HybridData mHybridData;
    private VisionCameraScheduler mScheduler;

    private final native HybridData initHybrid(long j, CallInvokerHolderImpl callInvokerHolderImpl, VisionCameraScheduler visionCameraScheduler);

    private final native void initializeRuntime();

    private final native void installJSIBindings();

    private final native void registerPlugin(FrameProcessorPlugin frameProcessorPlugin);

    public FrameProcessorRuntimeManager(ReactApplicationContext context, ExecutorService frameProcessorThread) {
        Intrinsics.checkNotNullParameter(context, "context");
        Intrinsics.checkNotNullParameter(frameProcessorThread, "frameProcessorThread");
        if (enableFrameProcessors) {
            CallInvokerHolder jSCallInvokerHolder = context.getCatalystInstance().getJSCallInvokerHolder();
            Intrinsics.checkNotNull(jSCallInvokerHolder, "null cannot be cast to non-null type com.facebook.react.turbomodule.core.CallInvokerHolderImpl");
            this.mScheduler = new VisionCameraScheduler(frameProcessorThread);
            this.mContext = new WeakReference<>(context);
            long j = context.getJavaScriptContextHolder().get();
            VisionCameraScheduler visionCameraScheduler = this.mScheduler;
            Intrinsics.checkNotNull(visionCameraScheduler);
            this.mHybridData = initHybrid(j, (CallInvokerHolderImpl) jSCallInvokerHolder, visionCameraScheduler);
            initializeRuntime();
            Log.i(TAG, "Installing JSI Bindings on JS Thread...");
            context.runOnJSQueueThread(new Runnable() { // from class: com.mrousavy.camera.frameprocessor.FrameProcessorRuntimeManager$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    FrameProcessorRuntimeManager.m417_init_$lambda0(FrameProcessorRuntimeManager.this);
                }
            });
        }
    }

    /* compiled from: FrameProcessorRuntimeManager.kt */
    @Metadata(d1 = {"\u0000*\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u000e\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R!\u0010\u0003\u001a\u0012\u0012\u0004\u0012\u00020\u00050\u0004j\b\u0012\u0004\u0012\u00020\u0005`\u0006¢\u0006\b\n\u0000\u001a\u0004\b\u0007\u0010\bR\u000e\u0010\t\u001a\u00020\nX\u0086T¢\u0006\u0002\n\u0000R\u001a\u0010\u000b\u001a\u00020\fX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\r\u0010\u000e\"\u0004\b\u000f\u0010\u0010¨\u0006\u0011"}, d2 = {"Lcom/mrousavy/camera/frameprocessor/FrameProcessorRuntimeManager$Companion;", "", "()V", "Plugins", "Ljava/util/ArrayList;", "Lcom/mrousavy/camera/frameprocessor/FrameProcessorPlugin;", "Lkotlin/collections/ArrayList;", "getPlugins", "()Ljava/util/ArrayList;", "TAG", "", "enableFrameProcessors", "", "getEnableFrameProcessors", "()Z", "setEnableFrameProcessors", "(Z)V", "react-native-vision-camera_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final ArrayList<FrameProcessorPlugin> getPlugins() {
            return FrameProcessorRuntimeManager.Plugins;
        }

        public final boolean getEnableFrameProcessors() {
            return FrameProcessorRuntimeManager.enableFrameProcessors;
        }

        public final void setEnableFrameProcessors(boolean z) {
            FrameProcessorRuntimeManager.enableFrameProcessors = z;
        }
    }

    static {
        enableFrameProcessors = true;
        try {
            System.loadLibrary("reanimated");
            System.loadLibrary("VisionCamera");
        } catch (UnsatisfiedLinkError unused) {
            Log.w(TAG, "Failed to load Reanimated/VisionCamera C++ library. Frame Processors are disabled!");
            enableFrameProcessors = false;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: _init_$lambda-0  reason: not valid java name */
    public static final void m417_init_$lambda0(FrameProcessorRuntimeManager this$0) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        this$0.installJSIBindings();
    }

    public final CameraView findCameraViewById(int i) {
        Log.d(TAG, "Finding view " + i + "...");
        WeakReference<ReactApplicationContext> weakReference = this.mContext;
        CameraView cameraView = null;
        ReactApplicationContext reactApplicationContext = weakReference != null ? weakReference.get() : null;
        if (reactApplicationContext != null) {
            UIManager uIManager = UIManagerHelper.getUIManager(reactApplicationContext, i);
            cameraView = (CameraView) (uIManager != null ? uIManager.resolveView(i) : null);
        }
        StringBuilder sb = cameraView != null ? new StringBuilder("Found view ") : new StringBuilder("Couldn't find view ");
        sb.append(i);
        sb.append('!');
        Log.d(TAG, sb.toString());
        if (cameraView != null) {
            return cameraView;
        }
        throw new ViewNotFoundError(i);
    }

    public final void registerPlugins() {
        Log.i(TAG, "Installing Frame Processor Plugins...");
        for (FrameProcessorPlugin frameProcessorPlugin : Plugins) {
            registerPlugin(frameProcessorPlugin);
        }
        Log.i(TAG, "Successfully installed " + Plugins.size() + " Frame Processor Plugins!");
    }
}
