package expo.modules.clipboard;

import android.content.ClipData;
import android.content.ClipDescription;
import android.content.ClipboardManager;
import android.content.Context;
import android.os.Build;
import android.util.Log;
import androidx.core.os.BundleKt;
import com.google.android.gms.common.internal.ServiceSpecificExtraArgs;
import expo.modules.clipboard.ClipboardModule;
import expo.modules.imagepicker.MediaTypes;
import expo.modules.kotlin.Promise;
import expo.modules.kotlin.events.BasicEventListener;
import expo.modules.kotlin.events.EventName;
import expo.modules.kotlin.functions.AsyncFunctionBuilder;
import expo.modules.kotlin.functions.AsyncFunctionComponent;
import expo.modules.kotlin.functions.AsyncFunctionWithPromiseComponent;
import expo.modules.kotlin.functions.SuspendFunctionComponent;
import expo.modules.kotlin.modules.Module;
import expo.modules.kotlin.modules.ModuleDefinitionBuilder;
import expo.modules.kotlin.modules.ModuleDefinitionData;
import expo.modules.kotlin.types.AnyType;
import expo.modules.kotlin.types.AnyTypeKt;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.Result;
import kotlin.ResultKt;
import kotlin.TuplesKt;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Reflection;
/* compiled from: ClipboardModule.kt */
@Metadata(d1 = {"\u0000F\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u000b\n\u0000\n\u0002\u0010\u000e\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\u0018\u00002\u00020\u0001:\u0001\u001dB\u0005¢\u0006\u0002\u0010\u0002J\u0010\u0010\u0017\u001a\u00020\u00182\u0006\u0010\u0019\u001a\u00020\u001aH\u0002J\b\u0010\u001b\u001a\u00020\u001cH\u0016R\u001b\u0010\u0003\u001a\u00020\u00048BX\u0082\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006R\u0012\u0010\t\u001a\u00060\nR\u00020\u0000X\u0082.¢\u0006\u0002\n\u0000R\u0014\u0010\u000b\u001a\u00020\f8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\r\u0010\u000eR\u0014\u0010\u000f\u001a\u00020\u00108BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u0011\u0010\u0012R\u001a\u0010\u0013\u001a\u0004\u0018\u00010\u0014*\u00020\f8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u0015\u0010\u0016¨\u0006\u001e"}, d2 = {"Lexpo/modules/clipboard/ClipboardModule;", "Lexpo/modules/kotlin/modules/Module;", "()V", "clipboardCacheDir", "Ljava/io/File;", "getClipboardCacheDir", "()Ljava/io/File;", "clipboardCacheDir$delegate", "Lkotlin/Lazy;", "clipboardEventEmitter", "Lexpo/modules/clipboard/ClipboardModule$ClipboardEventEmitter;", "clipboardManager", "Landroid/content/ClipboardManager;", "getClipboardManager", "()Landroid/content/ClipboardManager;", "context", "Landroid/content/Context;", "getContext", "()Landroid/content/Context;", "firstItem", "Landroid/content/ClipData$Item;", "getFirstItem", "(Landroid/content/ClipboardManager;)Landroid/content/ClipData$Item;", "clipboardHasItemWithType", "", "mimeType", "", "definition", "Lexpo/modules/kotlin/modules/ModuleDefinitionData;", "ClipboardEventEmitter", "expo-clipboard_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class ClipboardModule extends Module {
    private final Lazy clipboardCacheDir$delegate = LazyKt.lazy(new ClipboardModule$clipboardCacheDir$2(this));
    private ClipboardEventEmitter clipboardEventEmitter;

    /* compiled from: ClipboardModule.kt */
    @Metadata(k = 3, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes3.dex */
    public /* synthetic */ class WhenMappings {
        public static final /* synthetic */ int[] $EnumSwitchMapping$0;

        static {
            int[] iArr = new int[StringFormat.values().length];
            iArr[StringFormat.PLAIN.ordinal()] = 1;
            iArr[StringFormat.HTML.ordinal()] = 2;
            $EnumSwitchMapping$0 = iArr;
        }
    }

    @Override // expo.modules.kotlin.modules.Module
    public ModuleDefinitionData definition() {
        AsyncFunctionComponent asyncFunctionComponent;
        AsyncFunctionComponent asyncFunctionComponent2;
        ModuleDefinitionBuilder moduleDefinitionBuilder = new ModuleDefinitionBuilder(this);
        moduleDefinitionBuilder.Name("ExpoClipboard");
        ModuleDefinitionBuilder moduleDefinitionBuilder2 = moduleDefinitionBuilder;
        if (Intrinsics.areEqual(Reflection.getOrCreateKotlinClass(GetStringOptions.class), Reflection.getOrCreateKotlinClass(Promise.class))) {
            asyncFunctionComponent = new AsyncFunctionWithPromiseComponent("getStringAsync", new AnyType[0], new ClipboardModule$definition$lambda12$$inlined$AsyncFunction$1(this));
        } else {
            asyncFunctionComponent = new AsyncFunctionComponent("getStringAsync", new AnyType[]{AnyTypeKt.toAnyType(Reflection.typeOf(GetStringOptions.class))}, new ClipboardModule$definition$lambda12$$inlined$AsyncFunction$2(this));
        }
        moduleDefinitionBuilder2.getAsyncFunctions().put("getStringAsync", asyncFunctionComponent);
        if (Intrinsics.areEqual(Reflection.getOrCreateKotlinClass(SetStringOptions.class), Reflection.getOrCreateKotlinClass(Promise.class))) {
            asyncFunctionComponent2 = new AsyncFunctionWithPromiseComponent("setStringAsync", new AnyType[]{AnyTypeKt.toAnyType(Reflection.typeOf(String.class))}, new ClipboardModule$definition$lambda12$$inlined$AsyncFunction$3(this));
        } else {
            asyncFunctionComponent2 = new AsyncFunctionComponent("setStringAsync", new AnyType[]{AnyTypeKt.toAnyType(Reflection.typeOf(String.class)), AnyTypeKt.toAnyType(Reflection.typeOf(SetStringOptions.class))}, new ClipboardModule$definition$lambda12$$inlined$AsyncFunction$4(this));
        }
        moduleDefinitionBuilder2.getAsyncFunctions().put("setStringAsync", asyncFunctionComponent2);
        moduleDefinitionBuilder2.getAsyncFunctions().put("hasStringAsync", new AsyncFunctionComponent("hasStringAsync", new AnyType[0], new ClipboardModule$definition$lambda12$$inlined$AsyncFunctionWithoutArgs$1(this)));
        AsyncFunctionBuilder AsyncFunction = moduleDefinitionBuilder.AsyncFunction("getImageAsync");
        AsyncFunction.setSuspendFunctionComponent(new SuspendFunctionComponent(AsyncFunction.getName(), new AnyType[]{AnyTypeKt.toAnyType(Reflection.typeOf(GetImageOptions.class))}, new ClipboardModule$definition$lambda12$$inlined$Coroutine$1(null, this)));
        AsyncFunctionBuilder AsyncFunction2 = moduleDefinitionBuilder.AsyncFunction("setImageAsync");
        AsyncFunction2.setSuspendFunctionComponent(new SuspendFunctionComponent(AsyncFunction2.getName(), new AnyType[]{AnyTypeKt.toAnyType(Reflection.typeOf(String.class))}, new ClipboardModule$definition$lambda12$$inlined$Coroutine$2(null, this)));
        moduleDefinitionBuilder2.getAsyncFunctions().put("hasImageAsync", new AsyncFunctionComponent("hasImageAsync", new AnyType[0], new ClipboardModule$definition$lambda12$$inlined$AsyncFunctionWithoutArgs$2(this)));
        moduleDefinitionBuilder.Events(ClipboardModuleKt.CLIPBOARD_CHANGED_EVENT_NAME);
        moduleDefinitionBuilder.getEventListeners().put(EventName.MODULE_CREATE, new BasicEventListener(EventName.MODULE_CREATE, new ClipboardModule$definition$lambda12$$inlined$OnCreate$1(this)));
        moduleDefinitionBuilder.getEventListeners().put(EventName.MODULE_DESTROY, new BasicEventListener(EventName.MODULE_DESTROY, new ClipboardModule$definition$lambda12$$inlined$OnDestroy$1(this)));
        moduleDefinitionBuilder.getEventListeners().put(EventName.ACTIVITY_ENTERS_BACKGROUND, new BasicEventListener(EventName.ACTIVITY_ENTERS_BACKGROUND, new ClipboardModule$definition$lambda12$$inlined$OnActivityEntersBackground$1(this)));
        moduleDefinitionBuilder.getEventListeners().put(EventName.ACTIVITY_ENTERS_FOREGROUND, new BasicEventListener(EventName.ACTIVITY_ENTERS_FOREGROUND, new ClipboardModule$definition$lambda12$$inlined$OnActivityEntersForeground$1(this)));
        return moduleDefinitionBuilder.buildModule();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final Context getContext() {
        Context reactContext = getAppContext().getReactContext();
        if (reactContext != null) {
            return reactContext;
        }
        throw new IllegalArgumentException("React Application Context is null".toString());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final ClipboardManager getClipboardManager() {
        Object systemService = getContext().getSystemService("clipboard");
        ClipboardManager clipboardManager = systemService instanceof ClipboardManager ? (ClipboardManager) systemService : null;
        if (clipboardManager != null) {
            return clipboardManager;
        }
        throw new ClipboardUnavailableException();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final File getClipboardCacheDir() {
        return (File) this.clipboardCacheDir$delegate.getValue();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* compiled from: ClipboardModule.kt */
    @Metadata(d1 = {"\u0000.\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000b\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\t\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0004\b\u0082\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u0006\u0010\u000b\u001a\u00020\u0001J\r\u0010\f\u001a\u0004\u0018\u00010\r¢\u0006\u0002\u0010\u000eJ\u0006\u0010\u000f\u001a\u00020\rJ\u0006\u0010\u0010\u001a\u00020\rR\u000e\u0010\u0003\u001a\u00020\u0004X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u0010\u0010\u0007\u001a\u0004\u0018\u00010\bX\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u0082\u000e¢\u0006\u0002\n\u0000¨\u0006\u0011"}, d2 = {"Lexpo/modules/clipboard/ClipboardModule$ClipboardEventEmitter;", "", "(Lexpo/modules/clipboard/ClipboardModule;)V", "isListening", "", ServiceSpecificExtraArgs.CastExtraArgs.LISTENER, "Landroid/content/ClipboardManager$OnPrimaryClipChangedListener;", "maybeClipboardManager", "Landroid/content/ClipboardManager;", "timestamp", "", "attachListener", "detachListener", "", "()Lkotlin/Unit;", "pauseListening", "resumeListening", "expo-clipboard_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes3.dex */
    public final class ClipboardEventEmitter {
        private final ClipboardManager.OnPrimaryClipChangedListener listener;
        private final ClipboardManager maybeClipboardManager;
        private boolean isListening = true;
        private long timestamp = -1;

        public ClipboardEventEmitter() {
            Object m683constructorimpl;
            this.listener = new ClipboardManager.OnPrimaryClipChangedListener() { // from class: expo.modules.clipboard.ClipboardModule$ClipboardEventEmitter$$ExternalSyntheticLambda0
                @Override // android.content.ClipboardManager.OnPrimaryClipChangedListener
                public final void onPrimaryClipChanged() {
                    ClipboardModule.ClipboardEventEmitter.m479listener$lambda7(ClipboardModule.this, this);
                }
            };
            try {
                Result.Companion companion = Result.Companion;
                ClipboardEventEmitter clipboardEventEmitter = this;
                m683constructorimpl = Result.m683constructorimpl(ClipboardModule.this.getClipboardManager());
            } catch (Throwable th) {
                Result.Companion companion2 = Result.Companion;
                m683constructorimpl = Result.m683constructorimpl(ResultKt.createFailure(th));
            }
            this.maybeClipboardManager = (ClipboardManager) (Result.m689isFailureimpl(m683constructorimpl) ? null : m683constructorimpl);
        }

        public final void resumeListening() {
            this.isListening = true;
        }

        public final void pauseListening() {
            this.isListening = false;
        }

        public final Object attachListener() {
            Unit unit;
            String str;
            ClipboardManager clipboardManager = this.maybeClipboardManager;
            if (clipboardManager != null) {
                clipboardManager.addPrimaryClipChangedListener(this.listener);
                unit = Unit.INSTANCE;
            } else {
                unit = null;
            }
            if (unit == null) {
                str = ClipboardModuleKt.TAG;
                return Integer.valueOf(Log.e(str, "'CLIPBOARD_SERVICE' unavailable. Events won't be received"));
            }
            return unit;
        }

        public final Unit detachListener() {
            ClipboardManager clipboardManager = this.maybeClipboardManager;
            if (clipboardManager != null) {
                clipboardManager.removePrimaryClipChangedListener(this.listener);
                return Unit.INSTANCE;
            }
            return null;
        }

        /* JADX INFO: Access modifiers changed from: private */
        /* renamed from: listener$lambda-7  reason: not valid java name */
        public static final void m479listener$lambda7(ClipboardModule this$0, ClipboardEventEmitter this$1) {
            ClipDescription primaryClipDescription;
            boolean hasTextContent;
            Intrinsics.checkNotNullParameter(this$0, "this$0");
            Intrinsics.checkNotNullParameter(this$1, "this$1");
            if (this$0.getAppContext().getHasActiveReactInstance()) {
                ClipboardManager clipboardManager = this$1.maybeClipboardManager;
                if (!this$1.isListening) {
                    clipboardManager = null;
                }
                if (clipboardManager == null || (primaryClipDescription = clipboardManager.getPrimaryClipDescription()) == null) {
                    return;
                }
                if (Build.VERSION.SDK_INT >= 26) {
                    if (this$1.timestamp == primaryClipDescription.getTimestamp()) {
                        return;
                    }
                    this$1.timestamp = primaryClipDescription.getTimestamp();
                }
                Pair[] pairArr = new Pair[1];
                ContentType[] contentTypeArr = new ContentType[3];
                ContentType contentType = ContentType.PLAIN_TEXT;
                hasTextContent = ClipboardModuleKt.getHasTextContent(primaryClipDescription);
                if (!hasTextContent) {
                    contentType = null;
                }
                contentTypeArr[0] = contentType;
                ContentType contentType2 = ContentType.HTML;
                if (!primaryClipDescription.hasMimeType("text/html")) {
                    contentType2 = null;
                }
                contentTypeArr[1] = contentType2;
                contentTypeArr[2] = primaryClipDescription.hasMimeType(MediaTypes.ImageAllMimeType) ? ContentType.IMAGE : null;
                List<ContentType> listOfNotNull = CollectionsKt.listOfNotNull((Object[]) contentTypeArr);
                ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(listOfNotNull, 10));
                for (ContentType contentType3 : listOfNotNull) {
                    arrayList.add(contentType3.getJsName());
                }
                pairArr[0] = TuplesKt.to("contentTypes", arrayList);
                this$0.sendEvent(ClipboardModuleKt.CLIPBOARD_CHANGED_EVENT_NAME, BundleKt.bundleOf(pairArr));
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final boolean clipboardHasItemWithType(String str) {
        ClipDescription primaryClipDescription = getClipboardManager().getPrimaryClipDescription();
        if (primaryClipDescription != null) {
            return primaryClipDescription.hasMimeType(str);
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final ClipData.Item getFirstItem(ClipboardManager clipboardManager) {
        ClipData primaryClip = clipboardManager.getPrimaryClip();
        if (primaryClip != null) {
            if (!(primaryClip.getItemCount() > 0)) {
                primaryClip = null;
            }
            if (primaryClip != null) {
                return primaryClip.getItemAt(0);
            }
            return null;
        }
        return null;
    }
}
