package expo.modules.devlauncher.network;

import com.facebook.react.ReactInstanceManager;
import com.facebook.react.common.LifecycleState;
import com.google.common.net.HttpHeaders;
import expo.modules.devlauncher.DevLauncherController;
import io.sentry.SentryBaseEvent;
import io.sentry.protocol.Message;
import io.sentry.protocol.Response;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Map;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.collections.CollectionsKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.ranges.RangesKt;
import okhttp3.Headers;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.ResponseBody;
import okio.Buffer;
import org.json.JSONObject;
/* compiled from: DevLauncherNetworkLogger.kt */
@Metadata(d1 = {"\u0000>\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0010\b\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010\u000e\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u000b\n\u0002\b\u0002\u0018\u0000 \u00172\u00020\u0001:\u0001\u0017B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0016\u0010\n\u001a\u00020\u000b2\u0006\u0010\f\u001a\u00020\r2\u0006\u0010\u000e\u001a\u00020\u000fJ\u001e\u0010\u0010\u001a\u00020\u000b2\u0006\u0010\u0011\u001a\u00020\u00122\u0006\u0010\f\u001a\u00020\r2\u0006\u0010\u000e\u001a\u00020\u000fJ \u0010\u0013\u001a\u00020\u000b2\u0006\u0010\u0011\u001a\u00020\u00122\u0006\u0010\f\u001a\u00020\r2\b\u0010\u0014\u001a\u0004\u0018\u00010\u000fJ\u0006\u0010\u0015\u001a\u00020\u0016R\u0010\u0010\u0003\u001a\u0004\u0018\u00010\u0004X\u0082\u000e¢\u0006\u0002\n\u0000R\u0014\u0010\u0005\u001a\u00020\u00048BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u0006\u0010\u0007R\u000e\u0010\b\u001a\u00020\tX\u0082\u000e¢\u0006\u0002\n\u0000¨\u0006\u0018"}, d2 = {"Lexpo/modules/devlauncher/network/DevLauncherNetworkLogger;", "", "()V", "_inspectorPackagerConnection", "Lexpo/modules/devlauncher/network/InspectorPackagerConnectionWrapper;", "inspectorPackagerConnection", "getInspectorPackagerConnection", "()Lexpo/modules/devlauncher/network/InspectorPackagerConnectionWrapper;", "reactInstanceHashCode", "", "emitNetworkDidReceiveBody", "", "requestId", "", Response.TYPE, "Lokhttp3/Response;", "emitNetworkResponse", SentryBaseEvent.JsonKeys.REQUEST, "Lokhttp3/Request;", "emitNetworkWillBeSent", "redirectResponse", "shouldEmitEvents", "", "Companion", "expo-dev-launcher_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class DevLauncherNetworkLogger {
    private static final long MAX_BODY_SIZE = 1048576;
    private InspectorPackagerConnectionWrapper _inspectorPackagerConnection;
    private int reactInstanceHashCode;
    public static final Companion Companion = new Companion(null);
    private static final DevLauncherNetworkLogger instance = new DevLauncherNetworkLogger();

    private DevLauncherNetworkLogger() {
    }

    private final InspectorPackagerConnectionWrapper getInspectorPackagerConnection() {
        ReactInstanceManager reactInstanceManager = DevLauncherController.Companion.getInstance().getAppHost().getReactInstanceManager();
        if (this.reactInstanceHashCode != reactInstanceManager.hashCode()) {
            InspectorPackagerConnectionWrapper inspectorPackagerConnectionWrapper = this._inspectorPackagerConnection;
            if (inspectorPackagerConnectionWrapper != null) {
                inspectorPackagerConnectionWrapper.clear();
            }
            this._inspectorPackagerConnection = null;
            this.reactInstanceHashCode = 0;
        }
        if (this._inspectorPackagerConnection == null) {
            Intrinsics.checkNotNullExpressionValue(reactInstanceManager, "reactInstanceManager");
            this._inspectorPackagerConnection = new InspectorPackagerConnectionWrapper(reactInstanceManager);
            this.reactInstanceHashCode = reactInstanceManager.hashCode();
        }
        InspectorPackagerConnectionWrapper inspectorPackagerConnectionWrapper2 = this._inspectorPackagerConnection;
        if (inspectorPackagerConnectionWrapper2 != null) {
            return inspectorPackagerConnectionWrapper2;
        }
        throw new IllegalArgumentException("Required value was null.".toString());
    }

    public final boolean shouldEmitEvents() {
        return DevLauncherController.Companion.wasInitialized() && DevLauncherController.Companion.getInstance().getAppHost().getReactInstanceManager().getLifecycleState() == LifecycleState.RESUMED;
    }

    public final void emitNetworkWillBeSent(Request request, String requestId, okhttp3.Response response) {
        Intrinsics.checkNotNullParameter(request, "request");
        Intrinsics.checkNotNullParameter(requestId, "requestId");
        BigDecimal now = new BigDecimal(System.currentTimeMillis() / 1000.0d).setScale(3, RoundingMode.CEILING);
        Map createMapBuilder = MapsKt.createMapBuilder();
        String httpUrl = request.url().toString();
        Intrinsics.checkNotNullExpressionValue(httpUrl, "request.url().toString()");
        createMapBuilder.put("url", httpUrl);
        String method = request.method();
        Intrinsics.checkNotNullExpressionValue(method, "request.method()");
        createMapBuilder.put("method", method);
        Headers headers = request.headers();
        Intrinsics.checkNotNullExpressionValue(headers, "request.headers()");
        createMapBuilder.put("headers", DevLauncherNetworkLoggerKt.toSingleMap(headers));
        RequestBody body = request.body();
        if (body != null && body.contentLength() < 1048576) {
            Buffer buffer = new Buffer();
            body.writeTo(buffer);
            createMapBuilder.put("postData", buffer.readUtf8(RangesKt.coerceAtMost(buffer.size(), 1048576L)));
        }
        Map build = MapsKt.build(createMapBuilder);
        Map createMapBuilder2 = MapsKt.createMapBuilder();
        createMapBuilder2.put("requestId", requestId);
        createMapBuilder2.put("loaderId", "");
        createMapBuilder2.put("documentURL", "mobile");
        createMapBuilder2.put("initiator", MapsKt.mapOf(TuplesKt.to("type", "script")));
        createMapBuilder2.put("redirectHasExtraInfo", Boolean.valueOf(response != null));
        createMapBuilder2.put(SentryBaseEvent.JsonKeys.REQUEST, build);
        createMapBuilder2.put("referrerPolicy", HttpHeaders.ReferrerPolicyValues.NO_REFERRER);
        createMapBuilder2.put("type", "Fetch");
        Intrinsics.checkNotNullExpressionValue(now, "now");
        createMapBuilder2.put("timestamp", now);
        createMapBuilder2.put("wallTime", now);
        if (response != null) {
            Headers headers2 = response.headers();
            Intrinsics.checkNotNullExpressionValue(headers2, "redirectResponse.headers()");
            createMapBuilder2.put("redirectResponse", MapsKt.mapOf(TuplesKt.to("url", response.request().url().toString()), TuplesKt.to("status", Integer.valueOf(response.code())), TuplesKt.to("statusText", response.message()), TuplesKt.to("headers", DevLauncherNetworkLoggerKt.toSingleMap(headers2))));
        }
        JSONObject jSONObject = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Network.requestWillBeSent"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.build(createMapBuilder2))));
        InspectorPackagerConnectionWrapper inspectorPackagerConnection = getInspectorPackagerConnection();
        String jSONObject2 = jSONObject.toString();
        Intrinsics.checkNotNullExpressionValue(jSONObject2, "requestWillBeSentData.toString()");
        inspectorPackagerConnection.sendWrappedEventToAllPages(jSONObject2);
        Headers headers3 = request.headers();
        Intrinsics.checkNotNullExpressionValue(headers3, "request.headers()");
        JSONObject jSONObject3 = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Network.requestWillBeSentExtraInfo"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.mapOf(TuplesKt.to("requestId", requestId), TuplesKt.to("associatedCookies", CollectionsKt.emptyList()), TuplesKt.to("headers", DevLauncherNetworkLoggerKt.toSingleMap(headers3)), TuplesKt.to("connectTiming", MapsKt.mapOf(TuplesKt.to("requestTime", now)))))));
        InspectorPackagerConnectionWrapper inspectorPackagerConnection2 = getInspectorPackagerConnection();
        String jSONObject4 = jSONObject3.toString();
        Intrinsics.checkNotNullExpressionValue(jSONObject4, "extraInfoData.toString()");
        inspectorPackagerConnection2.sendWrappedEventToAllPages(jSONObject4);
    }

    public final void emitNetworkResponse(Request request, String requestId, okhttp3.Response response) {
        Intrinsics.checkNotNullParameter(request, "request");
        Intrinsics.checkNotNullParameter(requestId, "requestId");
        Intrinsics.checkNotNullParameter(response, "response");
        BigDecimal scale = new BigDecimal(System.currentTimeMillis() / 1000.0d).setScale(3, RoundingMode.CEILING);
        Headers headers = response.headers();
        Intrinsics.checkNotNullExpressionValue(headers, "response.headers()");
        JSONObject jSONObject = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Network.responseReceived"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.mapOf(TuplesKt.to("requestId", requestId), TuplesKt.to("loaderId", ""), TuplesKt.to("hasExtraInfo", false), TuplesKt.to(Response.TYPE, MapsKt.mapOf(TuplesKt.to("url", request.url().toString()), TuplesKt.to("status", Integer.valueOf(response.code())), TuplesKt.to("statusText", response.message()), TuplesKt.to("headers", DevLauncherNetworkLoggerKt.toSingleMap(headers)), TuplesKt.to("mimeType", response.header(HttpHeaders.CONTENT_TYPE, "")))), TuplesKt.to("referrerPolicy", HttpHeaders.ReferrerPolicyValues.NO_REFERRER), TuplesKt.to("type", "Fetch"), TuplesKt.to("timestamp", scale)))));
        InspectorPackagerConnectionWrapper inspectorPackagerConnection = getInspectorPackagerConnection();
        String jSONObject2 = jSONObject.toString();
        Intrinsics.checkNotNullExpressionValue(jSONObject2, "responseReceivedData.toString()");
        inspectorPackagerConnection.sendWrappedEventToAllPages(jSONObject2);
        Pair[] pairArr = new Pair[3];
        pairArr[0] = TuplesKt.to("requestId", requestId);
        pairArr[1] = TuplesKt.to("timestamp", scale);
        ResponseBody body = response.body();
        pairArr[2] = TuplesKt.to("encodedDataLength", Long.valueOf(body != null ? body.contentLength() : 0L));
        JSONObject jSONObject3 = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Network.loadingFinished"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.mapOf(pairArr))));
        InspectorPackagerConnectionWrapper inspectorPackagerConnection2 = getInspectorPackagerConnection();
        String jSONObject4 = jSONObject3.toString();
        Intrinsics.checkNotNullExpressionValue(jSONObject4, "loadingFinishedData.toString()");
        inspectorPackagerConnection2.sendWrappedEventToAllPages(jSONObject4);
    }

    /* JADX WARN: Code restructure failed: missing block: B:25:0x005c, code lost:
        if (kotlin.jvm.internal.Intrinsics.areEqual(r1 != null ? r1.subtype() : null, "json") != false) goto L29;
     */
    /* JADX WARN: Removed duplicated region for block: B:30:0x0064  */
    /* JADX WARN: Removed duplicated region for block: B:31:0x0069  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final void emitNetworkDidReceiveBody(String requestId, okhttp3.Response response) {
        boolean z;
        Intrinsics.checkNotNullParameter(requestId, "requestId");
        Intrinsics.checkNotNullParameter(response, "response");
        ResponseBody body = response.body();
        long contentLength = body != null ? body.contentLength() : 0L;
        if (contentLength <= 0 || contentLength > 1048576) {
            return;
        }
        ResponseBody peekBody = response.peekBody(1048576L);
        MediaType contentType = peekBody.contentType();
        if (!Intrinsics.areEqual(contentType != null ? contentType.type() : null, "text")) {
            if (Intrinsics.areEqual(contentType != null ? contentType.type() : null, "application")) {
            }
            z = false;
            JSONObject jSONObject = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Expo(Network.receivedResponseBody)"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.mapOf(TuplesKt.to("requestId", requestId), TuplesKt.to("body", !z ? peekBody.string() : peekBody.source().readByteString().base64()), TuplesKt.to("base64Encoded", Boolean.valueOf(!z))))));
            InspectorPackagerConnectionWrapper inspectorPackagerConnection = getInspectorPackagerConnection();
            String jSONObject2 = jSONObject.toString();
            Intrinsics.checkNotNullExpressionValue(jSONObject2, "data.toString()");
            inspectorPackagerConnection.sendWrappedEventToAllPages(jSONObject2);
        }
        z = true;
        JSONObject jSONObject3 = new JSONObject(MapsKt.mapOf(TuplesKt.to("method", "Expo(Network.receivedResponseBody)"), TuplesKt.to(Message.JsonKeys.PARAMS, MapsKt.mapOf(TuplesKt.to("requestId", requestId), TuplesKt.to("body", !z ? peekBody.string() : peekBody.source().readByteString().base64()), TuplesKt.to("base64Encoded", Boolean.valueOf(!z))))));
        InspectorPackagerConnectionWrapper inspectorPackagerConnection2 = getInspectorPackagerConnection();
        String jSONObject22 = jSONObject3.toString();
        Intrinsics.checkNotNullExpressionValue(jSONObject22, "data.toString()");
        inspectorPackagerConnection2.sendWrappedEventToAllPages(jSONObject22);
    }

    /* compiled from: DevLauncherNetworkLogger.kt */
    @Metadata(d1 = {"\u0000\u001a\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\t\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082T¢\u0006\u0002\n\u0000R\u0011\u0010\u0005\u001a\u00020\u0006¢\u0006\b\n\u0000\u001a\u0004\b\u0007\u0010\b¨\u0006\t"}, d2 = {"Lexpo/modules/devlauncher/network/DevLauncherNetworkLogger$Companion;", "", "()V", "MAX_BODY_SIZE", "", "instance", "Lexpo/modules/devlauncher/network/DevLauncherNetworkLogger;", "getInstance", "()Lexpo/modules/devlauncher/network/DevLauncherNetworkLogger;", "expo-dev-launcher_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
    /* loaded from: classes3.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final DevLauncherNetworkLogger getInstance() {
            return DevLauncherNetworkLogger.instance;
        }
    }
}
