package expo.modules.devlauncher.network;

import androidx.core.app.NotificationCompat;
import com.facebook.react.ReactInstanceManager;
import com.facebook.react.bridge.Inspector;
import com.facebook.react.devsupport.DevServerHelper;
import com.facebook.react.devsupport.InspectorPackagerConnection;
import com.facebook.react.devsupport.interfaces.DevSupportManager;
import java.lang.ref.WeakReference;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.Iterator;
import kotlin.Metadata;
import kotlin.jvm.internal.Intrinsics;
/* compiled from: DevLauncherNetworkLogger.kt */
@Metadata(d1 = {"\u0000@\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0000\b\u0000\u0018\u00002\u00020\u0001B\r\u0012\u0006\u0010\u0002\u001a\u00020\u0003¢\u0006\u0002\u0010\u0004J\u0006\u0010\u0011\u001a\u00020\u0012J\u000e\u0010\u0013\u001a\u00020\u00122\u0006\u0010\u0014\u001a\u00020\u0015R\u0014\u0010\u0005\u001a\b\u0012\u0004\u0012\u00020\u00070\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u0016\u0010\b\u001a\u0004\u0018\u00010\t8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\n\u0010\u000bR\u000e\u0010\f\u001a\u00020\rX\u0082\u0004¢\u0006\u0002\n\u0000R\u0014\u0010\u000e\u001a\b\u0012\u0004\u0012\u00020\t0\u0006X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u000f\u001a\u00020\u0010X\u0082\u0004¢\u0006\u0002\n\u0000¨\u0006\u0016"}, d2 = {"Lexpo/modules/devlauncher/network/InspectorPackagerConnectionWrapper;", "", "reactInstanceManager", "Lcom/facebook/react/ReactInstanceManager;", "(Lcom/facebook/react/ReactInstanceManager;)V", "devServerHelperWeak", "Ljava/lang/ref/WeakReference;", "Lcom/facebook/react/devsupport/DevServerHelper;", "inspectorPackagerConnection", "Lcom/facebook/react/devsupport/InspectorPackagerConnection;", "getInspectorPackagerConnection", "()Lcom/facebook/react/devsupport/InspectorPackagerConnection;", "inspectorPackagerConnectionField", "Ljava/lang/reflect/Field;", "inspectorPackagerConnectionWeak", "sendWrappedEventMethod", "Ljava/lang/reflect/Method;", "clear", "", "sendWrappedEventToAllPages", NotificationCompat.CATEGORY_EVENT, "", "expo-dev-launcher_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class InspectorPackagerConnectionWrapper {
    private final WeakReference<DevServerHelper> devServerHelperWeak;
    private final Field inspectorPackagerConnectionField;
    private WeakReference<InspectorPackagerConnection> inspectorPackagerConnectionWeak;
    private final Method sendWrappedEventMethod;

    public InspectorPackagerConnectionWrapper(ReactInstanceManager reactInstanceManager) {
        Intrinsics.checkNotNullParameter(reactInstanceManager, "reactInstanceManager");
        this.inspectorPackagerConnectionWeak = new WeakReference<>(null);
        DevSupportManager devSupportManager = reactInstanceManager.getDevSupportManager();
        Class<? super Object> superclass = devSupportManager.getClass().getSuperclass();
        Intrinsics.checkNotNullExpressionValue(superclass, "devSupportManager.javaClass.superclass");
        Field declaredField = superclass.getDeclaredField("mDevServerHelper");
        declaredField.setAccessible(true);
        Object obj = declaredField.get(devSupportManager);
        Intrinsics.checkNotNull(obj, "null cannot be cast to non-null type com.facebook.react.devsupport.DevServerHelper");
        this.devServerHelperWeak = new WeakReference<>((DevServerHelper) obj);
        Field declaredField2 = DevServerHelper.class.getDeclaredField("mInspectorPackagerConnection");
        Intrinsics.checkNotNullExpressionValue(declaredField2, "DevServerHelper::class.j…ectorPackagerConnection\")");
        this.inspectorPackagerConnectionField = declaredField2;
        declaredField2.setAccessible(true);
        Method declaredMethod = InspectorPackagerConnection.class.getDeclaredMethod("sendWrappedEvent", String.class, String.class);
        Intrinsics.checkNotNullExpressionValue(declaredMethod, "InspectorPackagerConnect…java, String::class.java)");
        this.sendWrappedEventMethod = declaredMethod;
        declaredMethod.setAccessible(true);
    }

    private final InspectorPackagerConnection getInspectorPackagerConnection() {
        InspectorPackagerConnection inspectorPackagerConnection = this.inspectorPackagerConnectionWeak.get();
        if (inspectorPackagerConnection == null) {
            DevServerHelper devServerHelper = this.devServerHelperWeak.get();
            if (devServerHelper == null) {
                return null;
            }
            Object obj = this.inspectorPackagerConnectionField.get(devServerHelper);
            inspectorPackagerConnection = obj instanceof InspectorPackagerConnection ? (InspectorPackagerConnection) obj : null;
            if (inspectorPackagerConnection != null) {
                this.inspectorPackagerConnectionWeak = new WeakReference<>(inspectorPackagerConnection);
            }
        }
        return inspectorPackagerConnection;
    }

    public final void clear() {
        this.inspectorPackagerConnectionWeak.clear();
    }

    public final void sendWrappedEventToAllPages(String event) {
        Intrinsics.checkNotNullParameter(event, "event");
        InspectorPackagerConnection inspectorPackagerConnection = getInspectorPackagerConnection();
        if (inspectorPackagerConnection == null) {
            return;
        }
        Iterator<Inspector.Page> it = Inspector.getPages().iterator();
        while (it.hasNext()) {
            this.sendWrappedEventMethod.invoke(inspectorPackagerConnection, String.valueOf(it.next().getId()), event);
        }
    }
}
