package expo.modules.devmenu.modules.internals;

import android.app.Activity;
import android.content.ClipData;
import android.content.ClipboardManager;
import com.facebook.react.ReactInstanceManager;
import com.facebook.react.bridge.BaseJavaModule;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.devsupport.interfaces.DevSupportManager;
import expo.interfaces.devmenu.DevMenuPreferencesInterface;
import expo.modules.devmenu.DevMenuManager;
import expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface;
import kotlin.Metadata;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.BuildersKt__Builders_commonKt;
/* compiled from: DevMenuInternalMenuControllerModule.kt */
@Metadata(d1 = {"\u0000:\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010\u000e\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\n\n\u0002\u0010\u000b\n\u0000\u0018\u00002\u00020\u0001B\r\u0012\u0006\u0010\u0002\u001a\u00020\u0003¢\u0006\u0002\u0010\u0004J\u0018\u0010\u0007\u001a\u00020\b2\u0006\u0010\t\u001a\u00020\n2\u0006\u0010\u000b\u001a\u00020\fH\u0016J$\u0010\r\u001a\u00020\b2\b\u0010\u000e\u001a\u0004\u0018\u00010\n2\b\u0010\u000f\u001a\u0004\u0018\u00010\u00102\u0006\u0010\u000b\u001a\u00020\fH\u0016J\u001a\u0010\u0011\u001a\u00020\b2\b\u0010\u0012\u001a\u0004\u0018\u00010\n2\u0006\u0010\u000b\u001a\u00020\fH\u0016J\u0018\u0010\u0013\u001a\u00020\b2\u0006\u0010\u0014\u001a\u00020\n2\u0006\u0010\u000b\u001a\u00020\fH\u0016J\b\u0010\u0015\u001a\u00020\bH\u0016J\u001a\u0010\u0016\u001a\u00020\b2\b\u0010\u0017\u001a\u0004\u0018\u00010\n2\u0006\u0010\u000b\u001a\u00020\fH\u0016J\b\u0010\u0018\u001a\u00020\bH\u0016J\u0010\u0010\u0019\u001a\u00020\b2\u0006\u0010\u001a\u001a\u00020\u001bH\u0016R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0002\u001a\u00020\u0003X\u0082\u0004¢\u0006\u0002\n\u0000¨\u0006\u001c"}, d2 = {"Lexpo/modules/devmenu/modules/internals/DevMenuInternalMenuControllerModule;", "Lexpo/modules/devmenu/modules/DevMenuInternalMenuControllerModuleInterface;", "reactContext", "Lcom/facebook/react/bridge/ReactContext;", "(Lcom/facebook/react/bridge/ReactContext;)V", "devMenuManager", "Lexpo/modules/devmenu/DevMenuManager;", "copyToClipboardAsync", "", "content", "", BaseJavaModule.METHOD_TYPE_PROMISE, "Lcom/facebook/react/bridge/Promise;", "dispatchCallableAsync", "callableId", "args", "Lcom/facebook/react/bridge/ReadableMap;", "fetchDataSourceAsync", "id", "fireCallback", "name", "hideMenu", "onScreenChangeAsync", "currentScreen", "openDevMenuFromReactNative", "setOnboardingFinished", "finished", "", "expo-dev-menu_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class DevMenuInternalMenuControllerModule implements DevMenuInternalMenuControllerModuleInterface {
    private final DevMenuManager devMenuManager;
    private final ReactContext reactContext;

    public DevMenuInternalMenuControllerModule(ReactContext reactContext) {
        Intrinsics.checkNotNullParameter(reactContext, "reactContext");
        this.reactContext = reactContext;
        this.devMenuManager = DevMenuManager.INSTANCE;
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void dispatchCallableAsync(String str, ReadableMap readableMap, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, "promise");
        if (str == null) {
            promise.reject("ERR_DEVMENU_ACTION_FAILED", "Callable ID not provided.");
            return;
        }
        this.devMenuManager.dispatchCallable(str, readableMap);
        promise.resolve(null);
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void hideMenu() {
        this.devMenuManager.hideMenu();
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void setOnboardingFinished(boolean z) {
        DevMenuPreferencesInterface settings = this.devMenuManager.getSettings();
        if (settings == null) {
            return;
        }
        settings.setOnboardingFinished(z);
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void openDevMenuFromReactNative() {
        Activity currentActivity;
        ReactInstanceManager reactInstanceManager = this.devMenuManager.getReactInstanceManager();
        if (reactInstanceManager == null) {
            return;
        }
        final DevSupportManager devSupportManager = reactInstanceManager.getDevSupportManager();
        ReactContext currentReactContext = reactInstanceManager.getCurrentReactContext();
        if (currentReactContext == null || (currentActivity = currentReactContext.getCurrentActivity()) == null) {
            return;
        }
        this.devMenuManager.closeMenu();
        currentActivity.runOnUiThread(new Runnable() { // from class: expo.modules.devmenu.modules.internals.DevMenuInternalMenuControllerModule$$ExternalSyntheticLambda0
            @Override // java.lang.Runnable
            public final void run() {
                DevMenuInternalMenuControllerModule.m486openDevMenuFromReactNative$lambda0(DevSupportManager.this);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: openDevMenuFromReactNative$lambda-0  reason: not valid java name */
    public static final void m486openDevMenuFromReactNative$lambda0(DevSupportManager devSupportManager) {
        devSupportManager.setDevSupportEnabled(true);
        devSupportManager.showDevOptionsDialog();
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void onScreenChangeAsync(String str, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, "promise");
        this.devMenuManager.setCurrentScreen(str);
        promise.resolve(null);
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void fetchDataSourceAsync(String str, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, "promise");
        if (str != null) {
            BuildersKt__Builders_commonKt.launch$default(this.devMenuManager.getCoroutineScope(), null, null, new DevMenuInternalMenuControllerModule$fetchDataSourceAsync$1(this, str, promise, null), 3, null);
        } else {
            promise.reject("ERR_DEVMENU_FETCH_FAILED", "DataSource ID not provided.");
        }
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void copyToClipboardAsync(String content, Promise promise) {
        Intrinsics.checkNotNullParameter(content, "content");
        Intrinsics.checkNotNullParameter(promise, "promise");
        Object systemService = this.reactContext.getSystemService("clipboard");
        Intrinsics.checkNotNull(systemService, "null cannot be cast to non-null type android.content.ClipboardManager");
        ((ClipboardManager) systemService).setPrimaryClip(ClipData.newPlainText(null, content));
        promise.resolve(null);
    }

    @Override // expo.modules.devmenu.modules.DevMenuInternalMenuControllerModuleInterface
    public void fireCallback(String name, Promise promise) {
        Intrinsics.checkNotNullParameter(name, "name");
        Intrinsics.checkNotNullParameter(promise, "promise");
        if (!this.devMenuManager.getRegisteredCallbacks().contains(name)) {
            promise.reject("ERR_DEVMENU_CALLBACK_FAILED", "Callback with name: " + name + " is not registered");
            return;
        }
        this.devMenuManager.sendEventToDelegateBridge("registeredCallbackFired", name);
        promise.resolve(null);
    }
}
