package expo.modules.localization;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.icu.util.LocaleData;
import android.icu.util.ULocale;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.text.format.DateFormat;
import androidx.core.os.BundleKt;
import androidx.core.os.LocaleListCompat;
import com.facebook.hermes.intl.Constants;
import com.google.firebase.analytics.FirebaseAnalytics;
import expo.modules.kotlin.events.BasicEventListener;
import expo.modules.kotlin.events.EventName;
import expo.modules.kotlin.functions.AsyncFunctionComponent;
import expo.modules.kotlin.functions.SyncFunctionComponent;
import expo.modules.kotlin.modules.Module;
import expo.modules.kotlin.modules.ModuleDefinitionBuilder;
import expo.modules.kotlin.modules.ModuleDefinitionData;
import expo.modules.kotlin.types.AnyType;
import io.sentry.protocol.Device;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Currency;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.collections.CollectionsKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt;
/* compiled from: LocalizationModule.kt */
@Metadata(d1 = {"\u0000J\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000e\n\u0000\n\u0002\u0010$\n\u0002\u0010\u0000\n\u0002\b\u0005\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000b\n\u0000\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\b\u0010\f\u001a\u00020\rH\u0016J\b\u0010\u000e\u001a\u00020\u000fH\u0002J\u001c\u0010\u0010\u001a\u0016\u0012\u0012\u0012\u0010\u0012\u0004\u0012\u00020\u000f\u0012\u0006\u0012\u0004\u0018\u00010\u00120\u00110\bH\u0002J\u0012\u0010\u0013\u001a\u0004\u0018\u00010\u000f2\u0006\u0010\u0014\u001a\u00020\tH\u0002J\u001c\u0010\u0015\u001a\u0016\u0012\u0012\u0012\u0010\u0012\u0004\u0012\u00020\u000f\u0012\u0006\u0012\u0004\u0018\u00010\u00120\u00110\bH\u0002J\u0012\u0010\u0016\u001a\u0004\u0018\u00010\u000f2\u0006\u0010\u0014\u001a\u00020\tH\u0002J\u0010\u0010\u0017\u001a\u00020\u00182\u0006\u0010\u0019\u001a\u00020\u001aH\u0002J\b\u0010\u001b\u001a\u00020\u001cH\u0002R\u0014\u0010\u0003\u001a\u00020\u00048BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u0005\u0010\u0006R\u001a\u0010\u0007\u001a\b\u0012\u0004\u0012\u00020\t0\b8BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\n\u0010\u000b¨\u0006\u001d"}, d2 = {"Lexpo/modules/localization/LocalizationModule;", "Lexpo/modules/kotlin/modules/Module;", "()V", "bundledConstants", "Landroid/os/Bundle;", "getBundledConstants", "()Landroid/os/Bundle;", "locales", "", "Ljava/util/Locale;", "getLocales", "()Ljava/util/List;", "definition", "Lexpo/modules/kotlin/modules/ModuleDefinitionData;", "getCalendarType", "", "getCalendars", "", "", "getMeasurementSystem", "locale", "getPreferredLocales", "getRegionCode", "setRTLFromStringResources", "", "context", "Landroid/content/Context;", "uses24HourClock", "", "expo-localization_release"}, k = 1, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class LocalizationModule extends Module {
    @Override // expo.modules.kotlin.modules.Module
    public ModuleDefinitionData definition() {
        ModuleDefinitionBuilder moduleDefinitionBuilder = new ModuleDefinitionBuilder(this);
        moduleDefinitionBuilder.Name("ExpoLocalization");
        moduleDefinitionBuilder.Constants(new LocalizationModule$definition$1$1(this));
        ModuleDefinitionBuilder moduleDefinitionBuilder2 = moduleDefinitionBuilder;
        moduleDefinitionBuilder2.getAsyncFunctions().put("getLocalizationAsync", new AsyncFunctionComponent("getLocalizationAsync", new AnyType[0], new LocalizationModule$definition$lambda5$$inlined$AsyncFunctionWithoutArgs$1(this)));
        moduleDefinitionBuilder2.getSyncFunctions().put("getLocales", new SyncFunctionComponent("getLocales", new AnyType[0], new LocalizationModule$definition$lambda5$$inlined$FunctionWithoutArgs$1(this)));
        moduleDefinitionBuilder2.getSyncFunctions().put("getCalendars", new SyncFunctionComponent("getCalendars", new AnyType[0], new LocalizationModule$definition$lambda5$$inlined$FunctionWithoutArgs$2(this)));
        moduleDefinitionBuilder.getEventListeners().put(EventName.MODULE_CREATE, new BasicEventListener(EventName.MODULE_CREATE, new LocalizationModule$definition$lambda5$$inlined$OnCreate$1(this)));
        return moduleDefinitionBuilder.buildModule();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void setRTLFromStringResources(Context context) {
        Context reactContext = getAppContext().getReactContext();
        String string = reactContext != null ? reactContext.getString(R.string.ExpoLocalization_supportsRTL) : null;
        if (Intrinsics.areEqual(string, "true") || Intrinsics.areEqual(string, Constants.CASEFIRST_FALSE)) {
            SharedPreferences.Editor edit = context.getSharedPreferences("com.facebook.react.modules.i18nmanager.I18nUtil", 0).edit();
            edit.putBoolean("RCTI18nUtil_allowRTL", Intrinsics.areEqual(string, "true"));
            edit.apply();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final Bundle getBundledConstants() {
        Locale locale = Locale.getDefault();
        String[] localeNames = LocalizationUtilsKt.getLocaleNames(getLocales());
        boolean z = TextUtils.getLayoutDirectionFromLocale(locale) == 1;
        Intrinsics.checkNotNullExpressionValue(locale, "locale");
        String regionCode = getRegionCode(locale);
        DecimalFormatSymbols decimalFormatSymbols = new DecimalFormatSymbols(locale);
        return BundleKt.bundleOf(TuplesKt.to(FirebaseAnalytics.Param.CURRENCY, LocalizationUtilsKt.getCurrencyCode(locale)), TuplesKt.to("decimalSeparator", String.valueOf(decimalFormatSymbols.getDecimalSeparator())), TuplesKt.to("digitGroupingSeparator", String.valueOf(decimalFormatSymbols.getGroupingSeparator())), TuplesKt.to("isoCurrencyCodes", LocalizationUtilsKt.getISOCurrencyCodes()), TuplesKt.to("isMetric", Boolean.valueOf(!CollectionsKt.contains(LocalizationUtilsKt.getUSES_IMPERIAL(), regionCode))), TuplesKt.to("isRTL", Boolean.valueOf(z)), TuplesKt.to("locale", localeNames[0]), TuplesKt.to("locales", localeNames), TuplesKt.to("region", regionCode), TuplesKt.to(Device.JsonKeys.TIMEZONE, TimeZone.getDefault().getID()));
    }

    private final List<Locale> getLocales() {
        Context reactContext = getAppContext().getReactContext();
        if (reactContext == null) {
            return CollectionsKt.emptyList();
        }
        Configuration configuration = reactContext.getResources().getConfiguration();
        if (Build.VERSION.SDK_INT > 24) {
            ArrayList arrayList = new ArrayList();
            int size = configuration.getLocales().size();
            for (int i = 0; i < size; i++) {
                arrayList.add(configuration.getLocales().get(i));
            }
            return arrayList;
        }
        return CollectionsKt.listOf(configuration.locale);
    }

    private final String getRegionCode(Locale locale) {
        String systemProperty = LocalizationUtilsKt.getSystemProperty("ro.miui.region");
        return !TextUtils.isEmpty(systemProperty) ? systemProperty : LocalizationUtilsKt.getCountryCode(locale);
    }

    private final String getMeasurementSystem(Locale locale) {
        if (Build.VERSION.SDK_INT >= 28) {
            LocaleData.MeasurementSystem measurementSystem = LocaleData.getMeasurementSystem(ULocale.forLocale(locale));
            if (!Intrinsics.areEqual(measurementSystem, LocaleData.MeasurementSystem.SI)) {
                if (!Intrinsics.areEqual(measurementSystem, LocaleData.MeasurementSystem.UK)) {
                    if (Intrinsics.areEqual(measurementSystem, LocaleData.MeasurementSystem.US)) {
                        return "us";
                    }
                }
                return "uk";
            }
            return "metric";
        }
        if (!StringsKt.equals$default(getRegionCode(locale), "uk", false, 2, null)) {
            if (CollectionsKt.contains(LocalizationUtilsKt.getUSES_IMPERIAL(), getRegionCode(locale))) {
                return "us";
            }
            return "metric";
        }
        return "uk";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final List<Map<String, Object>> getPreferredLocales() {
        ArrayList arrayList = new ArrayList();
        LocaleListCompat localeListCompat = LocaleListCompat.getDefault();
        Intrinsics.checkNotNullExpressionValue(localeListCompat, "getDefault()");
        int size = localeListCompat.size();
        for (int i = 0; i < size; i++) {
            Locale locale = localeListCompat.get(i);
            if (locale != null) {
                DecimalFormatSymbols decimalFormatSymbols = DecimalFormatSymbols.getInstance(locale);
                Pair[] pairArr = new Pair[9];
                pairArr[0] = TuplesKt.to("languageTag", locale.toLanguageTag());
                pairArr[1] = TuplesKt.to("regionCode", getRegionCode(locale));
                pairArr[2] = TuplesKt.to("textDirection", TextUtils.getLayoutDirectionFromLocale(locale) == 1 ? "rtl" : "ltr");
                pairArr[3] = TuplesKt.to("languageCode", locale.getLanguage());
                pairArr[4] = TuplesKt.to("decimalSeparator", String.valueOf(decimalFormatSymbols.getDecimalSeparator()));
                pairArr[5] = TuplesKt.to("digitGroupingSeparator", String.valueOf(decimalFormatSymbols.getGroupingSeparator()));
                pairArr[6] = TuplesKt.to("measurementSystem", getMeasurementSystem(locale));
                pairArr[7] = TuplesKt.to("currencyCode", decimalFormatSymbols.getCurrency().getCurrencyCode());
                pairArr[8] = TuplesKt.to("currencySymbol", Currency.getInstance(locale).getSymbol(locale));
                arrayList.add(MapsKt.mapOf(pairArr));
            }
        }
        return arrayList;
    }

    private final boolean uses24HourClock() {
        if (getAppContext().getReactContext() == null) {
            return false;
        }
        return DateFormat.is24HourFormat(getAppContext().getReactContext());
    }

    private final String getCalendarType() {
        return Build.VERSION.SDK_INT >= 26 ? Calendar.getInstance().getCalendarType().toString() : "gregory";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final List<Map<String, Object>> getCalendars() {
        return CollectionsKt.listOf(MapsKt.mapOf(TuplesKt.to("calendar", getCalendarType()), TuplesKt.to("uses24hourClock", Boolean.valueOf(uses24HourClock())), TuplesKt.to("firstWeekday", Integer.valueOf(Calendar.getInstance().getFirstDayOfWeek())), TuplesKt.to("timeZone", Calendar.getInstance().getTimeZone().getID())));
    }
}
