package expo.modules.localization;

import android.text.TextUtils;
import java.util.ArrayList;
import java.util.Currency;
import java.util.List;
import java.util.Locale;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.Metadata;
import kotlin.Result;
import kotlin.ResultKt;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.internal.Intrinsics;
/* compiled from: LocalizationUtils.kt */
@Metadata(d1 = {"\u0000\u001e\n\u0000\n\u0002\u0010\u0011\n\u0002\u0010\u000e\n\u0002\b\u0005\n\u0002\u0010 \n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\b\u001a\u0010\u0010\u000b\u001a\u0004\u0018\u00010\u00022\u0006\u0010\f\u001a\u00020\r\u001a\u0010\u0010\u000e\u001a\u0004\u0018\u00010\u00022\u0006\u0010\f\u001a\u00020\r\u001a'\u0010\u000f\u001a\u0010\u0012\f\u0012\n \u0010*\u0004\u0018\u00010\u00020\u00020\u00012\f\u0010\u0011\u001a\b\u0012\u0004\u0012\u00020\r0\b¢\u0006\u0002\u0010\u0012\u001a\u000e\u0010\u0013\u001a\u00020\u00022\u0006\u0010\u0014\u001a\u00020\u0002\"!\u0010\u0000\u001a\b\u0012\u0004\u0012\u00020\u00020\u00018FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0005\u0010\u0006\u001a\u0004\b\u0003\u0010\u0004\"\u0017\u0010\u0007\u001a\b\u0012\u0004\u0012\u00020\u00020\b¢\u0006\b\n\u0000\u001a\u0004\b\t\u0010\n¨\u0006\u0015"}, d2 = {"ISOCurrencyCodes", "", "", "getISOCurrencyCodes", "()[Ljava/lang/String;", "ISOCurrencyCodes$delegate", "Lkotlin/Lazy;", "USES_IMPERIAL", "", "getUSES_IMPERIAL", "()Ljava/util/List;", "getCountryCode", "locale", "Ljava/util/Locale;", "getCurrencyCode", "getLocaleNames", "kotlin.jvm.PlatformType", "locales", "(Ljava/util/List;)[Ljava/lang/String;", "getSystemProperty", "key", "expo-localization_release"}, k = 2, mv = {1, 7, 1}, xi = 48)
/* loaded from: classes3.dex */
public final class LocalizationUtilsKt {
    private static final List<String> USES_IMPERIAL = CollectionsKt.listOf((Object[]) new String[]{"US", "LR", "MM"});
    private static final Lazy ISOCurrencyCodes$delegate = LazyKt.lazy(LocalizationUtilsKt$ISOCurrencyCodes$2.INSTANCE);

    public static final List<String> getUSES_IMPERIAL() {
        return USES_IMPERIAL;
    }

    public static final String[] getISOCurrencyCodes() {
        return (String[]) ISOCurrencyCodes$delegate.getValue();
    }

    public static final String[] getLocaleNames(List<Locale> locales) {
        Intrinsics.checkNotNullParameter(locales, "locales");
        List<Locale> list = locales;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(list, 10));
        for (Locale locale : list) {
            arrayList.add(locale.toLanguageTag());
        }
        Object[] array = arrayList.toArray(new String[0]);
        Intrinsics.checkNotNull(array, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
        return (String[]) array;
    }

    public static final String getCountryCode(Locale locale) {
        Object m683constructorimpl;
        Intrinsics.checkNotNullParameter(locale, "locale");
        try {
            Result.Companion companion = Result.Companion;
            String country = locale.getCountry();
            if (TextUtils.isEmpty(country)) {
                country = null;
            }
            m683constructorimpl = Result.m683constructorimpl(country);
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            m683constructorimpl = Result.m683constructorimpl(ResultKt.createFailure(th));
        }
        return Result.m689isFailureimpl(m683constructorimpl) ? null : m683constructorimpl;
    }

    public static final String getSystemProperty(String key) {
        Object m683constructorimpl;
        Intrinsics.checkNotNullParameter(key, "key");
        try {
            Result.Companion companion = Result.Companion;
            Class<?> cls = Class.forName("android.os.SystemProperties");
            Object invoke = cls.getMethod("get", String.class).invoke(cls, key);
            Intrinsics.checkNotNull(invoke, "null cannot be cast to non-null type kotlin.String");
            m683constructorimpl = Result.m683constructorimpl((String) invoke);
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            m683constructorimpl = Result.m683constructorimpl(ResultKt.createFailure(th));
        }
        if (Result.m689isFailureimpl(m683constructorimpl)) {
            m683constructorimpl = null;
        }
        String str = (String) m683constructorimpl;
        return str == null ? "" : str;
    }

    public static final String getCurrencyCode(Locale locale) {
        Object m683constructorimpl;
        Intrinsics.checkNotNullParameter(locale, "locale");
        try {
            Result.Companion companion = Result.Companion;
            Currency currency = Currency.getInstance(locale);
            m683constructorimpl = Result.m683constructorimpl(currency != null ? currency.getCurrencyCode() : null);
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            m683constructorimpl = Result.m683constructorimpl(ResultKt.createFailure(th));
        }
        return Result.m689isFailureimpl(m683constructorimpl) ? null : m683constructorimpl;
    }
}
