package expo.modules.notifications.notifications;

import expo.modules.core.interfaces.SingletonModule;
import expo.modules.notifications.notifications.interfaces.NotificationListener;
import expo.modules.notifications.notifications.model.Notification;
import expo.modules.notifications.notifications.model.NotificationResponse;
import expo.modules.notifications.service.delegates.ExpoHandlingDelegate;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Collection;
import java.util.WeakHashMap;
/* loaded from: classes3.dex */
public class NotificationManager implements SingletonModule, expo.modules.notifications.notifications.interfaces.NotificationManager {
    private static final String SINGLETON_NAME = "NotificationManager";
    private Collection<NotificationResponse> mPendingNotificationResponses = new ArrayList();
    private WeakHashMap<NotificationListener, WeakReference<NotificationListener>> mListenerReferenceMap = new WeakHashMap<>();

    @Override // expo.modules.core.interfaces.SingletonModule
    public String getName() {
        return SINGLETON_NAME;
    }

    public NotificationManager() {
        ExpoHandlingDelegate.Companion.addListener(this);
    }

    @Override // expo.modules.notifications.notifications.interfaces.NotificationManager
    public void addListener(NotificationListener notificationListener) {
        if (this.mListenerReferenceMap.containsKey(notificationListener)) {
            return;
        }
        this.mListenerReferenceMap.put(notificationListener, new WeakReference<>(notificationListener));
        if (this.mPendingNotificationResponses.isEmpty()) {
            return;
        }
        for (NotificationResponse notificationResponse : this.mPendingNotificationResponses) {
            notificationListener.onNotificationResponseReceived(notificationResponse);
        }
    }

    @Override // expo.modules.notifications.notifications.interfaces.NotificationManager
    public void removeListener(NotificationListener notificationListener) {
        this.mListenerReferenceMap.remove(notificationListener);
    }

    public void onNotificationReceived(Notification notification) {
        for (WeakReference<NotificationListener> weakReference : this.mListenerReferenceMap.values()) {
            NotificationListener notificationListener = weakReference.get();
            if (notificationListener != null) {
                notificationListener.onNotificationReceived(notification);
            }
        }
    }

    public void onNotificationResponseReceived(NotificationResponse notificationResponse) {
        if (this.mListenerReferenceMap.isEmpty()) {
            this.mPendingNotificationResponses.add(notificationResponse);
            return;
        }
        for (WeakReference<NotificationListener> weakReference : this.mListenerReferenceMap.values()) {
            NotificationListener notificationListener = weakReference.get();
            if (notificationListener != null) {
                notificationListener.onNotificationResponseReceived(notificationResponse);
            }
        }
    }

    public void onNotificationsDropped() {
        for (WeakReference<NotificationListener> weakReference : this.mListenerReferenceMap.values()) {
            NotificationListener notificationListener = weakReference.get();
            if (notificationListener != null) {
                notificationListener.onNotificationsDropped();
            }
        }
    }
}
