package io.sentry;

import com.android.tools.r8.annotations.SynthesizedClassV2;
import io.sentry.protocol.SentryId;
import io.sentry.protocol.SentryTransaction;
import io.sentry.protocol.User;
import java.util.List;
/* loaded from: classes3.dex */
public interface IHub {
    void addBreadcrumb(Breadcrumb breadcrumb);

    void addBreadcrumb(Breadcrumb breadcrumb, Hint hint);

    void addBreadcrumb(String str);

    void addBreadcrumb(String str, String str2);

    void bindClient(ISentryClient iSentryClient);

    SentryId captureEnvelope(SentryEnvelope sentryEnvelope);

    SentryId captureEnvelope(SentryEnvelope sentryEnvelope, Hint hint);

    SentryId captureEvent(SentryEvent sentryEvent);

    SentryId captureEvent(SentryEvent sentryEvent, Hint hint);

    SentryId captureEvent(SentryEvent sentryEvent, Hint hint, ScopeCallback scopeCallback);

    SentryId captureEvent(SentryEvent sentryEvent, ScopeCallback scopeCallback);

    SentryId captureException(Throwable th);

    SentryId captureException(Throwable th, Hint hint);

    SentryId captureException(Throwable th, Hint hint, ScopeCallback scopeCallback);

    SentryId captureException(Throwable th, ScopeCallback scopeCallback);

    SentryId captureMessage(String str);

    SentryId captureMessage(String str, ScopeCallback scopeCallback);

    SentryId captureMessage(String str, SentryLevel sentryLevel);

    SentryId captureMessage(String str, SentryLevel sentryLevel, ScopeCallback scopeCallback);

    SentryId captureTransaction(SentryTransaction sentryTransaction, Hint hint);

    SentryId captureTransaction(SentryTransaction sentryTransaction, TraceContext traceContext);

    SentryId captureTransaction(SentryTransaction sentryTransaction, TraceContext traceContext, Hint hint);

    SentryId captureTransaction(SentryTransaction sentryTransaction, TraceContext traceContext, Hint hint, ProfilingTraceData profilingTraceData);

    void captureUserFeedback(UserFeedback userFeedback);

    void clearBreadcrumbs();

    IHub clone();

    void close();

    void configureScope(ScopeCallback scopeCallback);

    void endSession();

    void flush(long j);

    SentryId getLastEventId();

    SentryOptions getOptions();

    ISpan getSpan();

    Boolean isCrashedLastRun();

    boolean isEnabled();

    void popScope();

    void pushScope();

    void removeExtra(String str);

    void removeTag(String str);

    void reportFullDisplayed();

    void setExtra(String str, String str2);

    void setFingerprint(List<String> list);

    void setLevel(SentryLevel sentryLevel);

    void setSpanContext(Throwable th, ISpan iSpan, String str);

    void setTag(String str, String str2);

    void setTransaction(String str);

    void setUser(User user);

    void startSession();

    ITransaction startTransaction(TransactionContext transactionContext);

    ITransaction startTransaction(TransactionContext transactionContext, CustomSamplingContext customSamplingContext);

    ITransaction startTransaction(TransactionContext transactionContext, CustomSamplingContext customSamplingContext, boolean z);

    ITransaction startTransaction(TransactionContext transactionContext, TransactionOptions transactionOptions);

    ITransaction startTransaction(TransactionContext transactionContext, boolean z);

    ITransaction startTransaction(String str, String str2);

    ITransaction startTransaction(String str, String str2, CustomSamplingContext customSamplingContext);

    ITransaction startTransaction(String str, String str2, CustomSamplingContext customSamplingContext, boolean z);

    ITransaction startTransaction(String str, String str2, boolean z);

    SentryTraceHeader traceHeaders();

    void withScope(ScopeCallback scopeCallback);

    @SynthesizedClassV2(kind = 8, versionHash = "ea87655719898b9807d7a88878e9de051d12af172d2fab563c9881b5e404e7d4")
    /* renamed from: io.sentry.IHub$-CC */
    /* loaded from: classes3.dex */
    public final /* synthetic */ class CC {
        public static SentryId $default$captureEvent(IHub _this, SentryEvent sentryEvent) {
            return _this.captureEvent(sentryEvent, new Hint());
        }

        public static SentryId $default$captureEvent(IHub _this, SentryEvent sentryEvent, ScopeCallback scopeCallback) {
            return _this.captureEvent(sentryEvent, new Hint(), scopeCallback);
        }

        public static SentryId $default$captureMessage(IHub _this, String str) {
            return _this.captureMessage(str, SentryLevel.INFO);
        }

        public static SentryId $default$captureMessage(IHub _this, String str, ScopeCallback scopeCallback) {
            return _this.captureMessage(str, SentryLevel.INFO, scopeCallback);
        }

        public static SentryId $default$captureEnvelope(IHub _this, SentryEnvelope sentryEnvelope) {
            return _this.captureEnvelope(sentryEnvelope, new Hint());
        }

        public static SentryId $default$captureException(IHub _this, Throwable th) {
            return _this.captureException(th, new Hint());
        }

        public static SentryId $default$captureException(IHub _this, Throwable th, ScopeCallback scopeCallback) {
            return _this.captureException(th, new Hint(), scopeCallback);
        }

        public static void $default$addBreadcrumb(IHub _this, Breadcrumb breadcrumb) {
            _this.addBreadcrumb(breadcrumb, new Hint());
        }

        public static void $default$addBreadcrumb(IHub _this, String str) {
            _this.addBreadcrumb(new Breadcrumb(str));
        }

        public static void $default$addBreadcrumb(IHub _this, String str, String str2) {
            Breadcrumb breadcrumb = new Breadcrumb(str);
            breadcrumb.setCategory(str2);
            _this.addBreadcrumb(breadcrumb);
        }

        public static SentryId $default$captureTransaction(IHub _this, SentryTransaction sentryTransaction, TraceContext traceContext, Hint hint) {
            return _this.captureTransaction(sentryTransaction, traceContext, hint, null);
        }

        public static SentryId $default$captureTransaction(IHub _this, SentryTransaction sentryTransaction, Hint hint) {
            return _this.captureTransaction(sentryTransaction, null, hint);
        }

        public static SentryId $default$captureTransaction(IHub _this, SentryTransaction sentryTransaction, TraceContext traceContext) {
            return _this.captureTransaction(sentryTransaction, traceContext, null);
        }

        public static ITransaction $default$startTransaction(IHub _this, TransactionContext transactionContext, boolean z) {
            return _this.startTransaction(transactionContext, (CustomSamplingContext) null, z);
        }

        public static ITransaction $default$startTransaction(IHub _this, String str, String str2, CustomSamplingContext customSamplingContext) {
            return _this.startTransaction(str, str2, customSamplingContext, false);
        }

        public static ITransaction $default$startTransaction(IHub _this, String str, String str2, CustomSamplingContext customSamplingContext, boolean z) {
            return _this.startTransaction(new TransactionContext(str, str2), customSamplingContext, z);
        }

        public static ITransaction $default$startTransaction(IHub _this, TransactionContext transactionContext, CustomSamplingContext customSamplingContext) {
            return _this.startTransaction(transactionContext, customSamplingContext, false);
        }

        public static ITransaction $default$startTransaction(IHub _this, String str, String str2) {
            return _this.startTransaction(str, str2, (CustomSamplingContext) null);
        }

        public static ITransaction $default$startTransaction(IHub _this, String str, String str2, boolean z) {
            return _this.startTransaction(str, str2, null, z);
        }
    }
}
