package io.sentry;

import io.sentry.protocol.SentryId;
import io.sentry.protocol.TransactionNameSource;
import io.sentry.util.Objects;
/* loaded from: classes3.dex */
public final class TransactionContext extends SpanContext {
    private Baggage baggage;
    private Instrumenter instrumenter;
    private final String name;
    private TracesSamplingDecision parentSamplingDecision;
    private final TransactionNameSource transactionNameSource;

    public static TransactionContext fromSentryTrace(String str, String str2, SentryTraceHeader sentryTraceHeader) {
        return fromSentryTrace(str, TransactionNameSource.CUSTOM, str2, sentryTraceHeader, null, null);
    }

    public static TransactionContext fromSentryTrace(String str, TransactionNameSource transactionNameSource, String str2, SentryTraceHeader sentryTraceHeader) {
        Boolean isSampled = sentryTraceHeader.isSampled();
        return new TransactionContext(str, str2, sentryTraceHeader.getTraceId(), new SpanId(), transactionNameSource, sentryTraceHeader.getSpanId(), isSampled == null ? null : new TracesSamplingDecision(isSampled), null);
    }

    /* JADX WARN: Removed duplicated region for block: B:17:0x0033  */
    /* JADX WARN: Removed duplicated region for block: B:18:0x003a  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static TransactionContext fromSentryTrace(String str, TransactionNameSource transactionNameSource, String str2, SentryTraceHeader sentryTraceHeader, Baggage baggage, SpanId spanId) {
        TracesSamplingDecision tracesSamplingDecision;
        Boolean isSampled = sentryTraceHeader.isSampled();
        TracesSamplingDecision tracesSamplingDecision2 = isSampled == null ? null : new TracesSamplingDecision(isSampled);
        if (baggage != null) {
            baggage.freeze();
            Double sampleRateDouble = baggage.getSampleRateDouble();
            Boolean valueOf = Boolean.valueOf(isSampled != null ? isSampled.booleanValue() : true);
            if (sampleRateDouble != null) {
                tracesSamplingDecision = new TracesSamplingDecision(valueOf, sampleRateDouble);
                return new TransactionContext(str, str2, sentryTraceHeader.getTraceId(), spanId != null ? new SpanId() : spanId, transactionNameSource, sentryTraceHeader.getSpanId(), tracesSamplingDecision, baggage);
            }
            tracesSamplingDecision2 = new TracesSamplingDecision(valueOf);
        }
        tracesSamplingDecision = tracesSamplingDecision2;
        return new TransactionContext(str, str2, sentryTraceHeader.getTraceId(), spanId != null ? new SpanId() : spanId, transactionNameSource, sentryTraceHeader.getSpanId(), tracesSamplingDecision, baggage);
    }

    public TransactionContext(String str, String str2) {
        this(str, str2, (TracesSamplingDecision) null);
    }

    public TransactionContext(String str, TransactionNameSource transactionNameSource, String str2) {
        this(str, transactionNameSource, str2, null);
    }

    public TransactionContext(String str, String str2, TracesSamplingDecision tracesSamplingDecision) {
        this(str, TransactionNameSource.CUSTOM, str2, tracesSamplingDecision);
    }

    public TransactionContext(String str, TransactionNameSource transactionNameSource, String str2, TracesSamplingDecision tracesSamplingDecision) {
        super(str2);
        this.instrumenter = Instrumenter.SENTRY;
        this.name = (String) Objects.requireNonNull(str, "name is required");
        this.transactionNameSource = transactionNameSource;
        setSamplingDecision(tracesSamplingDecision);
    }

    public TransactionContext(String str, String str2, SentryId sentryId, SpanId spanId, TransactionNameSource transactionNameSource, SpanId spanId2, TracesSamplingDecision tracesSamplingDecision, Baggage baggage) {
        super(sentryId, spanId, str2, spanId2, null);
        this.instrumenter = Instrumenter.SENTRY;
        this.name = (String) Objects.requireNonNull(str, "name is required");
        this.parentSamplingDecision = tracesSamplingDecision;
        this.transactionNameSource = transactionNameSource;
        this.baggage = baggage;
    }

    public String getName() {
        return this.name;
    }

    public Boolean getParentSampled() {
        TracesSamplingDecision tracesSamplingDecision = this.parentSamplingDecision;
        if (tracesSamplingDecision == null) {
            return null;
        }
        return tracesSamplingDecision.getSampled();
    }

    public TracesSamplingDecision getParentSamplingDecision() {
        return this.parentSamplingDecision;
    }

    public Baggage getBaggage() {
        return this.baggage;
    }

    public void setParentSampled(Boolean bool) {
        if (bool == null) {
            this.parentSamplingDecision = null;
        } else {
            this.parentSamplingDecision = new TracesSamplingDecision(bool);
        }
    }

    public void setParentSampled(Boolean bool, Boolean bool2) {
        if (bool == null) {
            this.parentSamplingDecision = null;
        } else if (bool2 == null) {
            this.parentSamplingDecision = new TracesSamplingDecision(bool);
        } else {
            this.parentSamplingDecision = new TracesSamplingDecision(bool, null, bool2, null);
        }
    }

    public TransactionNameSource getTransactionNameSource() {
        return this.transactionNameSource;
    }

    public Instrumenter getInstrumenter() {
        return this.instrumenter;
    }

    public void setInstrumenter(Instrumenter instrumenter) {
        this.instrumenter = instrumenter;
    }
}
