package io.sentry.android.core;

import android.app.Activity;
import io.sentry.Attachment;
import io.sentry.EventProcessor;
import io.sentry.Hint;
import io.sentry.SentryEvent;
import io.sentry.SentryLevel;
import io.sentry.TypeCheckHint;
import io.sentry.android.core.internal.util.ScreenshotUtils;
import io.sentry.protocol.SentryTransaction;
import io.sentry.util.HintUtils;
import io.sentry.util.Objects;
/* loaded from: classes3.dex */
public final class ScreenshotEventProcessor implements EventProcessor {
    private final BuildInfoProvider buildInfoProvider;
    private final SentryAndroidOptions options;

    @Override // io.sentry.EventProcessor
    public /* synthetic */ SentryTransaction process(SentryTransaction sentryTransaction, Hint hint) {
        return EventProcessor.CC.$default$process(this, sentryTransaction, hint);
    }

    public ScreenshotEventProcessor(SentryAndroidOptions sentryAndroidOptions, BuildInfoProvider buildInfoProvider) {
        this.options = (SentryAndroidOptions) Objects.requireNonNull(sentryAndroidOptions, "SentryAndroidOptions is required");
        this.buildInfoProvider = (BuildInfoProvider) Objects.requireNonNull(buildInfoProvider, "BuildInfoProvider is required");
    }

    @Override // io.sentry.EventProcessor
    public SentryEvent process(SentryEvent sentryEvent, Hint hint) {
        byte[] takeScreenshot;
        if (sentryEvent.isErrored()) {
            if (!this.options.isAttachScreenshot()) {
                this.options.getLogger().log(SentryLevel.DEBUG, "attachScreenshot is disabled.", new Object[0]);
                return sentryEvent;
            }
            Activity activity = CurrentActivityHolder.getInstance().getActivity();
            if (activity == null || HintUtils.isFromHybridSdk(hint) || (takeScreenshot = ScreenshotUtils.takeScreenshot(activity, this.options.getLogger(), this.buildInfoProvider)) == null) {
                return sentryEvent;
            }
            hint.setScreenshot(Attachment.fromScreenshot(takeScreenshot));
            hint.set(TypeCheckHint.ANDROID_ACTIVITY, activity);
            return sentryEvent;
        }
        return sentryEvent;
    }
}
