package kotlin.reflect.jvm.internal.impl.load.java.typeEnhancement;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.reflect.jvm.internal.impl.builtins.jvm.JavaToKotlinClassMap;
import kotlin.reflect.jvm.internal.impl.load.java.AbstractAnnotationTypeQualifierResolver;
import kotlin.reflect.jvm.internal.impl.load.java.AnnotationQualifierApplicabilityType;
import kotlin.reflect.jvm.internal.impl.load.java.JavaDefaultQualifiers;
import kotlin.reflect.jvm.internal.impl.load.java.JavaTypeQualifiersByElementType;
import kotlin.reflect.jvm.internal.impl.name.FqNameUnsafe;
import kotlin.reflect.jvm.internal.impl.types.model.KotlinTypeMarker;
import kotlin.reflect.jvm.internal.impl.types.model.TypeConstructorMarker;
import kotlin.reflect.jvm.internal.impl.types.model.TypeParameterMarker;
import kotlin.reflect.jvm.internal.impl.types.model.TypeSystemContext;
import kotlin.reflect.jvm.internal.impl.types.model.TypeVariance;
/* compiled from: AbstractSignatureParts.kt */
/* loaded from: classes4.dex */
public abstract class AbstractSignatureParts<TAnnotation> {
    public abstract AbstractAnnotationTypeQualifierResolver<TAnnotation> getAnnotationTypeQualifierResolver();

    public abstract Iterable<TAnnotation> getAnnotations(KotlinTypeMarker kotlinTypeMarker);

    public abstract Iterable<TAnnotation> getContainerAnnotations();

    public abstract AnnotationQualifierApplicabilityType getContainerApplicabilityType();

    public abstract JavaTypeQualifiersByElementType getContainerDefaultTypeQualifiers();

    public abstract boolean getContainerIsVarargParameter();

    public abstract boolean getEnableImprovementsInStrictMode();

    public abstract KotlinTypeMarker getEnhancedForWarnings(KotlinTypeMarker kotlinTypeMarker);

    public boolean getForceOnlyHeadTypeConstructor() {
        return false;
    }

    public abstract boolean getForceWarning(TAnnotation tannotation);

    public abstract FqNameUnsafe getFqNameUnsafe(KotlinTypeMarker kotlinTypeMarker);

    public abstract boolean getSkipRawTypeArguments();

    public abstract TypeSystemContext getTypeSystem();

    public abstract boolean isArrayOrPrimitiveArray(KotlinTypeMarker kotlinTypeMarker);

    public abstract boolean isCovariant();

    public abstract boolean isEqual(KotlinTypeMarker kotlinTypeMarker, KotlinTypeMarker kotlinTypeMarker2);

    public abstract boolean isFromJava(TypeParameterMarker typeParameterMarker);

    public boolean isNotNullTypeParameterCompat(KotlinTypeMarker kotlinTypeMarker) {
        Intrinsics.checkNotNullParameter(kotlinTypeMarker, "<this>");
        return false;
    }

    private final NullabilityQualifier getNullabilityQualifier(KotlinTypeMarker kotlinTypeMarker) {
        TypeSystemContext typeSystem = getTypeSystem();
        if (typeSystem.isMarkedNullable(typeSystem.lowerBoundIfFlexible(kotlinTypeMarker))) {
            return NullabilityQualifier.NULLABLE;
        }
        if (typeSystem.isMarkedNullable(typeSystem.upperBoundIfFlexible(kotlinTypeMarker))) {
            return null;
        }
        return NullabilityQualifier.NOT_NULL;
    }

    private final JavaTypeQualifiers extractQualifiers(KotlinTypeMarker kotlinTypeMarker) {
        NullabilityQualifier nullabilityQualifier;
        NullabilityQualifier nullabilityQualifier2 = getNullabilityQualifier(kotlinTypeMarker);
        MutabilityQualifier mutabilityQualifier = null;
        if (nullabilityQualifier2 == null) {
            KotlinTypeMarker enhancedForWarnings = getEnhancedForWarnings(kotlinTypeMarker);
            nullabilityQualifier = enhancedForWarnings != null ? getNullabilityQualifier(enhancedForWarnings) : null;
        } else {
            nullabilityQualifier = nullabilityQualifier2;
        }
        TypeSystemContext typeSystem = getTypeSystem();
        if (JavaToKotlinClassMap.INSTANCE.isReadOnly(getFqNameUnsafe(typeSystem.lowerBoundIfFlexible(kotlinTypeMarker)))) {
            mutabilityQualifier = MutabilityQualifier.READ_ONLY;
        } else if (JavaToKotlinClassMap.INSTANCE.isMutable(getFqNameUnsafe(typeSystem.upperBoundIfFlexible(kotlinTypeMarker)))) {
            mutabilityQualifier = MutabilityQualifier.MUTABLE;
        }
        return new JavaTypeQualifiers(nullabilityQualifier, mutabilityQualifier, getTypeSystem().isDefinitelyNotNullType(kotlinTypeMarker) || isNotNullTypeParameterCompat(kotlinTypeMarker), nullabilityQualifier != nullabilityQualifier2);
    }

    /* JADX WARN: Code restructure failed: missing block: B:90:0x0138, code lost:
        if ((r0 != null && r0.getDefinitelyNotNull()) != false) goto L100;
     */
    /* JADX WARN: Removed duplicated region for block: B:104:0x0162  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private final JavaTypeQualifiers extractQualifiersFromAnnotations(TypeAndDefaultQualifiers typeAndDefaultQualifiers) {
        List emptyList;
        AnnotationQualifierApplicabilityType containerApplicabilityType;
        NullabilityQualifierWithMigrationStatus nullabilityQualifier;
        boolean z;
        TypeParameterMarker typeParameterForArgument;
        NullabilityQualifierWithMigrationStatus nullabilityQualifierWithMigrationStatus;
        TypeConstructorMarker typeConstructor;
        if (typeAndDefaultQualifiers.getType() == null) {
            TypeSystemContext typeSystem = getTypeSystem();
            TypeParameterMarker typeParameterForArgument2 = typeAndDefaultQualifiers.getTypeParameterForArgument();
            if ((typeParameterForArgument2 != null ? typeSystem.getVariance(typeParameterForArgument2) : null) == TypeVariance.IN) {
                return JavaTypeQualifiers.Companion.getNONE();
            }
        }
        boolean z2 = true;
        boolean z3 = typeAndDefaultQualifiers.getTypeParameterForArgument() == null;
        KotlinTypeMarker type = typeAndDefaultQualifiers.getType();
        if (type == null || (emptyList = getAnnotations(type)) == null) {
            emptyList = CollectionsKt.emptyList();
        }
        TypeSystemContext typeSystem2 = getTypeSystem();
        KotlinTypeMarker type2 = typeAndDefaultQualifiers.getType();
        TypeParameterMarker typeParameterClassifier = (type2 == null || (typeConstructor = typeSystem2.typeConstructor(type2)) == null) ? null : typeSystem2.getTypeParameterClassifier(typeConstructor);
        boolean z4 = getContainerApplicabilityType() == AnnotationQualifierApplicabilityType.TYPE_PARAMETER_BOUNDS;
        if (z3) {
            if (!z4 && getEnableImprovementsInStrictMode()) {
                KotlinTypeMarker type3 = typeAndDefaultQualifiers.getType();
                if (type3 != null && isArrayOrPrimitiveArray(type3)) {
                    Iterable<TAnnotation> containerAnnotations = getContainerAnnotations();
                    ArrayList arrayList = new ArrayList();
                    for (TAnnotation tannotation : containerAnnotations) {
                        if (!getAnnotationTypeQualifierResolver().isTypeUseAnnotation(tannotation)) {
                            arrayList.add(tannotation);
                        }
                    }
                    emptyList = CollectionsKt.plus((Collection) arrayList, (Iterable) emptyList);
                }
            }
            emptyList = CollectionsKt.plus((Iterable) getContainerAnnotations(), (Iterable) emptyList);
        }
        MutabilityQualifier extractMutability = getAnnotationTypeQualifierResolver().extractMutability(emptyList);
        NullabilityQualifierWithMigrationStatus extractNullability = getAnnotationTypeQualifierResolver().extractNullability((Iterable) emptyList, (Function1) new AbstractSignatureParts$extractQualifiersFromAnnotations$annotationsNullability$1(this));
        if (extractNullability != null) {
            return new JavaTypeQualifiers(extractNullability.getQualifier(), extractMutability, (extractNullability.getQualifier() != NullabilityQualifier.NOT_NULL || typeParameterClassifier == null) ? false : false, extractNullability.isForWarningOnly());
        }
        if (z3 || z4) {
            containerApplicabilityType = getContainerApplicabilityType();
        } else {
            containerApplicabilityType = AnnotationQualifierApplicabilityType.TYPE_USE;
        }
        JavaTypeQualifiersByElementType defaultQualifiers = typeAndDefaultQualifiers.getDefaultQualifiers();
        JavaDefaultQualifiers javaDefaultQualifiers = defaultQualifiers != null ? defaultQualifiers.get(containerApplicabilityType) : null;
        NullabilityQualifierWithMigrationStatus boundsNullability = typeParameterClassifier != null ? getBoundsNullability(typeParameterClassifier) : null;
        if (boundsNullability == null || (nullabilityQualifier = NullabilityQualifierWithMigrationStatus.copy$default(boundsNullability, NullabilityQualifier.NOT_NULL, false, 2, null)) == null) {
            nullabilityQualifier = javaDefaultQualifiers != null ? javaDefaultQualifiers.getNullabilityQualifier() : null;
        }
        if ((boundsNullability != null ? boundsNullability.getQualifier() : null) != NullabilityQualifier.NOT_NULL) {
            if (typeParameterClassifier != null) {
            }
            z = false;
            typeParameterForArgument = typeAndDefaultQualifiers.getTypeParameterForArgument();
            if (typeParameterForArgument != null || (nullabilityQualifierWithMigrationStatus = getBoundsNullability(typeParameterForArgument)) == null) {
                nullabilityQualifierWithMigrationStatus = null;
            } else if (nullabilityQualifierWithMigrationStatus.getQualifier() == NullabilityQualifier.NULLABLE) {
                nullabilityQualifierWithMigrationStatus = NullabilityQualifierWithMigrationStatus.copy$default(nullabilityQualifierWithMigrationStatus, NullabilityQualifier.FORCE_FLEXIBILITY, false, 2, null);
            }
            NullabilityQualifierWithMigrationStatus mostSpecific = mostSpecific(nullabilityQualifierWithMigrationStatus, nullabilityQualifier);
            return new JavaTypeQualifiers(mostSpecific != null ? mostSpecific.getQualifier() : null, extractMutability, z, (mostSpecific == null && mostSpecific.isForWarningOnly()) ? false : false);
        }
        z = true;
        typeParameterForArgument = typeAndDefaultQualifiers.getTypeParameterForArgument();
        if (typeParameterForArgument != null) {
        }
        nullabilityQualifierWithMigrationStatus = null;
        NullabilityQualifierWithMigrationStatus mostSpecific2 = mostSpecific(nullabilityQualifierWithMigrationStatus, nullabilityQualifier);
        return new JavaTypeQualifiers(mostSpecific2 != null ? mostSpecific2.getQualifier() : null, extractMutability, z, (mostSpecific2 == null && mostSpecific2.isForWarningOnly()) ? false : false);
    }

    private final NullabilityQualifierWithMigrationStatus mostSpecific(NullabilityQualifierWithMigrationStatus nullabilityQualifierWithMigrationStatus, NullabilityQualifierWithMigrationStatus nullabilityQualifierWithMigrationStatus2) {
        return nullabilityQualifierWithMigrationStatus == null ? nullabilityQualifierWithMigrationStatus2 : nullabilityQualifierWithMigrationStatus2 == null ? nullabilityQualifierWithMigrationStatus : (!nullabilityQualifierWithMigrationStatus.isForWarningOnly() || nullabilityQualifierWithMigrationStatus2.isForWarningOnly()) ? (nullabilityQualifierWithMigrationStatus.isForWarningOnly() || !nullabilityQualifierWithMigrationStatus2.isForWarningOnly()) ? (nullabilityQualifierWithMigrationStatus.getQualifier().compareTo(nullabilityQualifierWithMigrationStatus2.getQualifier()) >= 0 && nullabilityQualifierWithMigrationStatus.getQualifier().compareTo(nullabilityQualifierWithMigrationStatus2.getQualifier()) > 0) ? nullabilityQualifierWithMigrationStatus : nullabilityQualifierWithMigrationStatus2 : nullabilityQualifierWithMigrationStatus : nullabilityQualifierWithMigrationStatus2;
    }

    private final NullabilityQualifierWithMigrationStatus getBoundsNullability(TypeParameterMarker typeParameterMarker) {
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        ArrayList arrayList;
        boolean z6;
        TypeSystemContext typeSystem = getTypeSystem();
        if (isFromJava(typeParameterMarker)) {
            List<KotlinTypeMarker> upperBounds = typeSystem.getUpperBounds(typeParameterMarker);
            List<KotlinTypeMarker> list = upperBounds;
            boolean z7 = list instanceof Collection;
            if (!z7 || !list.isEmpty()) {
                for (KotlinTypeMarker kotlinTypeMarker : list) {
                    if (!typeSystem.isError(kotlinTypeMarker)) {
                        z = false;
                        break;
                    }
                }
            }
            z = true;
            if (z) {
                return null;
            }
            if (!z7 || !list.isEmpty()) {
                for (KotlinTypeMarker kotlinTypeMarker2 : list) {
                    if (getNullabilityQualifier(kotlinTypeMarker2) != null) {
                        z2 = true;
                        continue;
                    } else {
                        z2 = false;
                        continue;
                    }
                    if (z2) {
                        z3 = true;
                        break;
                    }
                }
            }
            z3 = false;
            if (z3) {
                arrayList = upperBounds;
            } else {
                if (!z7 || !list.isEmpty()) {
                    for (KotlinTypeMarker kotlinTypeMarker3 : list) {
                        if (getEnhancedForWarnings(kotlinTypeMarker3) != null) {
                            z4 = true;
                            continue;
                        } else {
                            z4 = false;
                            continue;
                        }
                        if (z4) {
                            z5 = true;
                            break;
                        }
                    }
                }
                z5 = false;
                if (!z5) {
                    return null;
                }
                ArrayList arrayList2 = new ArrayList();
                for (KotlinTypeMarker kotlinTypeMarker4 : list) {
                    KotlinTypeMarker enhancedForWarnings = getEnhancedForWarnings(kotlinTypeMarker4);
                    if (enhancedForWarnings != null) {
                        arrayList2.add(enhancedForWarnings);
                    }
                }
                arrayList = arrayList2;
            }
            List<KotlinTypeMarker> list2 = arrayList;
            if (!(list2 instanceof Collection) || !list2.isEmpty()) {
                for (KotlinTypeMarker kotlinTypeMarker5 : list2) {
                    if (!typeSystem.isNullableType(kotlinTypeMarker5)) {
                        z6 = false;
                        break;
                    }
                }
            }
            z6 = true;
            return new NullabilityQualifierWithMigrationStatus(z6 ? NullabilityQualifier.NULLABLE : NullabilityQualifier.NOT_NULL, arrayList != upperBounds);
        }
        return null;
    }

    /* JADX WARN: Code restructure failed: missing block: B:21:0x006a, code lost:
        if (r10 != false) goto L64;
     */
    /* JADX WARN: Removed duplicated region for block: B:26:0x0072  */
    /* JADX WARN: Removed duplicated region for block: B:27:0x0074  */
    /* JADX WARN: Removed duplicated region for block: B:30:0x007d  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final Function1<Integer, JavaTypeQualifiers> computeIndexedQualifiers(KotlinTypeMarker kotlinTypeMarker, Iterable<? extends KotlinTypeMarker> overrides, TypeEnhancementInfo typeEnhancementInfo, boolean z) {
        boolean z2;
        int size;
        int i;
        KotlinTypeMarker type;
        boolean z3;
        Intrinsics.checkNotNullParameter(kotlinTypeMarker, "<this>");
        Intrinsics.checkNotNullParameter(overrides, "overrides");
        List<TypeAndDefaultQualifiers> indexed = toIndexed(kotlinTypeMarker);
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(overrides, 10));
        for (KotlinTypeMarker kotlinTypeMarker2 : overrides) {
            arrayList.add(toIndexed(kotlinTypeMarker2));
        }
        ArrayList<List> arrayList2 = arrayList;
        if (!getForceOnlyHeadTypeConstructor()) {
            if (isCovariant()) {
                if (!(overrides instanceof Collection) || !((Collection) overrides).isEmpty()) {
                    for (KotlinTypeMarker kotlinTypeMarker3 : overrides) {
                        if (!isEqual(kotlinTypeMarker, kotlinTypeMarker3)) {
                            z3 = true;
                            break;
                        }
                    }
                }
                z3 = false;
            }
            z2 = false;
            size = !z2 ? 1 : indexed.size();
            JavaTypeQualifiers[] javaTypeQualifiersArr = new JavaTypeQualifiers[size];
            i = 0;
            while (i < size) {
                JavaTypeQualifiers extractQualifiersFromAnnotations = extractQualifiersFromAnnotations(indexed.get(i));
                ArrayList arrayList3 = new ArrayList();
                for (List list : arrayList2) {
                    TypeAndDefaultQualifiers typeAndDefaultQualifiers = (TypeAndDefaultQualifiers) CollectionsKt.getOrNull(list, i);
                    JavaTypeQualifiers extractQualifiers = (typeAndDefaultQualifiers == null || (type = typeAndDefaultQualifiers.getType()) == null) ? null : extractQualifiers(type);
                    if (extractQualifiers != null) {
                        arrayList3.add(extractQualifiers);
                    }
                }
                javaTypeQualifiersArr[i] = TypeEnhancementUtilsKt.computeQualifiersForOverride(extractQualifiersFromAnnotations, arrayList3, i == 0 && isCovariant(), i == 0 && getContainerIsVarargParameter(), z);
                i++;
            }
            return new AbstractSignatureParts$computeIndexedQualifiers$1(typeEnhancementInfo, javaTypeQualifiersArr);
        }
        z2 = true;
        if (!z2) {
        }
        JavaTypeQualifiers[] javaTypeQualifiersArr2 = new JavaTypeQualifiers[size];
        i = 0;
        while (i < size) {
        }
        return new AbstractSignatureParts$computeIndexedQualifiers$1(typeEnhancementInfo, javaTypeQualifiersArr2);
    }

    private final <T> void flattenTree(T t, List<T> list, Function1<? super T, ? extends Iterable<? extends T>> function1) {
        list.add(t);
        Iterable<? extends T> invoke = function1.invoke(t);
        if (invoke != null) {
            for (T t2 : invoke) {
                flattenTree(t2, list, function1);
            }
        }
    }

    private final <T> List<T> flattenTree(T t, Function1<? super T, ? extends Iterable<? extends T>> function1) {
        ArrayList arrayList = new ArrayList(1);
        flattenTree(t, arrayList, function1);
        return arrayList;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final JavaTypeQualifiersByElementType extractAndMergeDefaultQualifiers(KotlinTypeMarker kotlinTypeMarker, JavaTypeQualifiersByElementType javaTypeQualifiersByElementType) {
        return getAnnotationTypeQualifierResolver().extractAndMergeDefaultQualifiers(javaTypeQualifiersByElementType, getAnnotations(kotlinTypeMarker));
    }

    private final List<TypeAndDefaultQualifiers> toIndexed(KotlinTypeMarker kotlinTypeMarker) {
        return flattenTree(new TypeAndDefaultQualifiers(kotlinTypeMarker, extractAndMergeDefaultQualifiers(kotlinTypeMarker, getContainerDefaultTypeQualifiers()), null), new AbstractSignatureParts$toIndexed$1$1(this, getTypeSystem()));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* compiled from: AbstractSignatureParts.kt */
    /* loaded from: classes4.dex */
    public static final class TypeAndDefaultQualifiers {
        private final JavaTypeQualifiersByElementType defaultQualifiers;
        private final KotlinTypeMarker type;
        private final TypeParameterMarker typeParameterForArgument;

        public TypeAndDefaultQualifiers(KotlinTypeMarker kotlinTypeMarker, JavaTypeQualifiersByElementType javaTypeQualifiersByElementType, TypeParameterMarker typeParameterMarker) {
            this.type = kotlinTypeMarker;
            this.defaultQualifiers = javaTypeQualifiersByElementType;
            this.typeParameterForArgument = typeParameterMarker;
        }

        public final KotlinTypeMarker getType() {
            return this.type;
        }

        public final JavaTypeQualifiersByElementType getDefaultQualifiers() {
            return this.defaultQualifiers;
        }

        public final TypeParameterMarker getTypeParameterForArgument() {
            return this.typeParameterForArgument;
        }
    }
}
