package kotlin.reflect.jvm.internal.impl.load.java.typeEnhancement;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.reflect.jvm.internal.impl.descriptors.CallableDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.CallableMemberDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ClassDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ClassifierDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.DeclarationDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.DescriptorUtilKt;
import kotlin.reflect.jvm.internal.impl.descriptors.FunctionDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.PropertyDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ReceiverParameterDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.TypeParameterDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ValueParameterDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.annotations.Annotated;
import kotlin.reflect.jvm.internal.impl.descriptors.annotations.Annotations;
import kotlin.reflect.jvm.internal.impl.descriptors.impl.PropertyGetterDescriptorImpl;
import kotlin.reflect.jvm.internal.impl.load.java.AnnotationQualifierApplicabilityType;
import kotlin.reflect.jvm.internal.impl.load.java.DeprecationCausedByFunctionNInfo;
import kotlin.reflect.jvm.internal.impl.load.java.UtilsKt;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaCallableMemberDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaMethodDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaPropertyDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.lazy.ContextKt;
import kotlin.reflect.jvm.internal.impl.load.java.lazy.LazyJavaResolverContext;
import kotlin.reflect.jvm.internal.impl.load.java.lazy.descriptors.JavaDescriptorUtilKt;
import kotlin.reflect.jvm.internal.impl.load.java.lazy.descriptors.LazyJavaAnnotationDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.lazy.descriptors.LazyJavaClassDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaAnnotation;
import kotlin.reflect.jvm.internal.impl.load.kotlin.MethodSignatureBuildingUtilsKt;
import kotlin.reflect.jvm.internal.impl.load.kotlin.MethodSignatureMappingKt;
import kotlin.reflect.jvm.internal.impl.load.kotlin.SignatureBuildingComponents;
import kotlin.reflect.jvm.internal.impl.resolve.deprecation.DescriptorBasedDeprecationInfoKt;
import kotlin.reflect.jvm.internal.impl.types.KotlinType;
import kotlin.reflect.jvm.internal.impl.types.TypeUtils;
import kotlin.reflect.jvm.internal.impl.types.typeUtil.TypeUtilsKt;
/* compiled from: signatureEnhancement.kt */
/* loaded from: classes4.dex */
public final class SignatureEnhancement {
    private final JavaTypeEnhancement typeEnhancement;

    public SignatureEnhancement(JavaTypeEnhancement typeEnhancement) {
        Intrinsics.checkNotNullParameter(typeEnhancement, "typeEnhancement");
        this.typeEnhancement = typeEnhancement;
    }

    /* JADX WARN: Multi-variable type inference failed */
    public final <D extends CallableMemberDescriptor> Collection<D> enhanceSignatures(LazyJavaResolverContext c, Collection<? extends D> platformSignatures) {
        Intrinsics.checkNotNullParameter(c, "c");
        Intrinsics.checkNotNullParameter(platformSignatures, "platformSignatures");
        Collection<? extends D> collection = platformSignatures;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(collection, 10));
        Iterator<T> it = collection.iterator();
        while (it.hasNext()) {
            arrayList.add(enhanceSignature((CallableMemberDescriptor) it.next(), c));
        }
        return arrayList;
    }

    private final <D extends CallableMemberDescriptor> Annotations getDefaultAnnotations(D d, LazyJavaResolverContext lazyJavaResolverContext) {
        ClassifierDescriptor topLevelContainingClassifier = DescriptorUtilKt.getTopLevelContainingClassifier(d);
        if (topLevelContainingClassifier == null) {
            return d.getAnnotations();
        }
        LazyJavaClassDescriptor lazyJavaClassDescriptor = topLevelContainingClassifier instanceof LazyJavaClassDescriptor ? (LazyJavaClassDescriptor) topLevelContainingClassifier : null;
        List<JavaAnnotation> moduleAnnotations = lazyJavaClassDescriptor != null ? lazyJavaClassDescriptor.getModuleAnnotations() : null;
        List<JavaAnnotation> list = moduleAnnotations;
        if (list == null || list.isEmpty()) {
            return d.getAnnotations();
        }
        List<JavaAnnotation> list2 = moduleAnnotations;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(list2, 10));
        for (JavaAnnotation javaAnnotation : list2) {
            arrayList.add(new LazyJavaAnnotationDescriptor(lazyJavaResolverContext, javaAnnotation, true));
        }
        return Annotations.Companion.create(CollectionsKt.plus((Iterable) d.getAnnotations(), (Iterable) arrayList));
    }

    /* JADX WARN: Removed duplicated region for block: B:104:0x01fa  */
    /* JADX WARN: Removed duplicated region for block: B:105:0x020b  */
    /* JADX WARN: Removed duplicated region for block: B:107:0x020f A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:116:0x022e  */
    /* JADX WARN: Removed duplicated region for block: B:126:0x0243  */
    /* JADX WARN: Removed duplicated region for block: B:130:0x0251  */
    /* JADX WARN: Removed duplicated region for block: B:134:0x026d  */
    /* JADX WARN: Removed duplicated region for block: B:143:0x0298  */
    /* JADX WARN: Removed duplicated region for block: B:23:0x005a  */
    /* JADX WARN: Removed duplicated region for block: B:32:0x0083  */
    /* JADX WARN: Removed duplicated region for block: B:35:0x0089  */
    /* JADX WARN: Removed duplicated region for block: B:36:0x008d  */
    /* JADX WARN: Removed duplicated region for block: B:38:0x0090  */
    /* JADX WARN: Removed duplicated region for block: B:43:0x00bb  */
    /* JADX WARN: Removed duplicated region for block: B:46:0x00d7  */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0111  */
    /* JADX WARN: Removed duplicated region for block: B:64:0x015d  */
    /* JADX WARN: Removed duplicated region for block: B:65:0x015f  */
    /* JADX WARN: Removed duplicated region for block: B:68:0x0164  */
    /* JADX WARN: Removed duplicated region for block: B:73:0x016f  */
    /* JADX WARN: Removed duplicated region for block: B:74:0x0172  */
    /* JADX WARN: Removed duplicated region for block: B:77:0x0177  */
    /* JADX WARN: Removed duplicated region for block: B:78:0x017d  */
    /* JADX WARN: Removed duplicated region for block: B:81:0x01a4  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private final <D extends CallableMemberDescriptor> D enhanceSignature(D d, LazyJavaResolverContext lazyJavaResolverContext) {
        PropertyGetterDescriptorImpl propertyGetterDescriptorImpl;
        KotlinType kotlinType;
        JavaMethodDescriptor javaMethodDescriptor;
        PredefinedFunctionEnhancementInfo predefinedFunctionEnhancementInfo;
        PropertyDescriptor propertyDescriptor;
        AnnotationQualifierApplicabilityType annotationQualifierApplicabilityType;
        KotlinType enhance$default;
        KotlinType returnType;
        boolean z;
        KotlinType kotlinType2;
        ArrayList<KotlinType> arrayList;
        boolean z2;
        boolean z3;
        KotlinType type;
        List<TypeEnhancementInfo> parametersInfo;
        if (d instanceof JavaCallableMemberDescriptor) {
            JavaCallableMemberDescriptor javaCallableMemberDescriptor = (JavaCallableMemberDescriptor) d;
            boolean z4 = true;
            if (javaCallableMemberDescriptor.getKind() == CallableMemberDescriptor.Kind.FAKE_OVERRIDE && javaCallableMemberDescriptor.getOriginal().getOverriddenDescriptors().size() == 1) {
                return d;
            }
            LazyJavaResolverContext copyWithNewDefaultTypeQualifiers = ContextKt.copyWithNewDefaultTypeQualifiers(lazyJavaResolverContext, getDefaultAnnotations(d, lazyJavaResolverContext));
            if (d instanceof JavaPropertyDescriptor) {
                JavaPropertyDescriptor javaPropertyDescriptor = (JavaPropertyDescriptor) d;
                PropertyGetterDescriptorImpl getter = javaPropertyDescriptor.getGetter();
                if ((getter == null || getter.isDefault()) ? false : true) {
                    PropertyGetterDescriptorImpl getter2 = javaPropertyDescriptor.getGetter();
                    Intrinsics.checkNotNull(getter2);
                    propertyGetterDescriptorImpl = getter2;
                    TypeEnhancementInfo typeEnhancementInfo = null;
                    if (javaCallableMemberDescriptor.getExtensionReceiverParameter() == null) {
                        FunctionDescriptor functionDescriptor = (FunctionDescriptor) (!(propertyGetterDescriptorImpl instanceof FunctionDescriptor) ? null : propertyGetterDescriptorImpl);
                        kotlinType = enhanceValueParameter(d, functionDescriptor != null ? (ValueParameterDescriptor) functionDescriptor.getUserData(JavaMethodDescriptor.ORIGINAL_VALUE_PARAMETER_FOR_EXTENSION_RECEIVER) : null, copyWithNewDefaultTypeQualifiers, null, false, SignatureEnhancement$enhanceSignature$receiverTypeEnhancement$1.INSTANCE);
                    } else {
                        kotlinType = null;
                    }
                    javaMethodDescriptor = !(d instanceof JavaMethodDescriptor) ? (JavaMethodDescriptor) d : null;
                    if (javaMethodDescriptor != null) {
                        SignatureBuildingComponents signatureBuildingComponents = SignatureBuildingComponents.INSTANCE;
                        DeclarationDescriptor containingDeclaration = javaMethodDescriptor.getContainingDeclaration();
                        Intrinsics.checkNotNull(containingDeclaration, "null cannot be cast to non-null type org.jetbrains.kotlin.descriptors.ClassDescriptor");
                        String signature = MethodSignatureBuildingUtilsKt.signature(signatureBuildingComponents, (ClassDescriptor) containingDeclaration, MethodSignatureMappingKt.computeJvmDescriptor$default(javaMethodDescriptor, false, false, 3, null));
                        if (signature != null) {
                            predefinedFunctionEnhancementInfo = PredefinedEnhancementInfoKt.getPREDEFINED_FUNCTION_ENHANCEMENT_INFO_BY_SIGNATURE().get(signature);
                            if (predefinedFunctionEnhancementInfo != null) {
                                predefinedFunctionEnhancementInfo.getParametersInfo().size();
                                javaCallableMemberDescriptor.getValueParameters().size();
                            }
                            boolean z5 = (!UtilsKt.isJspecifyEnabledInStrictMode(lazyJavaResolverContext.getComponents().getJavaTypeEnhancementState()) || copyWithNewDefaultTypeQualifiers.getComponents().getSettings().getIgnoreNullabilityForErasedValueParameters()) && UtilsKt.hasErasedValueParameters(d);
                            List<ValueParameterDescriptor> valueParameters = propertyGetterDescriptorImpl.getValueParameters();
                            Intrinsics.checkNotNullExpressionValue(valueParameters, "annotationOwnerForMember.valueParameters");
                            List<ValueParameterDescriptor> list = valueParameters;
                            ArrayList arrayList2 = new ArrayList(CollectionsKt.collectionSizeOrDefault(list, 10));
                            for (ValueParameterDescriptor valueParameterDescriptor : list) {
                                TypeEnhancementInfo typeEnhancementInfo2 = (predefinedFunctionEnhancementInfo == null || (parametersInfo = predefinedFunctionEnhancementInfo.getParametersInfo()) == null) ? typeEnhancementInfo : (TypeEnhancementInfo) CollectionsKt.getOrNull(parametersInfo, valueParameterDescriptor.getIndex());
                                ArrayList arrayList3 = arrayList2;
                                arrayList3.add(enhanceValueParameter(d, valueParameterDescriptor, copyWithNewDefaultTypeQualifiers, typeEnhancementInfo2, z5, new SignatureEnhancement$enhanceSignature$valueParameterEnhancements$1$1(valueParameterDescriptor)));
                                arrayList2 = arrayList3;
                                typeEnhancementInfo = null;
                            }
                            ArrayList arrayList4 = arrayList2;
                            D d2 = propertyGetterDescriptorImpl;
                            propertyDescriptor = (PropertyDescriptor) (!(d instanceof PropertyDescriptor) ? null : d);
                            if (propertyDescriptor == null && JavaDescriptorUtilKt.isJavaField(propertyDescriptor)) {
                                annotationQualifierApplicabilityType = AnnotationQualifierApplicabilityType.FIELD;
                            } else {
                                annotationQualifierApplicabilityType = AnnotationQualifierApplicabilityType.METHOD_RETURN_TYPE;
                            }
                            enhance$default = enhance$default(this, d, d2, true, copyWithNewDefaultTypeQualifiers, annotationQualifierApplicabilityType, predefinedFunctionEnhancementInfo != null ? predefinedFunctionEnhancementInfo.getReturnTypeInfo() : null, false, SignatureEnhancement$enhanceSignature$returnTypeEnhancement$1.INSTANCE, 32, null);
                            returnType = javaCallableMemberDescriptor.getReturnType();
                            Intrinsics.checkNotNull(returnType);
                            if (!containsFunctionN(returnType)) {
                                ReceiverParameterDescriptor extensionReceiverParameter = javaCallableMemberDescriptor.getExtensionReceiverParameter();
                                if (!((extensionReceiverParameter == null || (type = extensionReceiverParameter.getType()) == null) ? false : containsFunctionN(type))) {
                                    List<ValueParameterDescriptor> valueParameters2 = javaCallableMemberDescriptor.getValueParameters();
                                    Intrinsics.checkNotNullExpressionValue(valueParameters2, "valueParameters");
                                    List<ValueParameterDescriptor> list2 = valueParameters2;
                                    if (!(list2 instanceof Collection) || !list2.isEmpty()) {
                                        for (ValueParameterDescriptor valueParameterDescriptor2 : list2) {
                                            KotlinType type2 = valueParameterDescriptor2.getType();
                                            Intrinsics.checkNotNullExpressionValue(type2, "it.type");
                                            if (containsFunctionN(type2)) {
                                                z3 = true;
                                                break;
                                            }
                                        }
                                    }
                                    z3 = false;
                                    if (!z3) {
                                        z = false;
                                        Pair<CallableDescriptor.UserDataKey<?>, ?> pair = !z ? TuplesKt.to(DescriptorBasedDeprecationInfoKt.getDEPRECATED_FUNCTION_KEY(), new DeprecationCausedByFunctionNInfo(d)) : null;
                                        if (kotlinType == null && enhance$default == null) {
                                            arrayList = arrayList4;
                                            if ((arrayList instanceof Collection) || !arrayList.isEmpty()) {
                                                for (KotlinType kotlinType3 : arrayList) {
                                                    if (kotlinType3 != null) {
                                                        z2 = true;
                                                        continue;
                                                    } else {
                                                        z2 = false;
                                                        continue;
                                                    }
                                                    if (z2) {
                                                        break;
                                                    }
                                                }
                                            }
                                            z4 = false;
                                            if (!z4 && pair == null) {
                                                return d;
                                            }
                                        }
                                        if (kotlinType != null) {
                                            ReceiverParameterDescriptor extensionReceiverParameter2 = javaCallableMemberDescriptor.getExtensionReceiverParameter();
                                            kotlinType2 = extensionReceiverParameter2 != null ? extensionReceiverParameter2.getType() : null;
                                        } else {
                                            kotlinType2 = kotlinType;
                                        }
                                        ArrayList arrayList5 = arrayList4;
                                        ArrayList arrayList6 = new ArrayList(CollectionsKt.collectionSizeOrDefault(arrayList5, 10));
                                        int i = 0;
                                        for (Object obj : arrayList5) {
                                            int i2 = i + 1;
                                            if (i < 0) {
                                                CollectionsKt.throwIndexOverflow();
                                            }
                                            KotlinType kotlinType4 = (KotlinType) obj;
                                            if (kotlinType4 == null) {
                                                kotlinType4 = javaCallableMemberDescriptor.getValueParameters().get(i).getType();
                                                Intrinsics.checkNotNullExpressionValue(kotlinType4, "valueParameters[index].type");
                                            }
                                            arrayList6.add(kotlinType4);
                                            i = i2;
                                        }
                                        ArrayList arrayList7 = arrayList6;
                                        if (enhance$default == null) {
                                            enhance$default = javaCallableMemberDescriptor.getReturnType();
                                            Intrinsics.checkNotNull(enhance$default);
                                        }
                                        JavaCallableMemberDescriptor enhance = javaCallableMemberDescriptor.enhance(kotlinType2, arrayList7, enhance$default, pair);
                                        Intrinsics.checkNotNull(enhance, "null cannot be cast to non-null type D of org.jetbrains.kotlin.load.java.typeEnhancement.SignatureEnhancement.enhanceSignature");
                                        return enhance;
                                    }
                                }
                            }
                            z = true;
                            if (!z) {
                            }
                            if (kotlinType == null) {
                                arrayList = arrayList4;
                                if (arrayList instanceof Collection) {
                                }
                                while (r1.hasNext()) {
                                }
                                z4 = false;
                                if (!z4) {
                                    return d;
                                }
                            }
                            if (kotlinType != null) {
                            }
                            ArrayList arrayList52 = arrayList4;
                            ArrayList arrayList62 = new ArrayList(CollectionsKt.collectionSizeOrDefault(arrayList52, 10));
                            int i3 = 0;
                            while (r2.hasNext()) {
                            }
                            ArrayList arrayList72 = arrayList62;
                            if (enhance$default == null) {
                            }
                            JavaCallableMemberDescriptor enhance2 = javaCallableMemberDescriptor.enhance(kotlinType2, arrayList72, enhance$default, pair);
                            Intrinsics.checkNotNull(enhance2, "null cannot be cast to non-null type D of org.jetbrains.kotlin.load.java.typeEnhancement.SignatureEnhancement.enhanceSignature");
                            return enhance2;
                        }
                    }
                    predefinedFunctionEnhancementInfo = null;
                    if (predefinedFunctionEnhancementInfo != null) {
                    }
                    if (UtilsKt.isJspecifyEnabledInStrictMode(lazyJavaResolverContext.getComponents().getJavaTypeEnhancementState())) {
                    }
                    List<ValueParameterDescriptor> valueParameters3 = propertyGetterDescriptorImpl.getValueParameters();
                    Intrinsics.checkNotNullExpressionValue(valueParameters3, "annotationOwnerForMember.valueParameters");
                    List<ValueParameterDescriptor> list3 = valueParameters3;
                    ArrayList arrayList22 = new ArrayList(CollectionsKt.collectionSizeOrDefault(list3, 10));
                    while (r18.hasNext()) {
                    }
                    ArrayList arrayList42 = arrayList22;
                    D d22 = propertyGetterDescriptorImpl;
                    propertyDescriptor = (PropertyDescriptor) (!(d instanceof PropertyDescriptor) ? null : d);
                    if (propertyDescriptor == null && JavaDescriptorUtilKt.isJavaField(propertyDescriptor)) {
                    }
                    enhance$default = enhance$default(this, d, d22, true, copyWithNewDefaultTypeQualifiers, annotationQualifierApplicabilityType, predefinedFunctionEnhancementInfo != null ? predefinedFunctionEnhancementInfo.getReturnTypeInfo() : null, false, SignatureEnhancement$enhanceSignature$returnTypeEnhancement$1.INSTANCE, 32, null);
                    returnType = javaCallableMemberDescriptor.getReturnType();
                    Intrinsics.checkNotNull(returnType);
                    if (!containsFunctionN(returnType)) {
                    }
                    z = true;
                    if (!z) {
                    }
                    if (kotlinType == null) {
                    }
                    if (kotlinType != null) {
                    }
                    ArrayList arrayList522 = arrayList42;
                    ArrayList arrayList622 = new ArrayList(CollectionsKt.collectionSizeOrDefault(arrayList522, 10));
                    int i32 = 0;
                    while (r2.hasNext()) {
                    }
                    ArrayList arrayList722 = arrayList622;
                    if (enhance$default == null) {
                    }
                    JavaCallableMemberDescriptor enhance22 = javaCallableMemberDescriptor.enhance(kotlinType2, arrayList722, enhance$default, pair);
                    Intrinsics.checkNotNull(enhance22, "null cannot be cast to non-null type D of org.jetbrains.kotlin.load.java.typeEnhancement.SignatureEnhancement.enhanceSignature");
                    return enhance22;
                }
            }
            propertyGetterDescriptorImpl = d;
            TypeEnhancementInfo typeEnhancementInfo3 = null;
            if (javaCallableMemberDescriptor.getExtensionReceiverParameter() == null) {
            }
            if (!(d instanceof JavaMethodDescriptor)) {
            }
            if (javaMethodDescriptor != null) {
            }
            predefinedFunctionEnhancementInfo = null;
            if (predefinedFunctionEnhancementInfo != null) {
            }
            if (UtilsKt.isJspecifyEnabledInStrictMode(lazyJavaResolverContext.getComponents().getJavaTypeEnhancementState())) {
            }
            List<ValueParameterDescriptor> valueParameters32 = propertyGetterDescriptorImpl.getValueParameters();
            Intrinsics.checkNotNullExpressionValue(valueParameters32, "annotationOwnerForMember.valueParameters");
            List<ValueParameterDescriptor> list32 = valueParameters32;
            ArrayList arrayList222 = new ArrayList(CollectionsKt.collectionSizeOrDefault(list32, 10));
            while (r18.hasNext()) {
            }
            ArrayList arrayList422 = arrayList222;
            D d222 = propertyGetterDescriptorImpl;
            propertyDescriptor = (PropertyDescriptor) (!(d instanceof PropertyDescriptor) ? null : d);
            if (propertyDescriptor == null && JavaDescriptorUtilKt.isJavaField(propertyDescriptor)) {
            }
            enhance$default = enhance$default(this, d, d222, true, copyWithNewDefaultTypeQualifiers, annotationQualifierApplicabilityType, predefinedFunctionEnhancementInfo != null ? predefinedFunctionEnhancementInfo.getReturnTypeInfo() : null, false, SignatureEnhancement$enhanceSignature$returnTypeEnhancement$1.INSTANCE, 32, null);
            returnType = javaCallableMemberDescriptor.getReturnType();
            Intrinsics.checkNotNull(returnType);
            if (!containsFunctionN(returnType)) {
            }
            z = true;
            if (!z) {
            }
            if (kotlinType == null) {
            }
            if (kotlinType != null) {
            }
            ArrayList arrayList5222 = arrayList422;
            ArrayList arrayList6222 = new ArrayList(CollectionsKt.collectionSizeOrDefault(arrayList5222, 10));
            int i322 = 0;
            while (r2.hasNext()) {
            }
            ArrayList arrayList7222 = arrayList6222;
            if (enhance$default == null) {
            }
            JavaCallableMemberDescriptor enhance222 = javaCallableMemberDescriptor.enhance(kotlinType2, arrayList7222, enhance$default, pair);
            Intrinsics.checkNotNull(enhance222, "null cannot be cast to non-null type D of org.jetbrains.kotlin.load.java.typeEnhancement.SignatureEnhancement.enhanceSignature");
            return enhance222;
        }
        return d;
    }

    public final List<KotlinType> enhanceTypeParameterBounds(TypeParameterDescriptor typeParameter, List<? extends KotlinType> bounds, LazyJavaResolverContext context) {
        KotlinType enhance$default;
        Intrinsics.checkNotNullParameter(typeParameter, "typeParameter");
        Intrinsics.checkNotNullParameter(bounds, "bounds");
        Intrinsics.checkNotNullParameter(context, "context");
        List<? extends KotlinType> list = bounds;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(list, 10));
        for (KotlinType kotlinType : list) {
            if (!TypeUtilsKt.contains(kotlinType, SignatureEnhancement$enhanceTypeParameterBounds$1$1.INSTANCE) && (enhance$default = enhance$default(this, new SignatureParts(typeParameter, false, context, AnnotationQualifierApplicabilityType.TYPE_PARAMETER_BOUNDS, false, 16, null), kotlinType, CollectionsKt.emptyList(), null, false, 12, null)) != null) {
                kotlinType = enhance$default;
            }
            arrayList.add(kotlinType);
        }
        return arrayList;
    }

    public final KotlinType enhanceSuperType(KotlinType type, LazyJavaResolverContext context) {
        Intrinsics.checkNotNullParameter(type, "type");
        Intrinsics.checkNotNullParameter(context, "context");
        KotlinType enhance$default = enhance$default(this, new SignatureParts(null, false, context, AnnotationQualifierApplicabilityType.TYPE_USE, true), type, CollectionsKt.emptyList(), null, false, 12, null);
        return enhance$default == null ? type : enhance$default;
    }

    private final boolean containsFunctionN(KotlinType kotlinType) {
        return TypeUtils.contains(kotlinType, SignatureEnhancement$containsFunctionN$1.INSTANCE);
    }

    private final KotlinType enhanceValueParameter(CallableMemberDescriptor callableMemberDescriptor, ValueParameterDescriptor valueParameterDescriptor, LazyJavaResolverContext lazyJavaResolverContext, TypeEnhancementInfo typeEnhancementInfo, boolean z, Function1<? super CallableMemberDescriptor, ? extends KotlinType> function1) {
        LazyJavaResolverContext copyWithNewDefaultTypeQualifiers;
        return enhance(callableMemberDescriptor, valueParameterDescriptor, false, (valueParameterDescriptor == null || (copyWithNewDefaultTypeQualifiers = ContextKt.copyWithNewDefaultTypeQualifiers(lazyJavaResolverContext, valueParameterDescriptor.getAnnotations())) == null) ? lazyJavaResolverContext : copyWithNewDefaultTypeQualifiers, AnnotationQualifierApplicabilityType.VALUE_PARAMETER, typeEnhancementInfo, z, function1);
    }

    static /* synthetic */ KotlinType enhance$default(SignatureEnhancement signatureEnhancement, CallableMemberDescriptor callableMemberDescriptor, Annotated annotated, boolean z, LazyJavaResolverContext lazyJavaResolverContext, AnnotationQualifierApplicabilityType annotationQualifierApplicabilityType, TypeEnhancementInfo typeEnhancementInfo, boolean z2, Function1 function1, int i, Object obj) {
        return signatureEnhancement.enhance(callableMemberDescriptor, annotated, z, lazyJavaResolverContext, annotationQualifierApplicabilityType, typeEnhancementInfo, (i & 32) != 0 ? false : z2, function1);
    }

    private final KotlinType enhance(CallableMemberDescriptor callableMemberDescriptor, Annotated annotated, boolean z, LazyJavaResolverContext lazyJavaResolverContext, AnnotationQualifierApplicabilityType annotationQualifierApplicabilityType, TypeEnhancementInfo typeEnhancementInfo, boolean z2, Function1<? super CallableMemberDescriptor, ? extends KotlinType> function1) {
        SignatureParts signatureParts = new SignatureParts(annotated, z, lazyJavaResolverContext, annotationQualifierApplicabilityType, false, 16, null);
        KotlinType invoke = function1.invoke(callableMemberDescriptor);
        Collection<? extends CallableMemberDescriptor> overriddenDescriptors = callableMemberDescriptor.getOverriddenDescriptors();
        Intrinsics.checkNotNullExpressionValue(overriddenDescriptors, "overriddenDescriptors");
        Collection<? extends CallableMemberDescriptor> collection = overriddenDescriptors;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(collection, 10));
        for (CallableMemberDescriptor it : collection) {
            Intrinsics.checkNotNullExpressionValue(it, "it");
            arrayList.add(function1.invoke(it));
        }
        return enhance(signatureParts, invoke, arrayList, typeEnhancementInfo, z2);
    }

    static /* synthetic */ KotlinType enhance$default(SignatureEnhancement signatureEnhancement, SignatureParts signatureParts, KotlinType kotlinType, List list, TypeEnhancementInfo typeEnhancementInfo, boolean z, int i, Object obj) {
        if ((i & 4) != 0) {
            typeEnhancementInfo = null;
        }
        return signatureEnhancement.enhance(signatureParts, kotlinType, list, typeEnhancementInfo, (i & 8) != 0 ? false : z);
    }

    private final KotlinType enhance(SignatureParts signatureParts, KotlinType kotlinType, List<? extends KotlinType> list, TypeEnhancementInfo typeEnhancementInfo, boolean z) {
        return this.typeEnhancement.enhance(kotlinType, signatureParts.computeIndexedQualifiers(kotlinType, list, typeEnhancementInfo, z), signatureParts.getSkipRawTypeArguments());
    }
}
